/***************************************************************************
                          cbibbasis.h  -  description
                             -------------------
    begin                : Fri Aug 10 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CBIBBASIS_H
#define CBIBBASIS_H

#include <string>
#include <ctype.h>
using namespace std;

#define ANZELS 30        /*!< Maximalanzahl von ELS fuer Intervallsuche bei der Nachbarschaftspruefung */
#define ANZELS2 100      /*!< Maximalanzahl von ELS fuer Intervallsuche zur Vorbereitung der Nachbarschaftspruefung und Matrixsuche*/
#define ANZGRP 20        /*!< Maximalanzahl von ELS-Gruppierungen bei der Nachbarschaftspruefung */
#define MAXWRT 3         /*!< Maximalanzahl von Woertern bei der Nachbarschaftspruefung */
#define ANZZL 52         /*!< Anzahl von Zeilen bei Fix-Listenausgabe */
#define ZLHOE 36         /*!< Anzahl Zeichen in einer Zeile fuer Listausgabe */
#define ZLBRT 62         /*!< Anzahl von hebr.Zeichen in einer Zeile bei Fix-Listenausgabe */
#define GRFZL 140        /*!< Zeilenbreite bei Grafikausgabe */
#define GRFSP  7         /*!< Spaltenanzahl bei Grafikausgabe */
#define GRFANZ 33        /*!< Zeilenanzahl bei Grafikausgabe */
#define MAXBRT 85        /*!< Maximale Zeilenbreite bei Flex-Listenausgabe */
#define MAXHEBLNG 150    /*!< Maximale Zeilenlaenge bei Ausgabe der Lexikasuche */
#define MAXLEXWRT 500    /*!< Maximale Anzahl von Lexikaausgaben in Liste */
#define MAXWRTLNG 40     /*!< Maximale Wortlaenge bei Lexika suchen und finden */
#define ANZHEBWRT 100    /*!< Maximale Anzahl hebr. Worte in einem Bibelvers */
#define WRTMATRIX 10     /*!< Maximale Anzahl hebr. Worte in einer Matrix */

//! Basisdaten zur Bitana Programmgruppe
/*!
Die Klasse CBibBasis -
dient zur Einstellung der Umgebungsparameter fuer das Projekt sowie
als Schnittstelle zur internen Datenuebergabe zwischen den einzelnen
Objekten.
*@author Heinz Schumann
*/

class KernProgress;

class CBibBasis
{
  public:
    CBibBasis();
    virtual ~CBibBasis();

    //! Setzt Basis - Verzeichnis
    /*!
    Von diesem Verzeichnis aus muss ein Unterverzeichnis
    /tmp/ vorhanden sein. In diesem Verzeichniss werden alle Zwischen- und Ausgabedateien
     der C++ Klassen abgelegt.

    \param string Absoluter Pfad zum Projektverzeichnis (default nicht belegt)
    */
    void setzBasVerzeichnis(string);

    //! Setzt das Buchverzeichnis
    /*!
    In diesem Verzeichnis sind die Code(Orginaltexte)
    jeweils mit *.cod und *.idx abgelegt. Unterverzeichnisse
    fuer die jeweilige Sprachvariante des Bibletextes haengen an
     diesem Verzeichnis (/de, /en). Die Lexika liegen in einem
     weiteren Unterverzeichniss (/lex).

    \param string Absoluter Pfad zum Verzeichnis (default nicht belegt)
    */
    void setzBasBuchVerzeichnis(string);

    //! Setzt das Ausgabeverzeichnis
    /*!
    Hier hinein werden alle Ausgabedateien der Benutzer-Oberflaechen geschrieben
    \param string Absoluter Pfad zum Verzeichnis (default nicht belegt)
    */
    void setzBasOutVerzeichnis(string);

    void setzNbrVonIntervall(int v);

    void setProgressText(string);
    
    bool setProgressStatus(int, int);
    
    void setProgressStop();
    
    /*!
     String Ausgabe der Funktion 'lesHebAbschnitt' in der Klasse 'CBuchHeb'
    \param var string heb_out_abschn
    \brief  Public Ausgabestring der Funktion "lesHebAbschnitt"
    */
    string heb_out_abschn;

    /*!
    \var string heb_in_abschn
    \brief Public Eingabestring f�r die Funktion (?)
     */
    string heb_in_abschn;

    /*!
     Char Ausgabe der Funktion 'lesHebBuchstaben' in der Klasse 'CBuchHeb'
    \var char heb_buchst
    \brief Public Ausgabe der Funktion "lesHebBuchstaben"
    */

    int progstat;             //! Status des Bearbeitungsstandes
    int progstep;             //! Steps des Bearbeitungsfortschrittes (=100%)
    
    char   heb_buchst;
    int    ikapitel;          //!< Integer Kapitel
    int    ivers;             //!< Integer Vers
    long   kapvpos;           //!< von Position bei posKap
    long   kapbpos;           //!< bis Position bei posKap

    string kap_vers;          //!< Kapitel Vers in Form '(01:22)'
    string kapitel;           //!< Kapitel
    string vers;              //!< Vers
    string progtxt;           //!< Text fuer Progress

//  protected:

    int nbr_von_inter;
    string tmp_verz;
    string buch_verz;
    string bas_verz;
    string out_verz;
  
   private:
   
   KernProgress *kp;       /*!< Objekt Progressbar */  
      
};

//! Struktur zur Intervallsuche
struct STRINTER
{
  int  apos;                /*!< Startposition ELS */
  int  epos;                /*!< Endposition ELS */
  int  inter;               /*!< Sequenz ELS */
  int  richt;               /*!< Route (0=forward 1=backward) */
  int  proz;                /*!< Prozent Minimalbereich */
  int  aber;                /*!< Beginn Minimalbereich */
  int  eber;                /*!< Ende Minimalbereich */
};

//! Struktur zur Nachbarschaftspruefung
struct STRNBRPR
{
      int inter[MAXWRT];   //!< Intervall
      int apos[MAXWRT];    //!< Beginposition Intervall
      int epos[MAXWRT];    //!< Endposition Intervall
      int aber[MAXWRT];    //!< Beginnposition Minimalbereich
      int eber[MAXWRT];    //!< Endposition Minimalbereich
      int proz[MAXWRT];    //!< Prozent Minimalbereich
      int idxint[MAXWRT];  //!< Zeilenbreite fuer Minimale Disdanz
      int adom;            //!< Beginn Domaene
      int edom;            //!< End Domaene
      int pro;             //!< Prozent Domaene
      int zlbrt;           //!< Zeilenbreite
      float distanz;       //!< Euklidischer Abstand
      float modabst;       //!< Modifizierter Abstand
};
//! Struktur zur Nachbarschaftssuche
struct STRNBR
{
  int  apos;       //!< Startposition ELS
  int  epos;       //!< Endposition ELS
  int  inter;      //!< Sequenz ELS
  int  richt;      //!< Route (0=forward 1=backward)
  int  proz;       //!< Prozent Minimalbereich
  int  aber;       //!< Beginn Minimalbereich
  int  eber;       //!< Ende Minimalbereich
  int  tmp;        //!< Arbeitsfeld
  int  entf[MAXWRT]; //!< Abstand der ELS
  int  satz[MAXWRT]; //!< Nummer der ELS
};

//! Struktur zur Nachbarschaft suchen
struct STRGRP
{
  int   entf;           //!< Linearabstand der Intervalle
  int   seq;            //!< Zeilenbreite fr Minimalabstand
  int   proz;           //!< Prozent der Domaene
  int   adom;           //!< Startposition minimal Domaene
  int   edom;           //!< Endposition minimal Domaene
  float abst;           //!< Euklid Minialabstand
  float koab;           //!< Modifizierte Euklid Minimalabstand
  int   els[MAXWRT];    //!< Intervalle fr Worte der Gruppe
  int   apos[MAXWRT];   //!< Beginposition Intervall
  int   epos[MAXWRT];   //!< Endposition Intervall
  int   aber[MAXWRT];   //!< Beginn Maximalbereich
  int   eber[MAXWRT];   //!< End Maximalbereich
  char  heb[MAXWRTLNG]; //!< Gefundene Worte bei such Nachbar (Hebr)
  char  deu[MAXWRTLNG]; //!< Gefundene Worte bei such Nachbar (Sprache)
};

//! Struktur fuer Nachbarschaft finden
struct STRHEBWRT
{
  float abst;                //!< Euklidischer Abstand zum Basiswort
  int  pos;                  //!< Beginnposition des Wortes
  int  seq;                  //!< Intervall des Wortes
  int  zl;                   //!< Nr. Zeile im Datenfeld
  int  sp;                   //!< Nr. Spalte im Datenfeld
  char ri;                   //!< Leserichtung
  char la;                   //!< Lage im Datenfeld
  char heb[MAXWRTLNG];       //!< Gefundene Worte (Hebr)
  char deu[MAXWRTLNG];       //!< Gefundene Worte (Sprache)  
};

//! Struktur fuer Intervallblock finden
struct STRBLOCK
{
  int inter;                 //!< Intervall
  int qswrt;                 //!< Quersumme Wort
  int apos;                  //!< Startposition Block
  int epos;                  //!< Endposition Block
  int banz;                  //!< Anzahl Buchstaben
  long int qsblk;            //!< Quersumme Block
  int qdiv;                  //!< Divident mit Quersumme Block / Quersumme Wort
  int qrest;                 //!< Divisionsrest  mit Quersumme Block / Quersumme Wort
  int idiv;                  //!<Divident  mit Anzahl Buchstaben / Intervall
  int irest;                 //!< Divisionsrest  mit Anzahl Buchstaben / Intervall
  int tdiv;                  //!< Divident bei Tripel Anzahl Buchstaben / Divisor (Parameter)
  int trest;                 //!< Divisionsrest bei Tripel Anzahl Buchstaben/ Divisor (Parameter)

};

//! Struktur fuer Matrixsuche
    struct STRMATRIX
    {
      int anzint;         //!< Anzahl Intervalle
      int lfdsatz;        //!< lfd Satz in der Intervalldatei
      int inter;          //!< Intervall d. lfd Satzes
      int apos;           //!< Beginposition Intervall
      int epos;           //!< Endposition Intervall
      int aber;           //!< Beginnposition Minimalbereich
      int eber;           //!< Endposition Minimalbereich
      int proz;           //!< Prozent Minimalbereich
      int abst;           //!< Linearabstand
      int anzbu;          //!< Anzahl Buchstaben
      int idxint;         //!< Intervall fuer Minimale Disdanz
      float distanz;      //!< Euklidischer Abstand
      string wrt;         //!< Suchwort
    };
//! Struktur fuer Datei Ein- und Ausgabe
/*! Struktur der Zwischendateien 'interlst.*' */
union UNIINTER
{
  STRINTER s;
  char     c[sizeof(STRINTER)];
};

//! Struktur fuer Datei Ein- und Ausgabe
/*! Struktur der Zwischendateien 'gruppen.*' */
union UNIGRP
{
  STRGRP s;
  char   c[sizeof(STRGRP)];
};

//! Struktur fuer Datei Ein- und Ausgabe
/*! Struktur der Zwischendatei 'nbrwrtls.*' */
union UNIHEBWRT
{
  STRHEBWRT s;
  char      c[sizeof(STRHEBWRT)];
};

//! Struktur fuer Datei Ein- und Ausgabe
/*! Struktur der Zwischendateien 'interblk.*' */
union UNIBLOCK
{
  STRBLOCK s;
  char     c[sizeof(STRBLOCK)];
};
#endif

