/***************************************************************************
                          cbibeltext.h  -  description
                             -------------------
    begin                : Sun Aug 12 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CBIBELTEXT_H
#define CBIBELTEXT_H

#include "cbuchindex.h"

//! Methoden zur Bibeltextbearbeitung
/*!
  Die Klasse 'CBibeltext' dient zur Bearbeitung von Bibeltexten in Versform
  *@author Heinz Schumann
  */
class CBibeltext : public CBuchIndex  {
public: 
	CBibeltext();
	~CBibeltext();

         /*!
          	
          Aus dem angegebenen Buch wird der vorgegebene Textabschnitt
          in der gewaehlten Sprache (Voreingestellt ist deutsch) dem
          Hebraeischtext gegenueber gestellt und in einer Liste
          ausgegeben (Voreingestellt ist "bibabschn.bta").
          Die Liste ist mit internen Steuerzeichen versehen und muss
          durch Objekte der Benutzeroberflaeche weiter bearbeitet werden.
          Der Rueckgabewert ist 0 bei Fehler der Fehlercode.
          \param string buch,    (Bibelbuch)
         	\param int vonKapitel,
         	\param int vonVers,
        	\param int bisKapitel,
         	\param int bisVers,
         	\param string sprache (default = "de" -> deutsch),
         	\param string datei (default = "bibabsch.bta"),
          \brief Listausgabe eines Bibelabschnittes in Versform
        */

  int bibelAbschnitt(string buch,
                     int vkap, int vvers,
                     int bkap, int bvers,
                     string sprache="de",
                     string datei="bibabsch.bta");

         /*!

         Aus dem angegebenen Buch wird der vorgegebene hebr Textabschnitt
         aufgesucht und einer Textanalyse unterzogen. Das Ergebniss
         wird in einer Liste ausgegeben (Voreingestellt ist "bibabana.bta").
         Die Liste ist mit internen Steuerzeichen versehen und muss
         durch Objekte der Benutzeroberflaeche weiter bearbeitet werden.
         Der Rueckgabewert ist 0 bei Fehler der Fehlercode.
         \param string buch,  (Bibelbuch)
         \param int vonKapitel
         \param int vonVers
         \param int bisKapitel
         \param int bisVers
         \param string datei (default = "bibabana.bta")
         \brief Gematria Analyse eines Bibelabschnittes
        */

  int bibelAbschnittAnalyse(string buch, int vkap, int vvers,
                            int bkap, int bvers,
                            string datei="bibabana.bta");


 private:
  FILE *fbuch;
  string gerverz;
  string gerbuch;
  string gertxt;
  int gerkap;
  int gervers;
};


#endif
