/***************************************************************************
                          cbibgematria.cpp  -  description
                             -------------------
    begin                : Thu Aug 23 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz@bitana.de

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <string>

#include "cbibgematria.h"

CBibGematria::CBibGematria(){
}
CBibGematria::~CBibGematria(){
}
/***********************************************************************/
int CBibGematria::wertBuchstabe(char buchst, int spalte=0)
{
// Gematria Tabelle
 int tabgem[8][27]={
/*0=absolute*/      {1,2,3,4,5,6,7,8,9,
                     10,20,20,30,40,40,50,50,60,70,80,80,90,90,
                     100,200,300,400},
/*1=absolutrevers*/ {400,300,200,100,90,80,70,60,50,
                     40,30,30,20,10,10,9,9,8,7,6,6,5,5,
                     4,3,2,1},
/*2=reducts*/       {1,2,3,4,5,6,7,8,9,
                     1,2,2,3,4,4,5,5,6,7,8,8,9,9,
                     1,2,3,4},
/*3=ordinal*/       {1,2,3,4,5,6,7,8,9,
                     10,11,11,12,13,13,14,14,15,16,17,17,18,18,
                     19,20,21,22},
/*4=quadrat*/       {1,4,9,16,25,36,49,64,81,
                     100,121,121,144,169,169,196,196,225,256,289,289,324,324,
                     361,400,441,484},
/*5=atbash*/        {9,8,7,6,5,4,3,2,1,
                     90,80,80,70,60,60,50,50,40,30,20,20,10,10,
                     400,300,200,100},
/*6=absolutdirekt*/ {1,2,3,4,5,6,7,8,9,
                     10,500,20,30,600,40,700,50,60,70,800,80,900,90,
                     100,200,300,400},
/*7=reductdirekt*/  {1,2,3,4,5,6,7,8,9,
                     1,5,2,3,6,4,7,5,6,7,8,8,9,9,
                     1,2,3,4}
                    };

 int ch= buchst+32;
 if(ch<0 || ch>26) return 0;    // Falsche Vorgabe
 return tabgem[spalte][ch];
}
/*********************************************************************/
int CBibGematria::wertZeile(string zeile, int spalte=0)
{
 int sum=0;
 int betr;
 for(int i=0;i < (int)zeile.size();i++)
 {
	betr=wertBuchstabe(zeile.at(i),spalte);  	
  if(betr==0) return 0;       // undefiniertes Zeichen
  sum+=betr;
 }
 return sum;
}
/******************************************************************/
string CBibGematria::textAtbash(string text, int spalte=0)
{
// Umkehrtabelle
 char tabcod[2][27]={
/*0=Abnsolut*/       {250,249,248,247,246,244,242,241,240,
                      238,236,236,235,233,233,232,232,231,230,229,229,228,228,
                      227,226,225,224},
/*1=*/               {245,244,243,242,241,240,239,238,237,
                      236,235,235,234,233,233,232,232,231,230,229,229,228,228,
                      227,226,225,224}
                    };
 string zwtx="";
 char ca[2]=" ";
 int i;

 for(i=0;i< (int)text.size();i++)
 {
  ca[0]=text.at(i)+32;
  if(ca[0]<0 || ca[0]>26) return "";    // Falsche Vorgabe
  zwtx+=tabcod[spalte][ca[0]];
 }
 return zwtx;
}
/************************************************************************/
string CBibGematria::eigenschaftBuchstabe(char bu)
{
string bez="             ";
int ch=bu+32;

// Tabelle Eigenschaften (Max = 14 Buchstaben)
 switch(ch)
 {
  case  0: bez="Unendlichkeit ";
           break;
  case  1: bez="Chaosordnen   ";
           break;
  case  2: bez="Formgeben     ";
           break;
  case  3: bez="Formdarstellen";
           break;
  case  4: bez="Materiebilden ";
           break;
  case  5: bez="Mineralien    ";
           break;
  case  6: bez="Pflanzen      ";
           break;
  case  7: bez="Tiere         ";
           break;
  case  8: bez="Schutzengel   ";
           break;
  case  9: bez="Heroen        ";
           break;
  case 10: bez="Universum     ";
           break;
  case 11: bez="Bewegung      ";
           break;
  case 12: bez="3.Himmel      ";
           break;
  case 13: bez="5.Himmel      ";
           break;
  case 14: bez="4.Himmel      ";
           break;
  case 15: bez="7.Himmel      ";
           break;
  case 16: bez="6.Himmel      ";
           break;
  case 17: bez="8.Himmel      ";
           break;
  case 18: bez="9.Himmel      ";
           break;
  case 19: bez="Luft          ";
           break;
  case 20: bez="Feuer         ";
           break;
  case 21: bez="Materie       ";
           break;
  case 22: bez="Wasser        ";
           break;
  case 23: bez="Erdreich      ";
           break;
  case 24: bez="Animalisch    ";
           break;
  case 25: bez="Lebenskeim    ";
           break;
  case 26: bez="Mikrokosmos   ";
           break;
  default: bez="Fehlerhaft    ";
 }
 return bez;
}
/************************************************************************/
char CBibGematria::buchstabeGruppe(char bu, int spalte)
{
 /*
  Gruppenzuordnungs Tabelle

   Rueckgabewerte
   Mtter   = 1
   Doppelte = 2
   Einfache = 3
 */
 char tabcod[4][27]={
/*0=Abnsolut*/       {1,2,2,2,3,3,3,3,3,
                      3,2,2,3,1,1,3,3,3,3,2,2,3,3,
                      3,2,1,2},
/*1=Absolutdirekt*/  {1,2,2,2,3,3,3,3,3,
                      3,2,2,3,1,1,3,3,3,3,2,2,3,3,
                      3,2,1,2},
/*2=Zahlgrpabsolut*/ {1,1,1,1,1,1,1,1,1,
                      2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,
                      3,3,3},
/*3=Zlgrpdirekt*/    {1,1,1,1,1,1,1,1,1,
                      2,3,2,2,3,2,3,2,2,2,2,3,2,3,2,
                      3,3,3},
                    };
 int ch= bu+32;
 if(ch<0 || ch>26) return 0;    // Falsche Vorgabe
 return tabcod[spalte][ch];
}

string CBibGematria::hebJahrErmitteln(int ja)
{
 string jahr="";
 int jahrzahl = (ja+3760)%1000;
 int vgl = 0;
 int bw = 0;
 char bu = -6;
 
 while(vgl != jahrzahl)
 {
  bw = wertBuchstabe(bu, 0);
  if((vgl+bw) <= jahrzahl)
  { 
   vgl += bw;
   jahr += bu;
  }
  bu -= 1;
  if( bu < -32 ) break;
 }

 return jahr;
}
