/***************************************************************************
                          cbibgematria.h  -  description
                             -------------------
    begin                : Thu Aug 23 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CBIBGEMATRIA_H
#define CBIBGEMATRIA_H

#include "cbibbasis.h"
using namespace std;

//! Funktionen zur Ermittlung von Gematria-Werten
/*!
  Auf Basis der Tabelle (CGematria::wertBuchstabe 'tabgem') werden Gematriawerte
  ermittelt und zurckgegeben.
  *@author Heinz Schumann
  */

class CBibGematria : public CBibBasis
{
 public:
	 CBibGematria();
   ~CBibGematria();
/*!

      Unter Vorgabe der Spalte (siehe tabgem) und des hebr. Buchstabens
      wird der Zahlenwert lt. Gematria aus der Tabelle zurueckgegeben.
      Voreingestellt ist Spalte 0.
      Bei falscher Vorgabe ist der Wert Null.
      \param char buchst  (Hebr. Buchstabe)
      \param int spalte = Tabellenspalte (default = 0)
      \brief Der Gematriawert eines Buchstabens wird zurckgegeben.
*/
   int    wertBuchstabe(char buchst, int spalte);
/*!

       Unter Vorgabe der Spalte (siehe tabgem) und eines hebr.Textes
       (ohne Leerzeichen) wird die Gematriasumme ermittelt und zurck-
       gegeben.Voreingestellt ist Spalte 0.
       Bei einem falschen Zeichen im Text ist die Rckgabe Null
       \param string zeile (Textvorgabe hebr.)
       \param int spalte = Tabellenspalte (default = 0)
       \brief Der Gematriawert einer Zeichenkette wird zurckgegeben
*/

   int    wertZeile(string zeile, int spalte);
/*!

   Unter Vorgabe eines Textes ohne Leerzeichen wird
   der Atbashtext (Textumkehrung) zurueckgegeben.
   Ueber Spalte wird das Umkehrverfahren (siehe tabcod) bestimmt.
   Bei falscher Vorgabe ist der Rueckgabewert ein Nullstring.
   \param string text (Vorgabetext hebr)
   \param int spalte = Tabellenspalte (default = 0)
   \brief Textumkehrung nach dem Atbashverfahren
*/
   string textAtbash(string text, int spalte);
/*!

   Unter Vorgabe eines Buchstaben wird dessen Eigenschaft
   (nach Papus) zurueckgegeben. Der Rueckgabewert ist String
   (max 14 Zeichen)
   \param char Buchstabe
   \brief Eigenschaft eines Buchstabens
*/
  string eigenschaftBuchstabe(char bu);
/*!

   Unter Vorgabe eines hebr. Buchstabens wird
   die Gruppe der Zugehoerigkeit lt. Buch Jesira
   (Mutter, Doppelt, Einfach) aufgesucht und zurueckgegeben.
   Ueber Spalte wird die Gruppenart (siehe tabcod) bestimmt.
   Bei falscher Vorgabe ist der Rueckgabewert Null.
   \param char buchstabe (Vorgabe hebr Buchstabe)
   \param int spalte = Tabellenspalte (default = 0)
   \brief Buchstabenzuordnung nach dem Buch Jesira
*/
   char buchstabeGruppe(char bu, int spalte=0);
/*!
   Untervorgabe einer gregor. Jahreszahl wird die
   heb. Jahreszahl ermittelt und im Feld heb_out_abschn 
   bereitgestellt 
   \param int ja = Gregorianische Jahreszahl
   \brief Umrechnung in heb Jahreszahl
*/
  string hebJahrErmitteln(int ja);
};

#endif
