/***************************************************************************
                          cbitanaconfig.cpp  -  description
                             -------------------
    begin                : Sun May 19 2002
    copyright            : (C) 2002 by Heinz & Hans-J�rgen Schumann
    email                : heinz@bitana.de; hans@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream>
#include <sstream>

using namespace std;

#include "cbitanaconfig.h"

CBitanaConfig::CBitanaConfig()
{

  clearConfig();
}

CBitanaConfig::~CBitanaConfig()
{}

/** Liest die Sektionen der Konfigurationsdatei datei. */
bool CBitanaConfig::readConfig(string datei, bool mix)
{

  ifstream cf(datei.c_str());
  if (!cf.good()) return false;

  if (!mix) clearConfig();

  string buf="";
  string line[3];		// 0 key, 1 wert, 2 section

  // Zeilenweise lesen
  while (getline(cf, buf))
  {
    char c;
    int i = 0;
    line[0] = "";

    // Zeichenweise lesen
    bool text = false;
    string::iterator p = buf.begin();
    while (p != buf.end())
    {
      c = char(*p++);
      if (c == '#') break;		// Kommentarzeile
      if (c == '\'' )
      {
        if (text == false) text = true;
        else text = false;
      }
      if ((c == ' ') && (text == false)) continue;		// Leerzeichen ueberlesen
      if (c == '[')
      {				// Begin neue Sektion
        i=2;
        line[i] = "";
        continue;
      }
      if (c == ']')
      {				// ende Sektionsbezeichnung
        setSection(line[2]);
        break;
      }
      if (c == '=')
      { 			// wert lesen
        i = 1;
        line[i] = "";
        continue;
      }
      line[i] += c;
    }
    if (i == 1) setStringEntry(line[0], line[1]);
  }
  cf.close();
  return true;
}

/** Schreibt die Konfiguration in eine datei */
bool CBitanaConfig::saveConfig(string datei)
{

  ofstream cf(datei.c_str(), ios::out);
  if (!cf.good()) return false;

  cf << "# Bitana - v. 3.0 " << endl;

  map<string,string>::iterator	itent;		// Iterator Eintr�ge
  map<string,string>* se;

  itsec = sections.begin();
  while (itsec != sections.end())
  {
    se = itsec->second;
    if ((se->size() != 0) && (nosave.find(itsec->first, 0) == string::npos))
    {
      // wenn Eintraege oder nicht in Liste nosave -> Sektion schreiben
      cf << "[" << itsec->first << "]" << endl;
      itent = se->begin();
      while (itent != se->end())
      {
        cf << itent->first << " = " << itent->second << endl;
        itent++;
      }
    }
    itsec++;
  }
  cf.close();
  return true;
}

/** Sektion setzen / neu erzeugen */
void CBitanaConfig::setSection(string sec)
{

  section = sec;
  if ( sections.find(sec) == sections.end() ) sections[sec] = new map<string, string>;
  secmap = sections[sec];

}

/** Liest ein Integer Eintrag aus der aktiven Sektion */
int CBitanaConfig::getIntEntry(string key, int standard)
{

  if ( secmap->find(key) == secmap->end() ) return standard;
  stringstream s;
  int wert;
  s << (*secmap)[key];
  s >> wert;
  return wert;
}

/** Liest ein Long-Integer Eintrag aus der aktiven Sektion */
long CBitanaConfig::getLongEntry(string key, long standard)
{

  if ( secmap->find(key) == secmap->end() ) return standard;
  stringstream s;
  long wert;
  s << (*secmap)[key];
  s >> wert;
  return wert;
}

/** Liest ein string Eintrag aus der aktiven Sektion. */
string CBitanaConfig::getStringEntry(string key, string standard)
{

  if ( secmap->find(key) == secmap->end() ) return standard;
  return (*secmap)[key];
}

/** Schreibt (legt an) / ueberschreibt ein Int-Wert in die aktive Sektion. */
void CBitanaConfig::setIntEntry(string key, int wert)
{

  stringstream s;
  s << wert;
  (*secmap)[key] = s.str();
}

/** Schreibt (legt an) / ueberschreibt ein long-Int-Wert in die aktive Sektion. */
void CBitanaConfig::setLongEntry(string key, long wert)
{

  stringstream s;
  s << wert;
  (*secmap)[key] = s.str();
}


/** Schreibt (legt an) / ueberschreibt ein String Eintrag in die aktive Sektion. */
void CBitanaConfig::setStringEntry(string key, string wert)
{
  (*secmap)[key] = wert;
}

/** Gibt die aktive sektion zurueck */
string CBitanaConfig::getSection(){ return section;}


/** Loeschen der aktuellen Eintruege unddefault - Sektion setzten */
void CBitanaConfig::clearConfig()
{

  itsec = sections.begin();
  while (itsec != sections.end())
  {
    secmap = itsec->second;
    secmap->clear();
    itsec++;
  }
  sections.clear();

  // default - Section als aktive Sektion
  //
  section = "default";
  secmap = new map<string, string>;
  sections[section] = secmap;
  nosave = "";

}

/** Pruefen, ob ein Eintrag in der aktuellen Sektion vorhanden ist */
bool CBitanaConfig::isEntry(string entry)
{

  if ( secmap->find(entry) == secmap->end() ) return false;
  return true;

}

/** Loescht - Nosave - Eintraege - alle sectionen werden gesichert */
void CBitanaConfig::clearNoSave() { nosave=""; }

/** Fuegt Eintrag zu nicht speichern hinzu */
void CBitanaConfig::addNoSave(string key)
{
  nosave += "--" + key;
}

