/***************************************************************************
                          cbuchheb.h  -  description
                             -------------------
    begin                : Fri Aug 10 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CBUCHHEB_H
#define CBUCHHEB_H

#include <string>
#include <stdio.h>

#include "cbibgematria.h"
using namespace std;


//! Bereitstellen von Datenformationen zum Hebr.Originaltext
/*!
 
  *@author Heinz Schumann
  */

class CBuchHeb : public CBibGematria
{
public:
    CBuchHeb();
    ~CBuchHeb();

    /*!
     
       Unter Vorgabe der 'von' 'bis' Position wird im Hebr.Code
       der Textabschnitt aufgesucht und in den string heb_out_abschn in
       'CBibBasis' fr die Unterklassen eingetragen.
        Rueckgabewert ist 0 ansonsten Fehlercode
       \param string buch  (Bibelbuch)
       \param int vonPosition (Beginnposition im hebr. Text)
       \param int bisPosition (Endposition im hebr. Text)
       \brief Bereitstellen eines hebr. Textausschnittes in 'heb_out_abschn'
    */
    int lesHebAbschnitt(string, int, int);

    /*!
     
       Der Buchstabe wird an der vorgegebenen Position im Hebr.Code
       gelesen und im Publikfeld char heb_buchst in CBibBasis fr die
       Unterklassen bereitgestellt.
       Rueckgabewert ist 0 ansonsten Fehlercode
       \param string buch (Bibelbuch)
       \param int position (Position des Buchstabens im Text)
       \brief Bereitstellen eines hebr.Buchstabens in heb_buchst
      */
    int lesHebBuchstaben(string, int);
    /*!
     
      Im hebr. Text des Bibelbuches werden alle Schlussbuchstaben Kaph,
      Mem, Nun, Pe und Sade in normale Schreibweise umgewandelt.
      Diese Umwandlung (Modifizierung) gilt fuer alle Aktionen am Bibeltext
      bis zum Aufruf eines anderen Buches. Sie kann nur durch Neuaufruf des
      Buches rueckgaengig gemacht werden.
      Rueckgabewert ist 0 ansonsten Fehlercode.
      \param string buch  (Bibelbuch)
      \brief Umwandeln der hebr.Schlussbuchstaben in einem Bibelbuch
      */
    int modifiBuch(string);

    /*!
      In der Bereitgestellten hebr. Textkette  werden alle Schlussbuchstaben Kaph,
      Mem, Nun, Pe und Sade in normale Schreibweise umgewandelt.
      Rueckgabewert ist die gewandelte Textkette.
      \param string text (Textkette)
      \brief Umwandeln der hebr. Schlussbuchstaben innerhalb einer Textkette
      */
    string modifiWort(string);

    /*!
      In der Bereitgestellten hebr. Textkette  werden alle Leerzeichen
      entfernt. Rueckgabewert ist die gewandelte Textkette.
      \param string text (Textkette)
      \brief Umwandeln der hebr. Schlussbuchstaben innerhalb einer Textkette
      */
    string pruefWort(string);

    /*!
      Der vorgegebene Text wird in seiner Schreibweise (Leserichtung) umgekehrt.
      Rueckgabewert ist der umgekehrte Text.
      \param string text (Textvorgabe)
      \brief Umkehrung der Leserichtung
      */
    string textUmkehr(string);
    /*!
     
       Zum vorgegebenen Wort werden im bezeichneten Buch die Intervalle aufgesucht
       und in der Datei mit der Satzstruktur \sa STRINTER eingetragen.
       Rueckgabewert ist die Anzahl der gefundenen Intervalle.
       Rueckgabewert bei Fehler die Fehlernummer als negative Zahl
       \param string buch  (Bibelbuch)
       \param string wort  (Suchwort)
       \param int vonIntervall (Beginn mit Intervallweite, default = 2)
       \param int bisIntervall (Suche bis Intervall, default = Maximal Intervall = 999999)
       \param int vonPosition  (Suchbeginn bei Textposition, default = 0)
       \param int bisPosition  (Suchende bei Textposition, default = Buchende = 999999)
       \param int Richtung (Zu suchende Intervallrichtung  0 = Vor- und Rckw�ts,
                            1 = Vorwaerts, 2 = Rueckwaerts, default = 0)
       \param string outdatei (Name der Ausgabedatei, default = "interlst.zwi")
       \brief Inervallsuche im Bibelbuch zu einem Wort
      */
    int suchIntervall(string buch, string wort,
                      int vinter, int binter,
                      int vpos, int bpos,
                      int richtung, 
                      string datei,
                      bool modifi);
    /*!
     
      Die vorher durch "suchIntervall" erstellte Liste wird sortiert und als
      neue Liste geschrieben. Die Datenstruktur \sa STRINTER wird beibehalten.
      Rueckgabewert ist 0, bei Fehler die Fehlernummer
      \param int art (Sortierfolge, 0 = Intervall, 1 = Startposition, 2 = Prozent Minimalbereich,
                      default = 0)
      \param string Ausgabedatei (Name der Ausgabedatei, default = "interlst.sor")
      \param string Eingabedatei (Name der Eingabedatei, default = "interlst.zwi")
      \brief Sortieren einer Intervalldatei
      */
    int sortListeIntervall(int art,
                           string outdatei,
                           string indatei);
    /*!
      Gibt den statistischen Erwartungswert der Anzahl von Intervallen zurck
      \param string buch (Bibelbuch)
      \param string wort (Suchwort)
      \param int vonIntervall (Beginn mit Intervallweite, default = 2)
      \param int bisIntervall (Suche bis Intervall, default = Maximal Intervall = 999999)
      \param int vonPosition  (Suchbeginn bei Textposition, default = 0)
      \param int bisPosition  (Suchende bei Textposition, default = Buchende = 999999)
      \param int Richtung (Zu suchende Intervallrichtung 0 = Vor- und Rueckwaerts,
                          1 = Vorwaerts, 2 = Rueckwaerts, default = 0).
      \param bool modifi (Berrechnung im modifizierten Text, default = true)
      \brief Berechnung des statistischen Erwartungswertes zu einer Intervallsuche
      */
    float intervallErwartung(string buch, string wort,
                             int vinter, int binter,
                             int vpos, int bpos,
                             int richtung,
                             bool modifi);
    /*!
      Gibt den erforderlichen "bisIntervall" Wert zurueck um die als "mindest"
      vorgegebene Anzahl von Intervallen zu erreichen. Er wird Anhand des stat.
      Erwartungswertes ermittelt.
      \param string buch (Bibelbuch)
      \param string wort (Suchwort)
      \param int Anzahl Intervalle (Anzahl der gewuenschten Intervalle)
      \param int vonPosition  (Suchbeginn bei Textposition, default = 0)
      \param int bisPosition  (Suchende bei Textposition, default = Buchende = 999999)
      \param bool modifi (Berrechnung im modifizierten Text, default = true)
      \brief Ermitteln der erforderlichen Intervallweite
      */
    int mindestIntervall(string buch, string wort, int mindest,
                         int vpos, int bpos,
                         int richtung,
                         bool modifi);
    /*!
      In einer nach Intervall sortierten Intervalldatei \sa 'suchIntervall' werden
      die Angaben zum Minimalbereich ergaenzt. Eine Vorsortierung nach Intervall ist zwingend.
      Minimalbereich ist jener Bereich im Text, in welchem kein kleineres Intervall
      zu diesem Wort vorkommt. Er wird in Prozent zum gesamten Text angegeben.
      Rueckgabewert ist 0, bei Fehler der Fehlercode.
      \param string Ausgabedatei (Name der Ausgabedatei, default = "interlst.min")
      \param string Eingabedatei (Name der Eingabedatei, default = "interlst.sor")
      \brief  Ermittelt den Minimalbereich zu einem Intervall.
      */
    int ermittleMinimalbereich(string outdatei,
                               string indatei);

    /*! Sucht zu einem vorgegebenen Wort alle Intervallbloecke im Textabschnitt und stellt das Ergebniss
     in der Datei "interblk.zwi" bereit.
     Rueckgabewert ist 0, bei Fehler der Fehlercode.
     \param string Bibelbuch
    \param string Hebr. Wort
    \param int vonPosition (Start Suchbereich, default = 0)
    \param int bisPosition (Ende Suchbereich, default = Buchende = 999999)
    \param int Divisor (default = 0) (eingetragen im Feld blk)
    \param int Anzahl Intervalle. (default = 1000)
    \param bool  Bibeltext modifizieren (default = true \sa CBuchHeb::modifiBuch) 
    \param string Datei Name der Ausgabedatei (default = "interblk.bta")
    \brief Intervallbloecke suchen
     */
    int suchBlock(string buch, string wort,
                  int vonpos,
                  int bispos,
                  int blk,
                  int ianz,
                  bool mod,
                  string outdatei);

    /*! Rueckgabe der Datenlaenge des Hebraeischen Textes zum vorgegebenen Buch */
    int ermittleBuchlaenge(string buch);

    /*!
      Liest den hebr. Text in Intervallschritten und stellt das Ergebniss in
      einer Datei bereit. Jede gelesene Zeile wird mit einem Zeilenende '\n'
      abgeschlossen. Rueckgabewert ist die Anzahl der geschriebenen Zeilen.
      \param string buch (Bibelbuch)
      \param int Intervall (Zu lesende Intervallweite)
      \param int Zeilenbreite (Zeilenbreite in welcher der Text geschrieben wird, default = 3)
      \param int vonPosition  (Suchbeginn bei Textposition, default = 0)
      \param int bisPosition  (Suchende bei Textposition, default = Buchende = 999999)
      \param string Name der Ausgabedatei (default = "intergrp.btn" 
      \param bool Modifiziert (default = true)
      */
    int lesIntervall(string buch, int intervall,
                     int zeilenbreite,
                     int vpos, int bpos,
                     string datei,
                     bool modifi);

    /*! Sucht zu einem vorgegebenen Wort alle Intervallbloecke im Buch und stellt das Ergebniss
     in der Datei "interblk.zwi" bereit.
     Rueckgabewert ist 0, bei Fehler der Fehlercode.
     \param string buch (bibelbuch)
     \param string wort (Suchwort)
     \param string datei (Ausgabedatei default = "interblk.zwi")
     */
    int suchWortBlock(string buch, string wort,
                      int blk=0,
                      int ianz=1000,
                      string datei="interblk.zwi");

    /*! Loescht das im Speicher eingelagerte Bibelbuch
        um die Neueroeffnung zu erzwingen
     */
    void loeschHebBuch();

    long   hebbuchlng;         //!< Buchlaenge des geoeffneten Buches

protected:
    bool schltmodifi;
    string hebbuch;
    bool openHebBuch(string);
    void zaehlBuchstaben(int vpos, int bpos);
    char *daten;

private:
    FILE *fhebbuch;
    int  hebbuchst[28];

};

#endif
