/***************************************************************************
                          cbuchindex.h  -  description
                             -------------------
    begin                : Thu Aug 9 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz@bitana.de

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/



#ifndef CBUCHINDEX_H
#define CBUCHINDEX_H

#include <string>
#include <stdio.h>
using namespace std;

#include "cbuchheb.h"

//!  Bereitstellen von Info-Werten und Texten aus Bibelbchern

/*!
  *@author Heinz Schumann
  */

class CBuchIndex : public CBuchHeb
{
 public:
	CBuchIndex();
	~CBuchIndex();
/*!

  Ermitteln von Kapitel und Vers zu einer Textposition. Es wird
  Kapitel und Vers ermittelt in dessen Bereich die Position liegt.
  Die ermittelten Werte werden in die Felder der Klasse \sa 'CBibBasis'
  eingetragen.
  Rueckgabewert ist 0, bei Fehler der Fehlercode.
  \param string buch (bibelbuch)
  \param int position (Zeichenposition im Text)
  \brief Ermitteln von Kapitel und Versangaben
  */
  int posKap(string,int);
/*!

  Es werden die Positionswerte zu einem Bibelvers ermittelt.
  Die ermittelten Werte werden in die Felder der Klasse \sa'CBibBasis'
  eingetragen.
  Rueckgabewert ist 0, bei Fehler der Fehlercode.
  \param string buch (bibelbuch)
  \param int Kapitel
  \param int Vers
  \brief Ermitteln von Start- und Endposition zu einem Bibelvers.
  */
  int kapPos(string, int, int);
/*!

  Es werden die Positionsdaten einschlieslich der Satzstruktur
  zum naechsten Bibelvers, ausgehend von den vorgegebenen Daten,
  im den entsprechenden Feldern in \sa 'CBibBasis' bereitgestellt.
  Rueckgabewert ist 0, bei Fehler der Fehlercode.
  \param string buch (Bibelbuch)
  \param int kapitel
  \param int vers
  \brief Bereitstellen der Daten zum naechsten Vers
  */
  int nextHebVers(string, int, int);

 protected:
  int    hebwrtstru[ANZHEBWRT];

 private:
  bool openIdxBuch(string);
  bool nextIdxSatz();
  void idxDatenEintragen();

  string idxbuch;

  long   idxbuchlng;
  FILE   *fidxbuch;
  struct
  {
   unsigned char kvbez[4];
   int  vpos;
   int  bpos;
  } idxkopf;

};

#endif
