/***************************************************************************
                          cintervall.cpp  -  description
                             -------------------
    begin                : Sun Oct 14 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <stdio.h>

#include "cintervall.h"

CIntervall::CIntervall()
{}
CIntervall::~CIntervall()
{}

int CIntervall::listeIntervall(string buch, string wort,
                               int voninter=2, int bisinter=999999,
                               int vonpos=0, int bispos=999999,
                               int richtung=0, int sortier=0,
                               bool modifi=true,
                               bool erwart=true,
                               string datei="interval.bta")
{
    int pr=5;
    int status=0;
    int anz=0;
    float erw=999999;
    bool maxanz=false;
    bool redu=false;
    string verz;

    FILE *fdatei, *fein;

    wort=pruefWort(wort);
    if(voninter==2)
        pr+=2;
    if(voninter==0)
        voninter=1;
    string uwort=textUmkehr(wort);

    // Bestimmen der statistischen Erwartung
    if(erwart)
    {
        while(erw>2000.0 && !maxanz)
        {
            erw=intervallErwartung(buch, wort, voninter, bisinter,
                                   vonpos, bispos, richtung,
                                   modifi);
            if(erw>2000.0 && voninter<bisinter)            // max Anzahl Intervalle in der Liste
            {
                anz=(bisinter-voninter)/2;
                bisinter=voninter+anz;
                redu=true;
            }
            if(erw>2000.0 && voninter==bisinter)
                maxanz=true;
        }
    }
    if(!maxanz)
    {
        // Aufsuchen der Intervalle
        anz=suchIntervall(buch, uwort,
                          voninter, bisinter,
                          vonpos, bispos,
                          richtung, "interlst.zwi", modifi);

        if(anz<0)
            return abs(anz);



        // Bestimmen Maximalbereich (Nur bei Intervall von 2 bis ...)
        if(voninter==2 && bispos>=(hebbuchlng-1))
        {
            status=sortListeIntervall(0, "interlst.zwi", "interlst.zwi");
            if(status>0)
                return status;
            status=ermittleMinimalbereich("interlst.min", "interlst.zwi");
            if(status>0)
                return status;

            // Sortieren Liste lt. Vorgabe
            if(sortier!=0)
                status=sortListeIntervall(sortier,"interlst.min","interlst.min");
            if(status>0)
                return status;
        }
        else
        {
            status=sortListeIntervall(sortier,"interlst.zwi", "interlst.zwi");
            if(status>0)
                return status;
            rename("interlst.zwi","interlst.min");    // Datei in min umbenennen
        }

    }

    // Oeffnen Ausgabedatei
    verz=out_verz;
    verz.append(datei);
    fdatei=fopen(verz.c_str(),"w+b");
    if(fdatei==NULL)
        return 13;

    // Daten fuer Listenkopf zusammenstellen
    string zwtxt;
    char zwsp[15];
    int bpos;
    int binter;

    // Bisposition pruefen
    if(bispos>hebbuchlng-1)
        bpos=hebbuchlng-1;
    else
        bpos=bispos;

    // Bis Intervall pruefen
    binter=bpos-vonpos;             // Suchbereich
    binter=binter/(wort.size()-1);  // Maxintervall
    if(binter>bisinter)
        binter=bisinter;

    status=posKap(buch,bpos);   // Bis Kapitel/Vers fuer Listenkopf
    if(status)
        return status;
    zwtxt=kap_vers;
    status=posKap(buch,vonpos); // Von Kapitel/Vers fuer Listenkopf
    if(status)
        return status;

    // Listenparameter schreiben
    string zeile="\a21\t1\t";
    zeile.append(buch);
    zeile.append("\t");
    zeile.append(wort);
    zeile.append("\t\t\t");     // Wort 2-3 leer
    zeile.append(kap_vers);     // Von Position
    zeile.append("\t");
    zeile.append(zwtxt);        // Bis Position
    zeile.append("\t");
    sprintf(zwsp,"% d",voninter);
    zeile.append(zwsp);         // Von Intervall
    zeile.append("\t");
    sprintf(zwsp,"% d",binter); // Bis Intervall
    zeile.append(zwsp);
    zeile.append("\t");
    zeile.append(datei);
    zeile.append("\n");
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

    // Listenkopf schreiben
    char cbuch[15];
    strcpy(cbuch,buch.c_str());           // Buchnamen in Grossbuchstaben
    for(unsigned int i=0;i<strlen(cbuch);i++)
        cbuch[i]=toupper(cbuch[i]);

    zeile="Intervallliste zum Wort ";
    zeile.append(wort);
    zeile.append(" im Buch ");
    zeile.append(cbuch);
    zeile.append("\n");

    zeile.append(" von Kapitel:Vers ");
    zeile.append(kap_vers);
    zeile.append(" bis ");
    zeile.append(zwtxt);
    zeile.append("\n     \n");
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

    zeile="Fuer Intervallbereich von ";
    sprintf(zwsp,"% d",voninter);
    zeile.append(zwsp);
    zeile.append(" bis ");
    sprintf(zwsp,"% d",binter);
    zeile.append(zwsp);
    if(richtung==0)
        zeile.append(" Vorwaerts und Rueckwaerts");
    if(richtung==1)
        zeile.append(" Vorwaerts");
    if(richtung==2)
        zeile.append(" Rueckwaerts");
    zeile.append("\n");
    zeile.append(" wurden ");

    if(maxanz)
        zeile.append("keine Intervalle gesucht");
    else
    {
        sprintf(zwsp,"% d",anz);
        zeile.append(zwsp);
        zeile.append(" Intervalle gefunden");
    }
    zeile.append("\n");

    if(erwart)
    {
        zeile.append(" Die statistische Erwartung ist");
        sprintf(zwsp,"% .2f",erw);
        zeile.append(zwsp);
        zeile.append(" Intervalle");
        zeile.append("\n");
    }

    if(redu)
    {
        zeile.append(" Der Intervallbereich (von/bis Intervallweite) wurde reduziert\n");
        zeile.append(" Es sind nur 2000 Intervalle in der Liste zulaesig\n");
    }
    zeile.append("   \n");
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

    if(!maxanz)
    {
        zeile="\blrclclc";
        if(voninter==2 && bispos>=(hebbuchlng-1))
            zeile.append("rrr");
        zeile.append("\n");
        fwrite(zeile.c_str(),1,zeile.length(),fdatei);

        // Listen-Spalten-Ueberschrift
        zeile="lfd Nr.\tIntervall\tVonpos\tKap/Vers\tBispos\tKap/Vers\tRicht.";
        if(voninter==2 && bispos>=(hebbuchlng-1))
            zeile.append("\t %\tBeginn\tEnde Maximalbereich");
        zeile.append("\n");
        fwrite(zeile.c_str(),1,zeile.length(),fdatei);


        // Oeffnen Eingabedatei
        verz=tmp_verz;
        if(voninter==2 && bispos>=(hebbuchlng-1))
            verz.append("interlst.min");
        else
            verz.append("interlst.zwi");
        fein=fopen(verz.c_str(),"rb");
        if(fein==NULL)
            return 14;

        UNIINTER ein;

        // Daten einlesen und Liste ausgeben
        rewind(fein);
        fread(ein.c,1,sizeof(STRINTER),fein);
        int lfd=1;
        int ok=0;
        while(!feof(fein))
        {
            sprintf(zwsp,"% d",lfd);
            zeile=zwsp;
            zeile.append("\t");
            sprintf(zwsp,"% d",ein.s.inter);
            zeile.append(zwsp);
            zeile.append("\t");
            sprintf(zwsp,"% d",ein.s.apos);
            zeile.append(zwsp);
            zeile.append("\t");
            //  zeile.append("(");
            ok=posKap(buch,ein.s.apos);
            zeile.append(kap_vers);
            //  zeile.append(")");
            zeile.append("\t");
            sprintf(zwsp,"% d",ein.s.epos);
            zeile.append(zwsp);
            zeile.append("\t");
            //  zeile.append("(");
            ok=posKap(buch,ein.s.epos);
            zeile.append(kap_vers);
            //  zeile.append(")");
            zeile.append("\t");
            if(ein.s.richt==0)
                zeile.append("V");
            else
                zeile.append("R");
            if(voninter==2)
            {
                zeile.append("\t");
                sprintf(zwsp,"% d",ein.s.proz);
                zeile.append(zwsp);
                zeile.append("\t");
                sprintf(zwsp,"% d",ein.s.aber);
                zeile.append(zwsp);
                zeile.append("\t");
                sprintf(zwsp,"% d",ein.s.eber);
                zeile.append(zwsp);
            }
            zeile.append("\n");
            fwrite(zeile.c_str(),1,zeile.length(),fdatei);
            fread(ein.c,1,sizeof(STRINTER),fein);
            lfd++;
        }
        fclose(fein);
    }
    fclose(fdatei);

    return 0;
}
/**********************************************************************/
int CIntervall::listeIntervallBlock(string buch, string wort,
                                    int vpos, int bpos,
                                    int blk, int ianz,
                                    bool mod,
                                    string datei)
{
    int anz=0;
    string uwort=textUmkehr(wort);

    anz=suchBlock(buch, wort, vpos, bpos, blk, ianz, mod, "interblk.zwi");
    if(anz<-1)
        return abs(anz);

    // Oeffnen Ausgabedatei
    FILE *fdatei;
    string verz=out_verz;
    verz.append(datei);
    fdatei=fopen(verz.c_str(),"w+b");
    if(fdatei==NULL)
        return 13;

    // Daten fuer Listenkopf zusammenstellen
    string zwtxt;
    char zwsp[15];
    char cbuch[15];
    strcpy(cbuch,buch.c_str());                // Buchnamen in Grossbuchstaben
    for(unsigned int i=0;i<strlen(cbuch);i++)
        cbuch[i]=toupper(cbuch[i]);

    // Listenparameter schreiben
    if(bpos>=hebbuchlng)
        bpos=hebbuchlng-1;
    int status=posKap(buch,bpos);   // Bis Kapitel/Vers fuer Listenkopf
    if(status)
        return status;
    zwtxt=kap_vers;
    status=posKap(buch,vpos); // Von Kapitel/Vers fuer Listenkopf
    if(status)
        return status;

    string zeile="\a22\t1\t";
    zeile.append(buch);
    zeile.append("\t");
    zeile.append(wort);
    zeile.append("\t\t\t");     // Wort 2-3 leer
    zeile.append(kap_vers);     // Von Position
    zeile.append("\t");
    zeile.append(zwtxt);        // Bis Position
    zeile.append("\t");
    zeile.append("\t");         // Von Intervall
    zeile.append("\t");         // Bis Intervall
    zeile.append(datei);        // Ausgabedatei
    zeile.append("\n");
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

    // Listenkopf schreiben
    zeile="Blockliste zum Wort ";
    zeile.append(wort);
    zeile.append(" im Buch ");
    zeile.append(cbuch);
    zeile.append("\n");
    zeile.append("bis zur Intervallweite ");
    sprintf(zwsp,"% d",ianz);
    zeile.append(zwsp);
    zeile.append("\n \n");

    if(blk!=0 )
    {
        zeile.append("Intervallbloecke bei Blocklaenge ist durch ");
        sprintf(zwsp,"% d",blk);
        zeile.append(zwsp);
        zeile.append(" teilbar\n");
    }
    else
        zeile.append("keine Blockselektion, alle Bloecke ausgewiesen\n");

    zeile.append("Es wurden ");
    if(anz>0)
    {
        sprintf(zwsp,"% d",anz);
        zeile.append(zwsp);
    }
    else
    {
        zeile.append("keine ");
    }
    zeile.append(" Bloecke gefunden");
    zeile.append("\n");
   
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

//     zeile="\blrrrrrrrr\n";
    zeile="\blrrrrrr\n";
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

    // Listen-Spalten-Ueberschrift
    zeile="lfd Nr.\tInterv.\tVonpos\tKap/Vers\tBispos\tKap/Vers\tBlocklaeng";
//    zeile.append("\tAnzInterv.\tRest");
    zeile.append("\n");
    fwrite(zeile.c_str(),1,zeile.length(),fdatei);

    if(anz<=0)
    {
        fclose(fdatei);
        return 0;                      // Keine Bl�cke
    }

    // Oeffnen Eingabedatei
    FILE *fein;
    verz=tmp_verz;
    verz.append("interblk.zwi");
    fein=fopen(verz.c_str(),"r");
    if(fein==NULL)
        return 14;

    UNIBLOCK ein;

    // Daten einlesen und Liste ausgeben
    rewind(fein);
    fread(ein.c,1,sizeof(STRBLOCK),fein);
    int lfd=1;
    while(!feof(fein))
    {
        sprintf(zwsp,"% d",lfd);
        zeile=zwsp;
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.inter);
        zeile.append(zwsp);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.apos);
        zeile.append(zwsp);
        zeile.append("\t");
        status=posKap(buch,ein.s.apos);
        zeile.append(kap_vers);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.epos);
        zeile.append(zwsp);
        zeile.append("\t");
        status=posKap(buch,ein.s.epos);
        zeile.append(kap_vers);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.banz);
        zeile.append(zwsp);
/*
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.trest);
        zeile.append(zwsp);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.idiv);
        zeile.append(zwsp);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.irest);
        zeile.append(zwsp);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.qdiv);
        zeile.append(zwsp);
        zeile.append("\t");
        sprintf(zwsp,"% d",ein.s.qrest);
        zeile.append(zwsp);
*/
        zeile.append("\n");
        fwrite(zeile.c_str(),1,zeile.length(),fdatei);
        fread(ein.c,1,sizeof(STRBLOCK),fein);
        lfd++;
    }

    fclose(fein);
    fclose(fdatei);

    return 0;
}
