/***************************************************************************
                          cintervall.h  -  description
                             -------------------
    begin                : Sun Oct 14 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CINTERVALL_H
#define CINTERVALL_H

#include "cbuchindex.h"

using namespace std;

//! Listen zur Intervallanalyse im Bibeltext

/*!
  *@author Heinz Schumann
  */

class CIntervall : public CBuchIndex {
public: 
	CIntervall();
	~CIntervall();
//! Liste der gefundenen Intervalle
/*!
   Es wird eine Intervallliste erzeugt und als Datei ausgegeben. Der Defaultname
   fuer die Liste ist "interval.bta"
   Rueckgabewert ist 0, bei Fehler der Fehlercode.
   \param string buch  (Bibelbuch)
   \param string wort  (Suchwort (hebr.))
   \param int vonIntervall (Beginn Intervallbereich, default = 2)
   \param int bisIntervall (Ende Intervallbereich, default = maximal = 999999)
   \param int vonPosition (Start Suchbereich, default = 0)
   \param int bisPosition (Ende Suchbereich, default = Buchende = 999999)
   \param int Intervallrichtung (default = 0 = Vor- und Rueckwaerts, 1 = Vorwaerts, 2 = Rueckwaerts)
   \param int Sortierung (default = 0 = N.Intervall, 1 = Position, 2 = Prozent Maximalbereich)
   \param bool Bibeltext modifizieren (default = true \sa CBuchHeb::modifiBuch)
   \param bool Erwartungswert in Liste (default = true \sa CBuchHeb::intervallErwartung)
   \param string datei Name der Ausgabedatei (default = interval.bta")
   \brief Erstellen einer Intervallliste
  */
  int listeIntervall(string buch, string wort,
                     int voninter,
                     int bisinter,
                     int vonpos,
                     int bispos,
                     int richtung, int sortier,
                     bool modifi,
                     bool erwart,
                     string datei);

//!  Methode zum Auffinden von Intervallbloecken
/*! Die Methode sucht im Buch anhand der Intervalle zum einem Wort
    Intervallbloecke auf. Ein Intervallblock ist ein Textabschnitt der
    mit einem Intervall (z.B. Vorwaerst) beginnt und zum gleichen Wort und
    gleicher Intervallweite aber in umgekehrter Intervallrichtung
    (z.B. Rueckwaerts) endet. Es wird eine Datei (default ="interblk.bta") mit
    der Datenstruktur STRBLOCK erzeugt.\n
    Rueckgabewert ist die Anzahl der gefundenen Bloecke. Bei Fehler
    ist der Rueckgabewert die negative Fehlernummer.\n
    Mit dem Parameter Divisor werden Bloecke selektiert bei denen die Anzahl
    der Buchstaben im Block durch den Divisor ohne Rest teilbar ist. Ist der
    Parameter Null wird keine Selektion durchgefuehrt und alle gefundenen Bloecke
    werden ausgegeben.\n
    Mit dem Parameter Anzahl Intervalle wird die Mindestanzahl der
    Intervalle bestimmt welche Untersucht werden sollen\n
    \param string Bibelbuch
    \param string Hebr. Wort
    \param int vonPosition (Start Suchbereich, default = 0)
    \param int bisPosition (Ende Suchbereich, default = Buchende = 999999)
    \param int Divisor (default = 0) (eingetragen im Feld vonInter)
    \param int Anzahl Intervalle. (default = 1000)
    \param bool  Bibeltext modifizieren (default = true \sa CBuchHeb::modifiBuch) 
    \param string Datei Name der Ausgabedatei (default = "interblk.bta")
    \brief Intervallbloecke suchen

*/
int listeIntervallBlock(string buch, string wort,
                        int vpos, int bpos,
                        int blk, int ianz,
                        bool mod,
                        string datei);
};

#endif
