/***************************************************************************
                          CKernInterface.cpp  -  description
                             -------------------
    begin                : Wed Oct 17 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "ckerninterface.h"
#include "cbibeltext.h"
#include "cintervall.h"

#include <iostream>
using namespace std;

CKernInterface::CKernInterface()
{
  bearbart=21;
  bearbalt=9999;
  buch="genesis";
  wrtbu=0;
}
CKernInterface::~CKernInterface()
{}

int CKernInterface::lesBibelAbschnitt(string buch,
                                      int vkap, int vvers,
                                      int bkap, int bvers,
                                      string datei,
                                      string sprache)
{
  ladeKernroutine(1);
  int status = bt->bibelAbschnitt(buch, vkap, vvers, bkap, bvers, sprache, datei);
  return status;
}

int CKernInterface::lesBibelAbschnittAnalyse(string buch, int vkap, int vvers,
    int bkap, int bvers,
    string datei)
{
  int status;
  if(vkap==0 && bkap==0)
  {
   status=test(vvers,bvers);
   return status;
  }
  ladeKernroutine(1);
  status = bt->bibelAbschnittAnalyse(buch, vkap, vvers, bkap, bvers, datei);
  return status;
}


int CKernInterface::lesListeIntervall(string buch, string wort,
                                      int voninter,
                                      int bisinter,
                                      int vonpos,
                                      int bispos,
                                      int richtung, int sortier,
                                      bool modifi,
                                      bool erwart,
                                      string datei)
{
  ladeKernroutine(2);
  int status = in->listeIntervall(buch, wort,
                                  voninter,bisinter,
                                  vonpos,bispos,
                                  richtung, sortier,
                                  modifi,
                                  erwart,
                                  datei);
  return status;
}

int CKernInterface::lesListeIntervallBlock(string buch, string wort,
    int vpos, int bpos,
    int blk, int ianz,
    bool mod,
    string datei)
{
  ladeKernroutine(2);
  int status = in->listeIntervallBlock(buch, wort,
                                       vpos,bpos,
                                       blk, ianz,
                                       mod,
                                       datei);
  return status;
}

int CKernInterface::lesLesIntervall(string buch, int intervall,
                                    int zeilenbreite,
                                    int vpos, int bpos,
                                    string datei,
                                    bool modifi)
{
  ladeKernroutine(2);
  int status = in->lesIntervall(buch,
                                intervall,
                                zeilenbreite,
                                vpos, bpos,
                                datei,
                                modifi);
  return status;
}
int CKernInterface::lesPruefNachbar(string buch, string wo1, string wo2, string wo3,
                                    bool in1,
                                    bool mod,
                                    int zlnr,
                                    string outdatei1,
                                    string outdatei2)
{
  ladeKernroutine(3);
  int status = nb->pruefNachbar(buch, wo1, wo2, wo3,
                                in1,
                                mod,
                                zlnr,
                                outdatei1,
                                outdatei2);
  return status;
}

int CKernInterface::lesFindNachbar(string buch, string wort, int intervall, int pos,
                                   string outdatei1,
                                   string outdatei2,
                                   string wrtbuch)
{
  ladeKernroutine(3);
  int status = nb->findNachbar(buch, wort, intervall, pos,
                               0,100,
                               outdatei1,
                               outdatei2,
                               wrtbuch);
  return status;
}

int CKernInterface::lesSuchNachbar(string buch, string wort,
                                   string outdatei,
                                   string wrtbuch)
{
  ladeKernroutine(3);
  int status = nb->suchNachbar(buch, wort,
                               -32,-6,
                               outdatei,
                               wrtbuch);
  return status;
}

int CKernInterface::lesSuchMatrix(string buch, string worte, bool in1, bool mod, string datei)
{
  ladeKernroutine(4);
  int status = ma->suchMatrix(buch,
                              worte,
                              in1,
                              mod,
                              datei);
  return status;
}

int CKernInterface::lesHebWort(string wort)
{
  int status=0;
  ladeKernroutine(5);
  if(wrtbu!=1) status = wb->openWortBuch(ebuch_verz,"kuhebdeu.lex",true);
  if(status!=0) return status;
  wrtbu=1;
  status = wb->findWort(wort);
  if(status<2)
  {
    whebwort=wb->strwrb.hebwrb;
    wdeuwort=wb->strwrb.deuwrb;
  }
  return status;
}

int CKernInterface::lesDeuWort(string wort)
{
  int status=0;
  ladeKernroutine(5);
  if(wrtbu!=2) status = wb->openWortBuch(ebuch_verz,"kudeuheb.lex",false);
  if(status!=0) return status;
  wrtbu=2;
  status = wb->findWort(wort);
  if(status<2)
  {
    whebwort=wb->strwrb.hebwrb;
    wdeuwort=wb->strwrb.deuwrb;
  }
  return status;
}

long CKernInterface::lesKapBegPos(string buch, int kap, int vers)
{
  ladeKernroutine(9);
  int status = po->kapPos(buch, kap, vers);
  if(status!=0) return status*-1;
  return po->kapvpos;
}

long CKernInterface::lesKapEndPos(string buch, int kap, int vers)
{
  ladeKernroutine(9);
  int status = po->kapPos(buch, kap, vers);
  if(status!=0) return status*-1;
  return po->kapbpos;
}

string CKernInterface::lesPosKap(string buch, int pos)
{
  ladeKernroutine(9);
  int status = po->posKap(buch, pos);
  if(status!=0) return "1";
  return po->kap_vers;
}

int CKernInterface::lesProgressStatus()
{
  int soll;
  int ist;
  switch (bearbalt)
  {
      case 1: soll=bt->progstep;
      ist=bt->progstat;
      break;
      case 2: soll=in->progstep;
      ist=in->progstat;
      break;
      case 3: soll=nb->progstep;
      ist=nb->progstat;
      break;
      case 4: soll=ma->progstep;
      ist=ma->progstat;
      break;
      case 9: soll=po->progstep;
      ist=po->progstat;
      break;
  }
  return (ist*100)/soll;
}

void CKernInterface::ladeKernroutine(int art)
{
  if(bearbalt!=art)           // Wechsel Objektaufruf
  {
    if(bearbalt!=9999)        // Alte Instanz loeschen
    {
      switch (bearbalt)
      {
          case 1: delete bt; break;
          case 2: delete in; break;
          case 3: delete nb; break;
          case 4: delete ma; break;
          case 5: delete wb; break;
          case 9: delete po; break;
      }
    }
  }
  bearbalt=art;
  switch (bearbalt)       // Neue Instanz herstellen
  {
      case 1: bt = new(CBibeltext);
      bt->setzBasVerzeichnis(ebasis_verz);
      bt->setzBasBuchVerzeichnis(ebuch_verz);
      bt->setzBasOutVerzeichnis(eout_verz);
      bt->progstep=100;
      bt->progstat=1;
      bt->loeschHebBuch();
      break;
      case 2: in = new(CIntervall);
      in->setzBasVerzeichnis(ebasis_verz);
      in->setzBasBuchVerzeichnis(ebuch_verz);
      in->setzBasOutVerzeichnis(eout_verz);
      in->progstep=100;
      in->progstat=1;
      in->loeschHebBuch();
      break;
      case 3: nb = new(CNbrListen);
      nb->setzBasVerzeichnis(ebasis_verz);
      nb->setzBasBuchVerzeichnis(ebuch_verz);
      nb->setzBasOutVerzeichnis(eout_verz);
      nb->progstep=100;
      nb->progstat=1;
      nb->loeschHebBuch();
      break;
      case 4: ma = new(CMatrix);
      ma->setzBasVerzeichnis(ebasis_verz);
      ma->setzBasBuchVerzeichnis(ebuch_verz);
      ma->setzBasOutVerzeichnis(eout_verz);
      ma->progstep=100;
      ma->progstat=1;
      ma->loeschHebBuch();
      break;
      case 5: wb = new(CWortBuch);
//      wb->setzBasVerzeichnis(ebasis_verz);
//      wb->setzBasBuchVerzeichnis(ebuch_verz);
//      wb->setzBasOutVerzeichnis(eout_verz);
//      wb->loeschHebBuch();
      wrtbu=0;
      break;
      case 9: po = new(CBuchIndex);
      po->setzBasVerzeichnis(ebasis_verz);
      po->setzBasBuchVerzeichnis(ebuch_verz);
      po->setzBasOutVerzeichnis(eout_verz);
      po->progstep=100;
      po->progstat=1;
      po->loeschHebBuch();
      break;
  }
}

// Testroutinen zum testen der Kernbausteine
int CKernInterface::test(int vnr,int bnr)
{
  string wo1, wo2, wo3;
  int status=0;

  if(vnr<2 && bnr>0)          // 1 = Anzeigen Bibelabschnitt
  {
    status=lesBibelAbschnitt("exodus",1,1,1,5,"anz_kerntestabschn.bta","de");
    cout <<"Liste 1"<< "status: " << status << " anz_kerntestabschn.bta - erzeugt" << endl;
  }

  if(vnr<3 && bnr>1)         // 2 = Anzeigen Bibelabschnittanalyse
  {
    status=lesBibelAbschnittAnalyse("exodus",1,1,1,5,"anz_kerntestgem1.bta");
    cout <<"Liste 2"<< "status: " << status << " anz_kerntestgem1.bta - erzeugt" << endl;
  }

  if(vnr<4 && bnr>2)      // 3 = Intervallliste 1 bis 3
  {
    // Wort Aaron
    wo1=-32;
    wo1+=-28;
    wo1+=-8;
    wo1+=-16;
    // Wort Israel
    wo2=-20;
    wo2+=-32;
    wo2+=-8;
    wo2+=-7;
    wo2+=-23;
    // Wort Zins
    wo3=-8;
    wo3+=-31;
    wo3+=-23;
    wo3+=-6;

    status=lesListeIntervall("leviticus",wo1,2,1000,0,715,0,1,true,true,"itv_kerntestinter1.bta");
    cout <<"Liste 3.1"<< "status: " << status << " itv_kerntestinter1.bta - erzeugt" << endl;

    status=lesListeIntervall("genesis",wo2,2,1000,0,999999,1,0,true,true,"itv_kerntestinter2.bta");
    cout <<"Liste 3.2"<< "status: " << status << " itv_kerntestinter2.bta - erzeugt" << endl;

    status=lesListeIntervall("genesis",wo3,2,1000,0,999999,0,0,true,true,"itv_kerntestinter3.bta");
    cout <<"Liste 3.3"<< "status: " << status << " itv_kerntestinter3.bta - erzeugt" << endl;
  }

  if(vnr<5 && bnr>3)      // 4 = Intervallblockliste 1 und 2
  {
    // Wort Israel
    wo1=-20;
    wo1+=-32;
    wo1+=-8;
    wo1+=-7;
    wo1+=-23;
    // Wort Zins
    wo2=-8;
    wo2+=-31;
    wo2+=-23;
    wo2+=-6;

    status=lesListeIntervallBlock("genesis",wo1,0,999999,0,200,true,"itv_kerntestblock1.bta");
    cout <<"Liste 4.1"<< "status: " << status << " itv_kerntestblock1.bta - erzeugt" << endl;

    status=lesListeIntervallBlock("genesis",wo2,0,999999,0,1000,true,"itv_kerntestblock2.bta");
    cout <<"Liste 4.2"<< "status: " << status << " itv_kerntestblock2.bta - erzeugt" << endl;
  }

  if(vnr<6 && bnr>4)       // 5 = pruefen Nachbarschaft 
  {
    // Hammer
    wo1=-7;
    wo1+=-23;
    wo1+=-24;
    wo1+=-13;
    // Ambos
    wo2=-17;
    wo2+=-29;
    wo2+=-15;
    // Wort Leer
    wo3="";


    status=lesPruefNachbar("genesis",wo1,wo2,wo3,false,true,1,"nbr_kerntestprdat1.bta","nbr_kerntestprbld1.bta");
    cout <<"Liste 5.1"<< "status: " << status << " nbr_kerntestprdat1.bta - erzeugt" << endl;
    cout <<"Liste 5.1"<< "status: " << status << " nbr_klerntesprtbld1.bta - erzeugt" << endl;

    // Chanukka
    wo1=-28;
    wo1+=-22;
    wo1+=-27;
    wo1+=-17;
    wo1+=-25;
    wo1+=-28;
    // Hasmonaeder
    wo2=-23;
    wo2+=-32;
    wo2+=-17;
    wo2+=-27;
    wo2+=-19;
    wo2+=-7;
    wo2+=-25;

    status=lesPruefNachbar("genesis",wo1,wo2,wo3,false,true,1,"nbr_kerntestprdat2.bta","nbr_kerntestprbld2.bta");
    cout <<"Liste 5.2"<< "status: " << status << " nbr_kerntestprdat2.bta - erzeugt" << endl;
    cout <<"Liste 5.2"<< "status: " << status << " nbr_klerntestprbld2.bta - erzeugt" << endl;

  }

  if(vnr<7 && bnr>5)       // 6 = finden Nachbarschaft
  {
    // Wort Zins
    wo1=-8;
    wo1+=-31;
    wo1+=-23;
    wo1+=-6;

    status=lesFindNachbar("genesis",wo1,2,4737,"wrt_kerntestfinddat.bta","wrt_kerntestfindbld.bta","kuhebdeu.lex");
    cout <<"Liste 6"<< "status: " << status << " wrt_kerntestfinddat.bta - erzeugt" << endl;
    cout <<"Liste 6"<< "status: " << status << " wrt_kerntestfindbld.bta - erzeugt" << endl;
  }


  if(vnr<8 && bnr>6)      // 7 = suchen Nachbarschaft
  {
    // Wort Zins
    wo1=-8;
    wo1+=-31;
    wo1+=-23;
    wo1+=-6;
    status=lesSuchNachbar("genesis",wo1,"nbr_kerntestsuchdat.bta","kuhebdeu.lex");
    cout <<"Liste 7"<< "status: " << status << " nbr_kerntestsuchdat.bta - erzeugt" << endl;
  }

  if(vnr<9 && bnr>7)      // 8 = suchen Matrix (benoetigt Buch Torah)
  {
    // Wortgruppe
    wo1=-28;
    wo1+=-6;
    wo1+=-32;
    wo1+=-27;
    wo1+=-18;
    wo1+=-23;
    wo1+=-18;
    wo1+='\t';
    wo1+=-18;
    wo1+=-30;
    wo1+=-29;
    wo1+=-20;
    wo1+=-23;
    wo1+='\t';
    wo1+=-28;
    wo1+=-12;
    wo1+=-23;
    wo1+=-20;
    wo1+='\t';
    wo1+=-18;
    wo1+=-24;
    wo1+=-27;
    wo1+=-15;
    wo1+='\t';
    wo1+=-12;
    wo1+=-14;
    wo1+=-18;
    wo1+=-23;
    wo1+=-18;
    wo1+='\t';
    wo1+=-20;
    wo1+=-18;
    wo1+=-27;
    wo1+=-6;
    wo1+=-7;
    wo1+=-18;
    wo1+='\t';
    wo1+=-27;
    wo1+=-23;
    wo1+=-21;
    wo1+='\t';
    status=lesSuchMatrix("torah",wo1,true,false,"wrt_kerntestsuchmatrix.bta");
    cout <<"Liste 8"<< "status: " << status << " wrt_kerntestsuchmatrix.bta - erzeugt" << endl;
  }
if(vnr<10 && bnr>8)      // 9 = Intervallesen
  {
   
    status=lesLesIntervall("genesis",50,8,5,10000,"anz_kerntestlesint.bta",false);
    cout <<"Liste 9"<< "status: " << status << " anz_kerntestlesint.bta - erzeugt" << endl;
  }
  cout << "fertig" << endl;
  return status;
}
/*****************************************************************************/
/* Fehlertexte ausgeben */
string CKernInterface::lesFehlertext(int fid)
{

  switch (fid)
  {
      case 0:
      return("Bearbeitung ohne Fehler");

      case 3:
      return("Bearbeitung abgebrochen mit Fehlermeldung in der Listausgabe");

      case 11:
      return("Verzeichniss oder Datei *.idx nicht gefunden");

      case 12:
      return("Verzeichniss oder Datei *.cod nicht gefunden");

      case 13:
      return("Tmp-Verzeichnis nicht gefunden");

      case 14:
      return("Interne Zwischendatei nicht gefunden");

      case 15:
      return("Verzeichnis oder Wortbuchdatei nicht gefunden");

      case 16:
      return("Verzeichniss oder Deutsch-Bibelbuch *.txt nicht gefunden");

      case 21:
      return("Positionsvorgabe von-bis unzulaessig");

      case 22:
      return("Kapitel-Versvorgabe unzulaessig");

      case 23:
      return("Buchende erreicht (bei nextVers)");

      case 24:
      return("Intervallbereichsvorgabe unzulaessig");

      case 25:
      return("Suchwort zu kurz (min = 3 Buchstaben)");

      case 31:
      return("Abbruch durch den Benutzer");
      
      default:
      return("Fehler-ID nicht bekannt");
  }
}

/******************************************************************
  Setzen und lesen allgemeine Variablen
******************************************************************/
void CKernInterface::setzTempVerzeichnis(string v)
{
  ebasis_verz=v;
}

void CKernInterface::setzBasisVerzeichnis(string v)
{
  ebasis_verz=v;
}

void CKernInterface::setzBuchVerzeichnis(string b)
{
  ebuch_verz=b;
}

void CKernInterface::setzOutVerzeichnis(string b)
{
  eout_verz=b;
}

