/***************************************************************************
                          CKernInterface.h  -  description
                             -------------------
    begin                : Wed Oct 17 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CKERNINTERFACE_H
#define CKERNINTERFACE_H

//! Schnittstelle zum Bitana-Kern (Beschreibung der Schnittstellen-Funktion)
/*!
 
   *@author Heinz Schumann
   *email kontakt@heinz-schumann.de
   
  Die Klasse bietet die Schnittstelle mit ihren Funktionen zum Bitanakern
 
  Bei Eroeffnung des Programm muss die Verzeichnissstruktur ueber die Funktionen
  'setBasisVerzeichniss', 'setBuchVerzeichniss' und 'setOutVerzeichniss'
  eingestellt werden
 
  Vor Start einer Bearbeitung muessen vom Benutzer alle fuer die Bearbeitungsart 
  relevanten Daten bereitgestellt sein, sofern die durch default eingestellten
  Werte nicht ausreichend sind.
 
  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
  Bearbeitungsarten  (default = Intervallliste)
 
  -------------------------------------------------------------------------
 
  1 Liste mit Bibelabschnitt in zwei Sprachen
 
  2 Liste mit Gematria eines Bibelabschnittes
 
  3 Intervallliste erstellen
 
  4 Intervallblockliste erstellen
 
  5 Nachbarschaft zwischen Woertern pruefen (wahlweise mit Textabbildung)
 
  6 Textabbildung mit Nachbarschaftswoertern, mithilfe des Lexikons gefunden
 
  7 Nachbarschaften zu einem Wort mithilfe des Lexikons suchen
 
  8 Umrechnung einer Kap/Versangabe in Position
 
  9 Umrechnung einer Positionsvorgabe in Kap/Vers
  
  10 Umrechnen einer Jahreszahl in den hebr. Kalender
 
  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
  Der Aufruf einer Funktion laesst den Bearbeitungsvorgang aus und liefert
  mit seinem Rueckkehrcode die Information ueber den Verlauf der Bearbeitung.
  Der Rueckkehrcode ist bei fehlerfreiem Verlauf 0, ansonsten wird ein
  Fehlercode zurueckgegeben.
 
  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
  Fehlercodes
 
  ---------------------------------------------------------------------------
 
  3  Bearbeitung abgebrochen mit Fehlermeldung in der Listausgabe
 
  11 Verzeichniss oder Datei "*.idx" nicht gefunden
 
  12 Verzeichniss oder Datei "*.cod" nicht gefunden
 
  13 Tmp-Verzeichnis nicht gefunden
 
  14 Interne Zwischendatei nicht gefunden
  
  15 Verzeichnis oder Wortbuch-Datei nicht gefunden
 
  16 Verzeichniss oder Deutsch-Bibelbuch nicht gefunden
 
  21 Positionsvorgabe von-bis unzulaessig
 
  22 Kapitel-Versvorgabe unzulaessig
 
  23 Buchende erreicht (bei nextVers)
 
  24 Intervallbereichsvorgabe unzulaessig
 
  25 Wortlaenge bei Intervallsuche unzulaessig (min = 3 Buchstaben)

  26 Fehlerhafte Worteingabe bei Nachbarpruefung
  
  31 Abbruch durch den Benutzer
 
  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
  Viele Ausgaben des BITANA-Objektes erfolgen in Dateien welche durch die
  Benutzeroberflaeche aufbereitet werden muessen. Zur Unterstuetzung der
  Aufbereitung sind die Dateien im Textformat und mit Steuerzeichen versehen.
 
  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
  Interne Steuerzeichen fuer Ausgabedateien der Objekte  (*.bta)
 
  --------------------------------------------------------------------------
 
  INT  HEX Compiler   Funktion
 
  6  '\006'      Unbedingter Seitenwechsel
 
  7  '\007' '\a' Direktausgabe Anfang
 
  8  '\010' '\b' Tabelle Anfang gefolgt von Aufbau Kopfzeile
 
  9  '\011' '\t' Tabulatorsprung Tabelle und Matrix
 
  10 '\012' '\n' Neue Zeile
 
  11 '\013' '\v' Hebr. Matix Begin gefolgt von Anzahl Buchstaben in einer Zeile
  
  12 '\014' '\f' Farbumschaltung gefolgt von Farbnummer
 
  27 '\036' '\e' Ende von Direktausgabe, Tabelle, Hebr. Matrix
 
  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
  Die den Berabeitungsarten zugeordneten Listen sind fest eingestellt. Eine evt.
  Umbenennung muss im Rahmen der Benutzeroberflaeche vorgenommen werden. Den
  Bearbeitungsarten sind folgende Listen zugeordnet:'eingabeBearbeiten'
 
  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  
  1 Liste mit Bibelabschnitt in zwei Sprachen  -> "bibabschn.bta"
 
  2 Liste mit Gematria eines Bibelabschnittes  -> "bibabana.bta"
 
  3 Intervallliste erstellen                   -> "interval.bta" 
 
  4 Intervallblockliste erstellen              -> "interblk.bta"
 
  5 Nachbarschaft zwischen Woertern pruefen      -> "datnbr.bta" und "flexnbr.bta" bzw "fixnbr.bta"
 
  6 Textabbildung mit gefundenen Nachbarschaftswoertern -> "txtabbld.bta" und "txtnbr.bta"
 
  7 Suchen von signifikanten Nachbarschaften   -> "suchnbr.bta"
 
  11
 
  12 
 
  21 
 
  22 
 
  31 
 
  32 
 
  33 
 
  */

#include <string>
#include "cbibeltext.h"
#include "cintervall.h"
#include "cnbrlisten.h"
#include "cmatrix.h"
#include "cwortbuch.h"

class CKernInterface
{
  public:
    CKernInterface();
    ~CKernInterface();
    /*********************************************************************************/
    /*!
      Funktion zum testen der Kernbausteine.  Über Gematria Kap 0 Vers 1 bis Kap 0 Vers 9
      Mit den beiden Variablen 'vnr' und 'bnr' wird
      aus den vorgegebenen Testbeispielen eine Gruppe Beispiele (von -> bis) bzw. ein
      Beispiel (von = bis) ausgewaehlt. Der Statuswert des letzten Beispiels wird zurueckgegeben.
      Testzuordnungen:
      1 = Anzeigen Bibelabschnitt (Exodus 1:1 1:5)
      2 = Bibelabschnittsanalyse (Exodus 1:1 1:5)
      3 = 3 Intervalllisten (Leviticus Aharon; Genesis Israel; Genesis Zins)
      4 = 2 Intervallblocklisten (Genesis Israel; Genesis Zins)
      5 = 2 Pruefen Nachbarschaft (Rips 1; Rips 3)
      6 = Finden Nachbarschaft (Genesis Zins)
      7 = Suchen Nachbarschaft (Genesis Zins)
      8 = Suchen Matrix (Torah Tuerme)
      9 = Intervalllesen (Genesis)
    */
    int test(int vnr, int bnr);
    /*********************************************************************************/
    /*!
     "lesBibelAbschnitt" erstellt eine Liste zu einem Bibelabschnitt
     
     Aus dem angegebenen Buch wird der vorgegebene Textabschnitt
     in der gewaehlten Sprache (Voreingestellt ist deutsch) dem
     Hebraeischtext gegenueber gestellt und in einer Liste
     ausgegeben (Voreingestellt ist "bibabschn.bta").
     Die Liste ist mit internen Steuerzeichen versehen und muss
     durch Objekte der Benutzeroberflaeche weiter bearbeitet werden.
     Der Rueckgabewert ist 0 bei Fehler der Fehlercode.
     \param string buch,    (Bibelbuch)
     \param int    vonKapitel,
     \param int    vonVers,
     \param int    bisKapitel,
     \param int    bisVers,
     \param string datei (default = "bibabsch.bta"),
     \param string sprache (default = "de" -> deutsch (en = englich nicht implementiert))
     \brief Listausgabe eines Bibelabschnittes in Versform
    */
    int lesBibelAbschnitt(string buch,
                          int vkap, int vvers,
                          int bkap, int bvers,
                          string datei="bibabsch.bta",
                          string sprache="de");
    /*********************************************************************************/
    /*!
       "lesBibelAbschnittAnalyse" erstellt eine Liste zur Gematria eines Bibelabschnittes
       
       Aus dem angegebenen Buch wird der vorgegebene hebr Textabschnitt
       aufgesucht und einer Textanalyse unterzogen. Das Ergebniss
       wird in einer Liste ausgegeben (Voreingestellt ist "bibabana.bta").
       Die Liste ist mit internen Steuerzeichen versehen und muss
       durch Objekte der Benutzeroberflaeche weiter bearbeitet werden.
       Der Rueckgabewert ist 0 bei Fehler der Fehlercode.
       \param string buch,  (Bibelbuch)
       \param int    vonKapitel
       \param int    vonVers
       \param int    bisKapitel
       \param int    bisVers
       \param string datei (default = "bibabana.bta")
       \brief Gematria Analyse eines Bibelabschnittes
           */

    int lesBibelAbschnittAnalyse(string buch,
                                 int vkap, int vvers,
                                 int bkap, int bvers,
                                 string datei="bibabana.bta");
    /***********************************************************************************/
    /*!
       "lesListeIntervall" Erstellen einer Intervallliste zu einem hebr Wort
       
       Es wird eine Intervallliste erzeugt und als Datei ausgegeben. Der Defaultname
       fuer die Liste ist "interval.bta"
       \param string buch  (Bibelbuch)
       \param string wort  (Suchwort (hebr.))
       \param int    vonIntervall (Beginn Intervallbereich, default = 2)
       \param int    bisIntervall (Ende Intervallbereich, default = maximal = 999999)
       \param int    vonPosition (Start Suchbereich, default = 0)
       \param int    bisPosition (Ende Suchbereich, default = Buchende = 999999)
       \param int    Intervallrichtung (default = 0 = Vor- und Rueckwaerts, 1 = Vorwaerts, 2 = Rueckwaerts)
       \param int    Sortierung (default = 0 = Intervall, 1 = Position, 2 = Prozent Maximalbereich)
       \param bool   Bibeltext modifizieren (default = true \sa CBuchHeb::modifiBuch)
       \param bool   Erwartungswert in Liste (default = true \sa CBuchHeb::intervallErwartung)
       \param string datei Name der Ausgabedatei (default = interval.bta")
       \brief Erstellen einer Intervallliste
      */
    int lesListeIntervall(string buch, string wort,
                          int voninter,
                          int bisinter,
                          int vonpos,
                          int bispos,
                          int richtung, int sortier,
                          bool modifi,
                          bool erwart,
                          string datei);
    /**********************************************************************************/
    /*! "lesListeIntervallBlock"  Methode zum Auffinden von Intervallbloecken
     
        Die Methode sucht im Buch anhand der Intervalle zum einem Wort
        Intervallbloecke auf. Ein Intervallblock ist ein Textabschnitt der
        mit einem Intervall (z.B. Vorwaerst) beginnt und zum gleichen Wort und
        gleicher Intervallweite aber in umgekehrter Intervallrichtung
        (z.B. Rueckwaerts) endet. Es wird eine Datei (default ="interblk.bta") mit
        der Datenstruktur STRBLOCK erzeugt.\n
        Rueckgabewert ist die Anzahl der gefundenen Bloecke. Bei Fehler
        ist der Rueckgabewert die negative Fehlernummer.\n
        Mit dem Parameter Divisor werden Bloecke selektiert bei denen die Anzahl
        der Buchstaben im Block durch den Divisor ohne Rest teilbar ist. Ist der
        Parameter Null wird keine Selektion durchgefuehrt und alle gefundenen Bloecke
        werden ausgegeben.\n
        Mit dem Parameter Anzahl Intervalle wird die Mindestanzahl der
        Intervalle bestimmt welche Untersucht werden sollen\n
        \param string Bibelbuch
        \param string Hebr. Wort
        \param int    vonPosition (Start Suchbereich, default = 0)
        \param int    bisPosition (Ende Suchbereich, default = Buchende = 999999)
        \param int    Divisor (default = 0) (eingetragen im Feld blk)
        \param int    Anzahl Intervalle. (default = 1000)
        \param bool   Bibeltext modifizieren (default = true \sa CBuchHeb::modifiBuch) 
        \param string Datei Name der Ausgabedatei (default = "interblk.bta")
        \brief Intervallbl�cke suchen
     
    */
    int lesListeIntervallBlock(string buch, string wort,
                               int vpos, int bpos,
                               int blk, int ianz,
                               bool mod,
                               string datei);
    /**********************************************************************************/
    /*!
      "lesPruefNachbar" Pruefen der Nachbarschaft zwischen Worten
      
      Prueft die Signifikanz einer Nachbarschaft zwischen max 3 Worten. Als Ergebniss
      werden zwei Listen erstellt. Liste "datnbr.bta" enthaellt die Ergebnisse von
      20 verschiedenen Gruppierungen der Worte im Text. Die zweite Liste kann in zwei
      verschiedenen Variantan angefordert werden. Einmal als Liste mit einer maximalen
      Zeilenbreite von 62 Zeichen und einer Zeilenanzahl von unter den Namen "fixnbr.bta" oder mit einer variablen
      Zeilenbrewite entsprechend der Anforderung unter dem Namen "flexnbr.bta".
      \param string Bibelbuch
      \param string heb. Wort1
      \param string heb. Wort2
      \param string heb. Wort3
      \param bool   mit Intervall 1 (default = false)
      \param bool   Text modifiziert (default = true)
      \param int    Zeilennummer als Basis fuer Nachbarschaftsabbildung (default = 1)
      \param string Name der Ausgabedatei 1 (Liste der Ergebnisse default= )
      \param string Name der Ausgabedatei 2 (Liste Textmatrix) 
      \brief Pr�fen einer Nachbarschaft
      */
    int lesPruefNachbar(string buch, string wo1, string wo2, string wo3,
                        bool in1,
                        bool mod,
                        int zlnr,
                        string outdatei1,
                        string outdatei2);
    /********************************************************************************/
    /*!
      "lesFindNachbar" Suche von Worten in der Textdarstellung zu einem Intervallwort
      
      Sucht in der Textdarstellung des Wortes mit hilfe des Woerterbuches
      nach Worten in der Nachbarschaft und gibt deren Position in der Liste 
      "txtnbr.bta"aus. Die zweite Liste "txtabbld.bta" ist die Darstellung der 
      Textmatrix in welcher die Nachbarschaftsworte gesucht wurden. Eine Pruefung 
      auf signifikanz wird nicht durchgefuehrt.Rueckgabewert ist die Anzahl der 
      gefundenen Worte. Bei Fehler ist der Rueckgabewert die negative Fehlernummer.
      
      \param string Bibelbuch
      \param string heb. Wort
      \param int    Intervall des Wortes
      \param int    Position des Wortes im Text
      \param string Ausgabedatei (default = "txtnbr.bta")
      \param string Eingabedatei (default = "txtabbld.bta")
      \param string Wortbuch (Default = "kudeuheb.lex")
      \brief Liste Textabbildung der Nachbarschaft
      */

    int lesFindNachbar(string buch, string wort, int intervall, int pos,
                       string outdatei1,
                       string outdatei2,
                       string wrtbuch);
    /**********************************************************************************/
    /*!
      "lesSuchNachbar" Suchen von signifikanten Nachbarschaften
      
      Sucht zu einem Wort signifikante Nachbarschaften mithilfe des Lexikon und der
      Nachbarschaftspruefung. Das Ergebniss wird in einer Datei "signbrls.bta"
      ausgegeben. Rueckgabewert ist die Anzahl der gefundenen Worte. Bei Fehler
      ist der Rueckgabewert die negative Fehlernummer.
      \param string Bibelbuch
      \param string Hebr. Wort
      \param string Name Ausgabedatei (default = "signbrls.bta")
      \param string Name Wortbuch     (default = "kudeuheb.lex") 
      \brief Nachbarschaften suchen
      */

    int lesSuchNachbar(string buch, string wort,
                       string outdatei,
                       string wrtbuch);
    /***********************************************************************************/
    /*!
     "lesSuchMatrix" Suchen einer Textmatrix
     
     Sucht zu einer Worttabelle im Bibeltext (default torah) nach einer Matrix in der 
     alle Worte enthalten sind. Die Worttabelle wird als String uebergeben in welchem 
     die einzelnen Worte mit "\t" enden muessen. 
     Bei Fehler ist der Rueckgabewert die Fehlernummer 
     \param string Bibelbuch
     \param string Worttabelle (max 10 Worte durch "\t" getrennt)
     \param bool   mit Intervall 1 (default = false)
     \param bool   Text Modifiziert (default = true)
     \param string Name Ausgabedatei
     */
    int lesSuchMatrix(string, string, bool, bool, string);
    /***********************************************************************************/
    /*!
       Liest den hebr. Text in Intervallschritten und stellt das Ergebniss in
       einer Datei bereit. Jede gelesene Zeile wird mit einem Zeilenende '\n'
       abgeschlossen. Rueckgabewert ist die Anzahl der geschriebenen Zeilen.
       \param string buch (Bibelbuch)
       \param int    Intervall (Zu lesende Intervallweite)
       \param int    Zeilenbreite (Zeilenbreite in welcher der Text geschrieben wird, default = 3)
       \param int    vonPosition  (Suchbeginn bei Textposition, default = 0)
       \param int    bisPosition  (Suchende bei Textposition, default = Buchende = 999999)
       \param string Name der Ausgabedatei (default = "intergrp.btn" 
       \param bool   Modifiziert (default = true)
       
       */
    int lesLesIntervall(string, int, int, int, int, string, bool);
    /***********************************************************************************/
    /*!
      "lesKapEndPos" Ermittlung der Positionswerte
       
      Es wird die Beginnposition zu einem Bibelvers ermittelt.
      Rueckgabewert ist die Position als long-Wert, bei Fehler der negative Fehlercode.
      \param string buch (bibelbuch)
      \param int    Kapitel
      \param int    Vers
      \brief Ermitteln der Startposition zu einem Bibelvers.
      */
    long lesKapBegPos(string buch, int kap, int vers);
    /**********************************************************************************/
    /*!
    "lesKapBegPos" Ermittlung der Positionswerte
     
    Es wird die Endposition zu einem Bibelvers ermittelt.
    Rueckgabewert ist die Position als long-Wert, bei Fehler der negative Fehlercode.
    \param string buch (bibelbuch)
    \param int    Kapitel
    \param int    Vers
    \brief Ermitteln der Endposition zu einem Bibelvers.
    */

    long lesKapEndPos(string buch, int kap, int vers);
    /************************************************************************************/
    /*!

    Ermitteln von Kapitel und Vers zu einer Textposition. Es wird
    Kapitel und Vers ermittelt in dessen Bereich die Position liegt.
    Die ermittelten Werte werden in die Felder der Klasse \sa 'CBibBasis'
    eingetragen.
    Rueckgabewert ist die Kap/Vers angabe in der Form '(01:22)', bei Fehler "1".
    \param string buch (bibelbuch)
    \param int    position (Zeichenposition im Text)
    \brief Ermitteln von Kapitel und Versangaben
    */
    string lesPosKap(string,int);
    /************************************************************************************/
    /*!
      "lesHebWort" Funktion zum Aufsuchen eines Hebr-Wortes im Wortbuch
      
      Unter Vorgabe eines deutschen Wortes wird im Wortbuch der Wortbucheintrag gesucht
      und in die Variablen "whebwort" und "wdeuwort" eingetragen. Rueckgabe ist der Statuswert.\n
      Es gilt:\n
    0 = Gesuchtes Wort wurde gefunden.\n
    1 = Gesuchtes Wort ist kuerzer als im Wortbuch, aber sonst gleich \n
    2 = Das Wort wurde nicht gefunden.\n
    3 = Ende Lexika erreicht \n
    4 = Fehler in der Lexikadatei \n
    Bei Werten >10 gelten die allgemeinen Fehlerarten.\n
    \param string Suchwort
    \brief Suche die Eintragung im Woerterbuch 
    */
    int lesHebWort(string);
    /************************************************************************************/
    /*!
        "lesDeuWort" Funktion zum Aufsuchen eines deutschen Wortes im Wortbuch
        
        Unter Vorgabe eines hebr.Wortes wird im Wortbuch der Wortbucheintrag gesucht
        und in die Variablen "whebwort" und "wdeuwort" eingetragen. Rueckgabe ist der Statuswert.\n
        Es gilt:\n
      0 = Gesuchtes Wort wurde gefunden.\n
      1 = Gesuchtes Wort ist kuerzer als im Wortbuch, aber sonst gleich \n
      2 = Das Wort wurde nicht gefunden.\n
      3 = Ende Lexika erreicht \n
      4 = Fehler in der Lexikadatei \n
      \param string Suchwort
      \brief Suche die Eintragung Woerterbuch 
      */
    int lesDeuWort(string);
    /************************************************************************************/
    // Variable W�rterbuch
    string wkalender;
    string whebwort;
    string wdeuwort;

    /************************************************************************************/
    /*!
    "lesFehlertext" Funktion zur Bereitstellung des Fehlertextes

    Es wird der Text zur Beschreibung des Fehlers bei einer fehlerhaften 
    Bearbeitung (Status != 0) zurueckgegeben. 
    */
    string lesFehlertext(int);

    /*!
    "lesProgressStatus" Funktion zur Bereitstellung des Bearbeitungsfortschritt 

    Liefert den Bearbeitungsfortschritt des laufenden Prozesses in Prozent von Hundert.
    Parameter keine. Rueckgabewert ist die Prozentangabe von Hundert zum aktuellen 
    Bearbeitungsstand.
    */
    int lesProgressStatus();

    /************************************************************************************/
    //! Setzt die Variable fuer das Temp- (alt Basis) verzeichniss (kein default)
    void setzTempVerzeichnis(string);

    //! Setzt die Variable fuer das Basisverzeichniss
    void setzBasisVerzeichnis(string);

    //! Setzt die Variable fuer das Buchverzeichniss der Bibelbuecher (kein default)
    void setzBuchVerzeichnis(string);

    //! Setzt die Variable fuer das Verzeichniss der Ausgabedateien  (kein default)
    void setzOutVerzeichnis(string);

    /****************************************************************************
         Interne (privat) Routinen des Kerninterface
    *****************************************************************************/
  private:

    /*!
      "ladeKernroutine" = Laed den Kern zur Bearbeitung der Anforderung
      
      In Abhaengikeit der Aufgabe wird die erforderliche Kernroutine bausteine 
      geladen und die benoetigten Verzeichnisse an den Kern durchgereicht
      wenn die vorangegangene Aufgabe eine andere Konstellation verwendet 
      hat. Rueckgabewert keiner 
      \param int art (1 = lesBibelAbschnitt, lesBibelAbschnittAnalyse \n
                      2 = lesIntervallListe, lesIntervallBlock \n
                      3 = lesPruefNachbar, lesNachbarFinden, lesNachbarSuchen \n
                      4 = lesSuchMatrix \n
                      5 = lesHebWort, lesDeuWort \n
                      9 = lesHebrJahreszahl, lesHebrTransliteration ect.\n
      \brief Laed die erforderliche Kernroutine
    */

    void ladeKernroutine(int art);


    CBibeltext *bt;
    CIntervall *in;
    CNbrListen *nb;
    CMatrix    *ma;
    CBuchIndex *po;
    CWortBuch  *wb;
    int wrtbu;
    int bearbalt;
    int bearbart;
    string buch;
    string etmp_verz;
    string ebasis_verz;
    string ebuch_verz;
    string eout_verz;

};

#endif
