/***************************************************************************
                          clexikon.h  -  description
                             -------------------
    begin                : Wed Nov 7 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CLEXIKON_H
#define CLEXIKON_H

#include "cbibbasis.h"
#include "string"
#include "stdio.h"
//! Lexikonroutinen zum BITANA-Projekt

/*!
  *@author Heinz Schumann
  */

class CLexikon
{
public: 
	CLexikon();
	~CLexikon();
/*!

  Setzt den Lexikonpfad. Die Lexika liegen in einem Unterverzeichniss des
  Buchpfades.Er wird der Buchpfad angegeben aus dem durch anhängen
  des Unterverzeichnisses "lex/" intern der eigentliche Pfad gebildet wird.
  \param string Buchverzeichniss
  \brief Setzt das Lexikonverzeichniss
  */
  void setLexBuchVerzeichnis(string v);
/*!

  Zu einem vorgegebenen Wort wird der Lexikaeintrag aufgesucht. Rückgabe ist das
  Suchwort und die dazugehörige Übersetzung.
  Im Rückgabestring sind die einzelnen Worte durch ein newline getrennt. An erster Stelle
  steht immer das gesuchte Wort. Wird das Wort im Lexikon nicht gefunden so wird
  eine Ziffer zurückgegeben. Es gilt:\n
  1 = Gesuchtes Wort ist kürzer als im Lexika, aber sonst gleich\n
  2 = Das Wort wurde nicht gefunden.\n
  3 = Ende Lexika erreicht\n
  4 = Fehler in der Lexikadatei\n
  \param string Suchwort
  \param int Sprache des Suchwortes  0 = Hebraeisch, 1 = Deutsch (default = 0)

  */
  string findWort(string wo, int sp);
/*!

  Ausgehend vom aktuellen Stand wird im Lexika das nächstfolgende hebr.Wort aufgesucht
  und zurückgegeben.Im Rückgabestring sind die einzelnen Worte durch ein newline getrennt.
  An erster Stelle steht immer das hebr. Wort.
  \param keine Parameter
  \brief Nächstes Wort aus dem Lexikon bereitstellen
 */
  string nextHebWort();

private:
  bool ladIndex(int sp);
  int  lesWort();

  string lbuch_verz;
  int sprache;
  unsigned int lexbuchlng;
  int aktidx;
  char vgl[200];
  char wrt[80];

  FILE *dat;
  union INDEX
  {
   unsigned int  idx[30][30][30];
   char idxca[30*30*30*4];
  };

  INDEX tab;
};

#endif
