//
// C++ Interface: cmatrix
//
// Description:
//
//
// Author: Heinz Schumann <kontakt@heinz-schumann.de>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef CMATRIX_H
#define CMATRIX_H

#include "cnachbar.h"
using namespace std;

//! Methoden zum Aufbau einer Textmatrix
class CMatrix : public CNachbar
  {
  public:
    CMatrix();
    ~CMatrix();


    /*!
     "suchMatrix" Suchen einer Textmatrix
     
     Sucht zu einer Worttabelle im Bibeltext (default torah) nach einer Matrix in der 
     alle Worte enthalten sind. Die Worttabelle wird als String uebergeben in welchem 
     die Worte durch "\t" getrennt sind. Bei Fehler ist der Rueckgabewert die Fehlernummer 
     \param string Bibelbuch
     \param string Worttabelle (max 10 Worte durch "\t" getrennt)
     \param bool Modifiziert
     \param string Name Ausgabedatei
     \brief Suche nach einer Textmatrix
     */
    int suchMatrix(string buch, string worte, bool in1, bool mod, string datei);

  private:

    /*!
      "eukabs" Berechnen des euklidischen Abstandes in der Flaeche      
      
      Berechnet den euklidischen Abstand eines Intervallwortes zu einem Basiswort.
      Die Daten des Basiswortes sind im Header eingetragen. Rueckgabewert ist der 
      Abstand als Gleitkommazahl.
      \param int Intervallweite
      \param int Beginposition
      \param int Endposition
      \brief Berechnen des euklidischen Abstandes
    */
    float abstand(int pa1, int pe1, int pa2, int pe2, int ldfint, int in1, int in2);
    float wurzel(int p1, int p2, int s);
    float kompakt(int pa1, int pe1, int pa2, int pe2, int ldfint);
    void  eintragen(int, int, int);

    float lindnz;
    float linalt;
    int   basint;

    STRMATRIX bas[WRTMATRIX];                // Komplexdaten Matrix
    STRMATRIX erg[WRTMATRIX];
    UNIINTER ein;
   
  };

#endif
