/***************************************************************************
                          cnachbar.h  -  description
                             -------------------
    begin                : Thu Nov 1 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CNACHBAR_H
#define CNACHBAR_H

#include "cbuchindex.h"
#include "cwortbuch.h"

//! Methoden zur Nachbarschaftsbehandlung im Bibeltext (2-D)

/*!
  *@author Heinz Schumann
  */

class CNachbar : public CBuchIndex
{
public: 
	CNachbar();
	~CNachbar();
/*!

  Aus den vorbereiteten Intervalllisten (Sortiert nach Intervall) "wort1.nbr" bis
  "wort3.nbr" wird eine Berechnung zur Ermittlung der Nachbarschaftswerte durchgefuehrt.
  Die Ergebnisse sind in der Datei "gruppen.nbr" zusammengefasst. Es werden aus den
  Worten insgesammt 20 Nachbarschaftsgruppierungen gebildet und nach dem Verfahren
  von Rips bewertet. In der Ausgabedatei sind die Gruppierungen nach ihrer
  Bewertungsgroesse absteigend sortiert. Rueckgabewert ist die Bewertungsdifferenz
  zwischen der ersten und zweiten Gruppierung.
  \param  int Anzahl Worte Max = 3 (kein defaultwert)
  \param string Name der Ausgabedatei (default = "gruppen.nbr")
  \param bool Normalisierung der Gruppenbewertung (default = true)
  \brief Bewertung von Nachbarschaften
  */
   float berechneNachbar(int anzwrt, string datei,
                         bool norma);
/*!

  Zu einem vorgegebenen Wort werden in einem Textausschnitt, in dessen Mitte das
  Wort eingelagert ist, mithilfe des Lexikon in der Nachbarschaft nach
  Worten gesucht. Fuer die gefundenen Worte wird die eukidische Entfernung zum
  vorgegebenen Wort ermittelt und sortiert nach dem Abstand in einer Datei
 "hebwrtls.nbr" ausgegeben.
  Rueckgabewert ist, unabhaengig von der Liste,  die Anzahl der insgesammt gefundenen Worte.
  Bei Fehler ist der Rueckgabewert die negative Fehlernummer.
  \param string Bibelbuch
  \param string hebr. Wort
  \param int Intervall des Wortes
  \param int Startposition des Wortes
  \param int Maximale Anzahl der Worte in der Liste (default = 100)
  \param string Name Ausgabedatei (default = "hebwrtls.nbr")
  \brief Nachbar in Wortumgebung finden
  */
   int nbrFindHebWorte(string buch, string wort, int intervall, int pos,
                        int wrtlst,
                        string outdatei,
                        string wrtbuch);
/*!

  Sucht zu einem Wort signifikante Nachbarschaften mithilfe des Lexikon und der
  Nachbarschaftspruefung. Das Ergebniss wird in einer Datei "nbrwrt.nbr"
  ausgegeben. Rueckgabewert ist die Anzahl der gefundenen Worte. Bei Fehler
  ist der Rueckgabewert die negative Fehlernummer.
  \param string Bibelbuch
  \param string Hebr. Wort
  \param char Suche von Buchstaben (default = -32 = Alpha)
  \param char Suche bis einschlieslich Buchstaben im Lexikon (default = -6 = Tau)
  \param string Name Ausgabedatei (default = nbrwrt.nbr)
  \brief Nachbarschaften suchen
  */

  int suchHebNachbar(string buch, 
                     char vonbu,
                     char bisbu,
                     string outdatei,
                     string wrtbuch);
/*!

   Sortierung der Ergebnissdatei aus CNachbar::suchHebNachbar() nach Intervall
   und Startposition des Suchwortes sowie Zeilenbreite in aufsteigender Reihenfolge
   Die Ein und Ausgabedatei haben den Satzaufbau der Struktur \sa STRGRP
   \param string Name Ausgabedatei (default = nbrwrt.sor)
   \param string Name Eingabedatei (default = nbrwrt.nbr)
   \brief Sortierung der Nachbarschaften
 */
  int sortSuchNachbar(string outdatei,
                       string indatei);

  bool inFlaeche(int, int, int, int, int);

   int    wrtlng[3];
private:
  void abstand(int, int);
  float wurzel(int, int, int);

  CWortBuch  *lex;
  STRHEBWRT *fisor;
  STRHEBWRT gef;
 
  bool check();
  void einsort();
  float wrtAbstand(int, int);
  int  absPosition();
  float diff(int, int);
  
  char text[MAXBRT+1];
  int lexwrt;
  int anzgef;
  int anzwrt;
  int zlbrt;
  int lfdint;
  int suinter;
  int lfdbu;
  int anzchar;
  int anzbu;
  int beglfdzl;
  int beglfdwrt;
  int begsuwrt, endsuwrt;
  int begpos;
  int spsuwrt, zlsuwrt;
  int fak, faki;

  int aber[MAXWRT];
  int eber[MAXWRT];
  int apos[MAXWRT];
  int epos[MAXWRT];
  int inter[MAXWRT];
  int prozi[MAXWRT];
  int abst;
  int proz;
  int seq;
  int adom;
  int edom;

};


#endif
