/***************************************************************************
                          cnbrlisten.h  -  description
                             -------------------
    begin                : Sun Nov 4 2001
    copyright            : (C) 2001 by Heinz Schumann
    email                : heinz.schumann@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CNBRLISTEN_H
#define CNBRLISTEN_H

#include "cnachbar.h"
//#include "cwortbuch.h"

using namespace std;

//! Methoden zur Listenerstellung fuer Nachbarschaften im Bibeltext (2D)
/*!
  Die Klasse CNbrListen stellt die Funktionen zur Erstellung von verschiedenen
  Nachbarschaftslisten im 2-D Bereich bereit.
  *@author Heinz Schumann
  */

class CNbrListen : public CNachbar
{
public: 
	CNbrListen();
	~CNbrListen();
/*!

  Prueft die Signifikanz einer Nachbarschaft zwischen max 3 Worten. Als Ergebniss
  werden zwei Listen erstellt. Liste "datnbr.bta" enthaellt die Ergebnisse von
  20 verschiedenen Gruppierungen der Worte im Text. Die zweite Liste kann in zwei
  verschiedenen Variantan angefordert werden. Einmal als Liste mit einer maximalen
  Zeilenbreite von 62 Zeichen und einer Zeilenanzahl von unter den Namen "fixnbr.bta" oder mit einer variablen
  Zeilenbrewite entsprechend der Anforderung unter dem Namen "flexnbr.bta".
  \param string Bibelbuch
  \param string heb. Wort1
  \param string heb. Wort2
  \param string heb. Wort3
  \param bool Fix-Liste (default = true)
  \param int Zeilennummer als Basis fuer Flex- Fixliste (default = 1)
  \brief Pruefen einer Nachbarschaft
  */
  int pruefNachbar(string buch, string wo1, string wo2, string wo3,
                   bool in1,
                   bool mod,
                   int zlnr,
                   string outdatei1,
                   string outdatei2);
/*!

  Erstellt die Liste aus den Ergebnissen der Nachbarschaftspruefung. Vorher muss
  die Funktion \sa CNachbar::berechneNachbar(); durchlaufen sein.
  \param string Bibelbuch
  \param string heb. Wort1
  \param string heb. Wort2
  \param string heb. Wort3
  \param int Nummer des Wortes wenn keine Intervalle gefunden wurden.
  \param string Ausgabedatei (default = "datnbr.bta")
  \param string Eingabedatei (default = gruppen.nbr")
  \brief Liste Daten der Nachbarschaft
  */
  int nbrDatenListe(string buch, string wo1, string wo2, string wo3,int fw,
                    string outdatei,
                    string indatei);

 /*!

  Textabbildung der Nachbarschaft mit variabler Zeilenbreite fuer
  Ausgaben in scrollbare Listen. Erstellt die Liste "flexnbr.bta".
  \param string Bibelbuch
  \param string heb. Wort1
  \param string heb. Wort2
  \param string heb. Wort3
  \param int Nummer der Zeile (Satznummer) aus der Eingabedatei fuer welche die
             Textdarstellung erfolgen soll (default = 1)
  \param string Ausgabedatei (default = "flexnbr.bta")
  \param string Eingabedatei (default = gruppen.nbr")
  \brief Liste Textabbildung der Nachbarschaft
  */
  int nbrFlexAbbildung(string buch, string wo1, string wo2, string wo3,
                     int zl, int fw,
                     string outdatei,
                     string indatei);
/*!

  Sucht in der Textdarstellung des Wortes mit hilfe des Woerterbuches
  nach Worten in der Nachbarschaft und gibt deren Position in einer Liste aus.
  Die zweite Liste ist die Darstellung der Textmatrix in welcher die 
  Nachbarschaftsworte gesucht wurden. Eine Pruefung auf signifikanz wird nicht
  durchgefuehrt
  \param string Bibelbuch
  \param string heb. Wort
  \param int    Intervall des Wortes
  \param int    Position des Wortes im Text
  \param string Ausgabedatei (default = "txtnbr.bta")
  \param string Eingabedatei (default = "txtabbld.bta")
  \brief Liste Textabbildung der Nachbarschaft
  */

  int findNachbar(string buch, string wort, int intervall, int pos,
                  int zl,
                  int wrtlst,
                  string outdatei1,
                  string outdatei2,
                  string indatei);
/*!

  Erstellen der Liste "txtabbld.bta" zur Funktion findNachbar()
  \param string Bibelbuch
  \param string heb. Wort
  \param int Intervallweite des heb. Wortes
  \param int Startposition des heb. Wortes im Text
  \param string Ausgabedatei (default = "txtabbld.bta")
  \brief Liste zur Textabbildung bei Nachbarschaftsfindung
  */

  int txtAbbildung(string buch, string wort, int intervall, int pos,
                   string outdatei);

/*!

  Erstellt die Liste "txtnbr.bta" zur Funktion findNachbar()
  \param string heb. Wort
  \param int Intervallweite des heb. Wortes
  \param int Startposition des heb. Wortes im Text
  \param int Anzahl der gefundenen Nachbarschaftsworte
  \param int Maximale Anzahl von Nachbarschaftsworten in der Liste (default keine)
  \param string Ausgabedatei (default = "txtnbr.bta")
  \param string Eingabedatei (default = "hebwrtls.nbr")
  \brief Liste der Nachbarschaftsworte in einem Textausschnitt
  */
  int nbrWortListe(string wort, int intervall, int pos,
                   int anzgef, int wrtlst,
                   string outdatei,
                   string indatei);

/*!
  Sucht zu einem Wort signifikante Nachbarschaften mithilfe des Lexikon und der
  Nachbarschaftspruefung. Das Ergebniss wird in einer Datei "signbrls.bta"
  ausgegeben. Rueckgabewert ist die Anzahl der gefundenen Worte. Bei Fehler
  ist der Rueckgabewert die negative Fehlernummer.
  \param string Bibelbuch
  \param string Hebr. Wort
  \param char Suche von Buchstaben (default = -32 = Alpha)
  \param char Suche bis einschlieslich Buchstaben im Lexikon (default = -6 = Tau)
  \param string Name Ausgabedatei (default = "signbrls.bta")
  \brief Nachbarschaften suchen
  */
  int suchNachbar(string buch, string wort,
                  char vonbu,
                  char bisbu,
                  string outdatei,
                  string wrtbuch);

private:

  int aber[MAXWRT];
  int eber[MAXWRT];
  int apos[MAXWRT];
  int epos[MAXWRT];
  int inter[MAXWRT];

  int abst;
  int proz;
  int seq;
  int adom;
  int edom;


};

#endif
