//
// C++ Interface: cwortbuch
//
// Description:
//
//
// Author: Heinz Schumann <kontakt@heinz-schumann.de>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef CWORTBUCH_H
#define CWORTBUCH_H

#include "cbibbasis.h"
#include "string"
#include "stdio.h"

/**
@author Heinz Schumann
*/

class CWortBuch
{
  public:
    CWortBuch();
    ~CWortBuch();
//! Methoden zur Arbeit mit dem Woerterbuch    
/*!
  "openWortBuch" Setzt den Pfad und oeffnet das Woerterbuch fuer die Wortbuch-Routinen
  
  Die Woerterbuecher liegen in einem Unterverzeichniss des Buchpfades.
  Er wird der Buchpfad angegeben aus dem durch anhaengen des Unterverzeichnisses
  "lex/" intern der eigentliche Pfad gebildet wird. oeffnet dann die Wortbuchdatei 
  fuer die Routinen zur Benutzung des Woerterbuches. Das Hebr. - Deutsch Buch ist nach
  Hebr. sortiert und wird mit "kuhebdeu.lex" geoeffnet, Das Deutsch - Hebr. ist nach 
  Deutsch sortiert und wird mit "kudeuheb.lex" geoeffnet. 
  
  \param string Buchverzeichniss
  \param string Name der Wortbuchdatei 
  \param bool   Sortierung des Wortbuches (false = Deutsch, true = Hebr.)
  \brief Setzt das Verzeichnis und oeffnet das Woerterbuch
  */
    int openWortBuch(string v, string datei, bool sp);
 
/*!
  "findWort" Sucht nach einem Wortbucheintrag
  
  Zu einem vorgegebenen Wort wird der Wortbucheintrag im dem mit
  "openWortBuch" geoeffneten Wortbuch aufgesucht und in die Struktur
  STRWRB eingetragen. Rueckgabe ist der Statuswert.  Es gilt:\n
  0 = Gesuchtes Wort wurde gefunden.\n
  1 = Gesuchtes Wort ist kuerzer als im Wortbuch, aber sonst gleich \n
  2 = Das Wort wurde nicht gefunden.\n
  3 = Ende Lexika erreicht \n
  4 = Fehler in der Lexikadatei \n
  \param string Suchwort
  \brief Suche das Wort im W�rterbuch 
  */
  int findWort(string);

  /*!
  "nextWort" Liest den naechstfolgenden Wortbucheintrag
  
  Ausgehend vom aktuellen Stand wird im mit "openWortBuch" geoeffneten Wortbuch
  das naechstfolgende Wort aufgesucht und in die Struktur strwrb eingetragen.
  Ist das Dateiende erreicht wird eine "1" zurueckgegeben ansonsten "0"
  \param keine Parameter
  \brief N�chstes Wort aus dem Wortbuch bereitstellen
 */
  int nextWort();
 
//! Struktur der Suchfunktionen des Woerterbuches
struct STRWRB
{
  int    lnhebwrt;        /*!< Laenge Heb-Wort */
  int    lndeuwrt;        /*!< Laenge Deu-Wort */
  string hebwrb;          /*!< Heb-Wort des Wortbuches */
  string deuwrb;          /*!< Deu-Wort des Wortbuches */
} strwrb;  
            
  private:
    
    bool heb;
    string lbuch_verz;
    string wrtbuch;
   
    unsigned int lexbuchlng;

    FILE *dat;
};

#endif
