/***************************************************************************
                          bhebinp.h  -  description
                             -------------------
    begin                : Sun Jan 2 2000
    copyright            : (C) 2000 by Hans-Jrgen Schumann
    email                : hans@bitana.de
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream>

#include <qpushbt.h>
#include <qbttngrp.h>
#include <qcombo.h>
#include <qfontdialog.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qlineedit.h>

#include "bhebinp.h"

using namespace std;

BHebInp::BHebInp(QWidget *parent, const char *name ) : QWidget(parent,name)
{}

BHebInp::~BHebInp()
{}

/** Initialisierung */

void BHebInp::init(QtBitanaDoc *conf)
{

  HEB_BEG=224;		// 1. Heb-Zeichen ALEPH
  ANZB = 13;			// Anzeigenbreite
  // Rechtsbndig mit Leerzeichen links
  MAX_INP_STACK = 20;

  static const int	BDI=35;			// Buttondistance - Buttonabstand
  static const int	BBO=10;			// ButtonBoarder - Buttonrand
  static const int	BSI=30;			// Buttonsize - Buttongrsse

  static const QString hebletters[28] =
    {"Alef", "Bet", "Gimel", "Datet", "He", "Waw", "Zajin",
     "Het", "Tet", "Jod", "Schluss Kaf", "Kaf", "Lamed", "Schluss Mem",
     "Mem", "Schluss Nun", "Nun", "Samek", "Ajin", "Schluss Pe", "Pe",
     "Schluss Sade", "Sade", "Kof", "Resch", "Schin", "Taw"
    };


  bc = conf;
  codec = QTextCodec::codecForName("ISO 8859-8-I");

  // hebfont1 fuer Buttons holen und setzen

  bc->setSection("qtbitana");

  // inputstack initialisieren

  inpstack = new QStrList();

  // Button Group for common slot define

  QButtonGroup* bgroup;
  bgroup = new QButtonGroup( this, "bgroup" );
  bgroup->setGeometry( BBO/2, BBO/2, 2 * BBO + 4 * BDI + BSI, 6 * BDI + BSI + 4 * BBO );
  bgroup->setMinimumSize( 2 * BBO + 4 * BDI + BSI, 6 * BDI + BSI + 4 * BBO );
  bgroup->setMaximumSize( 2 * BBO + 4 * BDI + BSI, 6 * BDI + BSI + 4 * BBO );
  bgroup->setTitle( tr("Hebinput") );

  // Inputline - Widget

  in = new QComboBox( true, this, "in" );
  in->lineEdit()->setAlignment( int( QLineEdit::AlignRight ) );
  in->setGeometry( BBO + BBO/2, 3 * BBO, 4 * BDI + BSI, BSI );
  in->setEnabled(true);
  in->clearEdit();
  wmod = true;
  getInputStack();


  QPushButton *but;

  // Aufbau des Eingabefeldes

  char  cb[2] = " ";             // Tastenbezeichnung
  int i,k;
  int xs = BBO + BBO/2, ys= 4 * BBO + BSI;	// Pos. des 1. Buttonx, y - offset fr Positionen

  k=0;

  for (i=0; i<27; i++)
  {
    cb[0] = (char)(HEB_BEG+i);



    but  = new QPushButton(this, "heb");
    but->setGeometry( xs, ys, BSI, BSI );

    QString unibut =  codec->toUnicode(cb);

    but->setText( unibut);
    QString sletter = hebletters[i];
    QToolTip::add(  but, sletter );
    QWhatsThis::add(  but, "Buchstabe \n" + sletter );

    bgroup->insert(but);

    if (k++ < 4) xs += BDI;
    else
    {
      xs = BBO + BBO/2; k = 0;

      ys += BDI;
    }
  }

  // drei weitere Buttons, der erste kann auch anders
  // verwendet werden s. Auswertung Tastendruck

  // Taste nicht belegt ('-' Bindestrich?)

  but  = new QPushButton(this, " ");
  but->setGeometry( xs, ys, BSI, BSI );
  but->setText( "R" );
  bgroup->insert(but);
  xs += BDI;

  // 'M' memory - Wort Speichern

  but = new QPushButton(this, "M");
  but->setGeometry( xs, ys, BSI, BSI );
  but->setText( "M" );
  bgroup->insert(but);
  xs += BDI;

  // 'C' clear - Wort lschen

  but = new QPushButton(this, "C");
  but->setGeometry( xs, ys, BSI, BSI );
  but->setText( "C" );
  bgroup->insert(but);

  resize( 2 * BBO + 4 * BDI + BSI + 10, 6 * BDI + BSI + 4 * BBO + 10);
  setMinimumSize( 2 * BBO + 4 * BDI + BSI +10, 6 * BDI + BSI + 4 * BBO + 10 );
  setMaximumSize( 2 * BBO + 4 * BDI + BSI +10, 6 * BDI + BSI + 4 * BBO + 10 );

  connect(bgroup, SIGNAL(clicked(int)), this, SLOT(slotPressx(int)));
  connect(in, SIGNAL(activated(int)), this, SLOT(slotNewWord(int)));

}

/** Auswertung Tastendruck */
void BHebInp::slotPressx(int taste)
{

  QString uniword;

  switch (taste)
  {

  case 27:
    // Taste nicht belegt Stack lschen
    in->clear();
    word = "";
    wmod = true;
    setInputStack();
    setWord();
    break;

  case 28:
    // c = 'M' memory
    uniword =  codec->toUnicode(word);
    in->insertItem(uniword,0);
    in->clearEdit();
    if (in->count() > MAX_INP_STACK) in->removeItem(MAX_INP_STACK);
    word = "";
    wmod = true;
    setInputStack();
    setWord();
    break;

  case 29:
    // c = 'C' clear
    if (wmod)
    {
      in->clearEdit();
      word = "";
    }
    else
    {
      in->removeItem(in->currentItem());
      in->setCurrentItem(0);
      in->clearEdit();
      word = "";
      wmod = true;
    }
    setWord();
    break;

  default:
    QString ta = "";
    ta += (char)(HEB_BEG + taste);
    //			word = word.insert(0, ta);	// von rechts nach links
    word = word.append(ta);
    wmod = true;
    setWord();
    break;
  }

}

/** Auswahl eines Wortes aus Liste */
void BHebInp::slotNewWord(int item)
{

  wmod = false;
  word = in->text(item);
  word = codec->fromUnicode(word);
  setWord();

}


/** Reading the Input */
QString BHebInp::readInput()
{
  return ( word );
}

void BHebInp::setInputStack()
{


  bc->setSection("hebinput");
  QString tmp;
  for (int i=0; i<in->count(); i++)
  {
    tmp += (in->text(i));  // Rechstbund lsen
    tmp += ",";
  }
  string s(codec->fromUnicode(tmp));
  bc->setStringEntry("stack", s);
  return;
}

void BHebInp::getInputStack()
{
  bc->setSection("hebinput");
  string tmp = bc->getStringEntry("stack");
  while (tmp.size() > 1)
  {
    QString s(tmp.substr(0, tmp.find(",", 0)).c_str());
    tmp = tmp.substr(tmp.find(",", 0)+1);
    if (in->count() < MAX_INP_STACK) in->insertItem(codec->toUnicode(s));

  }
  if (in->count() == 0) in->insertItem(codec->toUnicode(""));
  slotNewWord(0);
}

void BHebInp::setWord()
{

  bc->setSection("hebinput");
  string s(word.latin1());
  bc->setStringEntry("word", s);
  in->setEditText(codec->toUnicode(word));
}

