/***************************************************************************
                          qtbitana.cpp  -  description
                             -------------------
    begin                : Don Aug  8 22:46:53 CEST 2002
    copyright            : (C) 2002 by Heinz & Hans-Jrgen Schumann
    email                : heinz@bitana.de; hans@bitana.de
    			 : $Id: qtbitana.cpp 220 2009-01-26 19:52:47Z hans $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#define VERSION "3.01"

#include "filesave.xpm"
#include "fileopen.xpm"
#include "filenew.xpm"
#include "file_properties.xpm"
#include "contents.xpm"
//#include "book.xpm"
#include "viewtree.xpm"

#include "qtbitana.h"

#include <qaccel.h>
#include <qaction.h>
#include <qpixmap.h>
#include <qmainwindow.h>
#include <qfont.h>
#include <qfontdialog.h>
#include <qtextstream.h>
#include <qpushbutton.h>
#include <qfiledialog.h>

#include <string>


#include <iostream>

QtBitanaApp::QtBitanaApp(const QString conf)
//QtBitanaApp::QtBitanaApp()
{


  bc = new CBitanaConfig;
  noconfig = false;

  if (!bc->readConfig(conf.latin1()))
  {
    int exit = QMessageBox::information(this, tr("Abbruch!"),
                                        tr("Die Konfigurationsdatei \n" + conf + "\nkann nicht gelesen werden!"),
                                        QMessageBox::Ok);
    noconfig = true;
    return;


  }

  kern = new CKernInterface();
  bc->setSection("kern");
  kern->setzBuchVerzeichnis(bc->getStringEntry("BookDir"));
  kern->setzTempVerzeichnis(bc->getStringEntry("TempDir"));
  kern->setzOutVerzeichnis(bc->getStringEntry("OutDir"));

  connect(qApp, SIGNAL(lastWindowClosed()), this, SLOT(slotWindowClosed()));

  ///////////////////////////////////////////////////////////////////
  // call inits to invoke all other construction parts
  initDoc();
  doc->loadProperties(conf.latin1());

  initActions();
  initMenuBar();
  initToolBar();
  initStatusBar();

  initView();

  //  confFile = conf;
  //  bc->saveConfig(conf.latin1());
  //  wo->setFont(hfont1);

  setCaption(tr("QtBitana - "  VERSION  " - "));
  setCaption(caption() + conf);

  viewToolBar->setOn(true);
  viewStatusBar->setOn(true);
  viewParaWindow->setOn(true);
  viewDocLst->setOn(true);
}

QtBitanaApp::~QtBitanaApp()
{}

/** initializes all QActions of the application */
void QtBitanaApp::initActions()
{

  QPixmap openIcon, saveIcon, newIcon, propIcon, viewtIcon, searchIcon;
  newIcon = QPixmap(filenew);
  openIcon = QPixmap(fileopen);
  saveIcon = QPixmap(filesave);
  propIcon = QPixmap(file_properties);
  searchIcon = QPixmap(contents);

  viewtIcon = QPixmap(viewtree);


  fileNew = new QAction(tr("New File"), newIcon, tr("&New"), QAccel::stringToKey(tr("Ctrl+N")), this);
  fileNew->setStatusTip(tr("Creates a new document"));
  fileNew->setWhatsThis(tr("New File\n\nCreates a new document"));
  connect(fileNew, SIGNAL(activated()), this, SLOT(slotFileNew()));

  fileOpen = new QAction(tr("Open File"), openIcon, tr("&Open..."), 0, this);
  fileOpen->setStatusTip(tr("Opens an existing document"));
  fileOpen->setWhatsThis(tr("Open File\n\nOpens an existing document"));
  connect(fileOpen, SIGNAL(activated()), this, SLOT(slotFileOpen()));

  fileSave = new QAction(tr("Save File"), saveIcon, tr("&Save"), QAccel::stringToKey(tr("Ctrl+S")), this);
  fileSave->setStatusTip(tr("Saves the actual document"));
  fileSave->setWhatsThis(tr("Save File.\n\nSaves the actual document"));
  connect(fileSave, SIGNAL(activated()), this, SLOT(slotFileSave()));

  fileSaveAs = new QAction(tr("Save File As"), tr("Save &as..."), 0, this);
  fileSaveAs->setStatusTip(tr("Saves the actual document under a new filename"));
  fileSaveAs->setWhatsThis(tr("Save As\n\nSaves the actual document under a new filename"));
  connect(fileSaveAs, SIGNAL(activated()), this, SLOT(slotFileSaveAs()));

  fileClose = new QAction(tr("Close File"), tr("&Close"), QAccel::stringToKey(tr("Ctrl+W")), this);
  fileClose->setStatusTip(tr("Closes the actual document"));
  fileClose->setWhatsThis(tr("Close File\n\nCloses the actual document"));
  connect(fileClose, SIGNAL(activated()), this, SLOT(slotFileClose()));

  filePrint = new QAction(tr("Print File"), tr("&Print"), QAccel::stringToKey(tr("Ctrl+P")), this);
  filePrint->setStatusTip(tr("Prints out the actual document"));
  filePrint->setWhatsThis(tr("Print File\n\nPrints out the actual document"));
  connect(filePrint, SIGNAL(activated()), this, SLOT(slotFilePrint()));

  fileQuit = new QAction(tr("Exit"), tr("E&xit"), QAccel::stringToKey(tr("Ctrl+Q")), this);
  fileQuit->setStatusTip(tr("Quits the application"));
  fileQuit->setWhatsThis(tr("Exit\n\nQuits the application"));
  connect(fileQuit, SIGNAL(activated()), this, SLOT(slotFileQuit()));


  viewParaWindow = new QAction(tr("ParaWindow"), propIcon, tr("Search&parameter"), 0, this, 0, true);
  viewParaWindow->setStatusTip(tr("Enables/disables the ParaWindow"));
  viewParaWindow->setWhatsThis(tr("ParaWindow\n\nEnables/disables the ParaWindow"));
  connect(viewParaWindow, SIGNAL(toggled(bool)), this, SLOT(slotViewParaWindow(bool)));

  searchInText = new QAction(tr("search"), searchIcon, tr("Suche"), 0, this);
  searchInText->setStatusTip(tr("Suche im text"));
  searchInText->setWhatsThis(tr("Ruft Kern auf und sucht laut Einstellungen"));
  connect(searchInText, SIGNAL(activated()), this, SLOT(slotSearch()));


  viewDocLst = new QAction(tr("DocList"), viewtIcon, tr("Ergebnissdateien"), 0, this, 0, true);
  viewDocLst->setStatusTip(tr("Enables/disables the resul tList"));
  viewDocLst->setWhatsThis(tr("DocList\n\nEnables/disables the Doc / Result Window"));
  connect(viewDocLst, SIGNAL(toggled(bool)), this, SLOT(slotViewDocList(bool)));

  viewToolBar = new QAction(tr("Toolbar"), tr("Tool&bar"), 0, this, 0, true);
  viewToolBar->setStatusTip(tr("Enables/disables the toolbar"));
  viewToolBar->setWhatsThis(tr("Toolbar\n\nEnables/disables the toolbar"));
  connect(viewToolBar, SIGNAL(toggled(bool)), this, SLOT(slotViewToolBar(bool)));

  viewStatusBar = new QAction(tr("Statusbar"), tr("&Statusbar"), 0, this, 0, true);
  viewStatusBar->setStatusTip(tr("Enables/disables the statusbar"));
  viewStatusBar->setWhatsThis(tr("Statusbar\n\nEnables/disables the statusbar"));
  connect(viewStatusBar, SIGNAL(toggled(bool)), this, SLOT(slotViewStatusBar(bool)));

  //  propCut = new QAction(tr("Cut"), tr("Cu&t"), QAccel::stringToKey(tr("Ctrl+X")), this);
  //  propCut->setStatusTip(tr("Cuts the selected section and puts it to the clipboard"));
  //  propCut->setWhatsThis(tr("Cut\n\nCuts the selected section and puts it to the clipboard"));
  //  connect(propCut, SIGNAL(activated()), this, SLOT(slotPropCut()));

  propFont = new QAction(tr("Font"), tr("&Font"), QAccel::stringToKey(tr("Ctrl+C")), this);
  propFont->setStatusTip(tr("Fonteinstellung (unicode benutzen !"));
  propFont->setWhatsThis(tr("Fonteinstellung\n\nEin Unicode oder ISO 8859-8 ist zu verwenden!"));
  connect(propFont, SIGNAL(activated()), this, SLOT(slotPropFont()));
  propFont->setVisible(false);

  propPfade = new QAction(tr("Pfade"), tr("&Pfade"), QAccel::stringToKey(tr("Ctrl+V")), this);
  propPfade->setStatusTip(tr("Pastes the clipboard contents to actual position"));
  propPfade->setWhatsThis(tr("Paste\n\nPastes the clipboard contents to actual position"));
  connect(propPfade, SIGNAL(activated()), this, SLOT(slotPropPfade()));

  propWbdlg = new QAction(tr("Wrterbuch"), tr("&Wrterbuch"), QAccel::stringToKey(tr("Ctrl+W")), this);
  propWbdlg->setStatusTip(tr("Wrterbuchauswahl"));
  //   propPfade->setWhatsThis(tr("Paste\n\nPastes the clipboard contents to actual position"));
  connect(propWbdlg, SIGNAL(activated()), this, SLOT(slotWrtBuch()));



  helpAboutApp = new QAction(tr("About"), tr("&About..."), 0, this);
  helpAboutApp->setStatusTip(tr("About the application"));
  helpAboutApp->setWhatsThis(tr("About\n\nAbout the application"));
  connect(helpAboutApp, SIGNAL(activated()), this, SLOT(slotHelpAbout()));


}

void QtBitanaApp::initMenuBar()
{
  ///////////////////////////////////////////////////////////////////
  // MENUBAR

  ///////////////////////////////////////////////////////////////////
  // menuBar entry fileMenu
  fileMenu=new QPopupMenu();
  fileNew->addTo(fileMenu);
  fileOpen->addTo(fileMenu);
  fileClose->addTo(fileMenu);
  fileMenu->insertSeparator();
  fileSave->addTo(fileMenu);
  fileSaveAs->addTo(fileMenu);
  //   fileMenu->insertSeparator();
  //   filePrint->addTo(fileMenu);
  fileMenu->insertSeparator();
  fileQuit->addTo(fileMenu);

  ///////////////////////////////////////////////////////////////////
  // menuBar entry ProppertyMenu
  propMenu=new QPopupMenu();
  //  propCut->addTo(propMenu);
  propFont->addTo(propMenu);
  propPfade->addTo(propMenu);
  propWbdlg->addTo(propMenu);

  ///////////////////////////////////////////////////////////////////
  // menuBar entry viewMenu
  viewMenu=new QPopupMenu();
  viewMenu->setCheckable(true);
  viewParaWindow->addTo(viewMenu);
  viewDocLst->addTo(viewMenu);
  viewToolBar->addTo(viewMenu);
  viewStatusBar->addTo(viewMenu);
  ///////////////////////////////////////////////////////////////////
  // Prop YOUR APPLICATION SPECIFIC MENUENTRIES HERE

  ///////////////////////////////////////////////////////////////////
  // menuBar entry helpMenu
  helpMenu=new QPopupMenu();
  helpAboutApp->addTo(helpMenu);

  ///////////////////////////////////////////////////////////////////
  // MENUBAR CONFIGURATION
  menuBar()->insertItem(tr("&File"), fileMenu);
  menuBar()->insertItem(tr("&View"), viewMenu);
  menuBar()->insertItem(tr("&Einstellungen"), propMenu);
  menuBar()->insertSeparator();
  menuBar()->insertItem(tr("&Help"), helpMenu);

}

void QtBitanaApp::initToolBar()
{
  ///////////////////////////////////////////////////////////////////
  // TOOLBAR
  fileToolbar = new QToolBar(this, "file operations");
  fileNew->addTo(fileToolbar);
  fileOpen->addTo(fileToolbar);
  fileSave->addTo(fileToolbar);
  viewParaWindow->addTo(fileToolbar);
  viewDocLst->addTo(fileToolbar);
  fileToolbar->addSeparator();
  searchInText->addTo(fileToolbar);
  fileToolbar->addSeparator();
  QWhatsThis::whatsThisButton(fileToolbar);


  bookToolBar = new BibText(this, "book selections", doc);

}

void QtBitanaApp::initStatusBar()
{
  ///////////////////////////////////////////////////////////////////
  //STATUSBAR

  progress = new QProgressBar( 100, this );
  statusBar()->message(tr("Ready..."));
  statusBar()->addWidget(progress, 0, true); // , int stretch = 0, bool permanent = FALSE );
  //    progress->show();
}

void QtBitanaApp::initDoc()
{
  doc=new QtBitanaDoc();

}

void QtBitanaApp::initView()
{
  ////////////////////////////////////////////////////////////////////
  // set the main widget here
  view=new QtBitanaView(this, doc);
  setCentralWidget(view);
  bookToolBar->setDoc(doc);
  connect(view, SIGNAL(signalSearch()), this, SLOT(slotSearch()));
  connect(view, SIGNAL(signalInitBook()), bookToolBar, SLOT(slotInitBook()));
}

void QtBitanaApp::slotWindowClosed()
{
  doc->saveProperties();
}

bool QtBitanaApp::queryExit()
{
  if (noconfig) return true;

  int exit=QMessageBox::information(this, tr("Exit..."),
                                    tr("Aktuelle Datei speichern ?"),
                                    QMessageBox::Yes, QMessageBox::No, QMessageBox::Abort);

  switch (exit)
  {
  case QMessageBox::Yes:
    slotFileSave();
    break;

  case QMessageBox::No:
    break;

  case QMessageBox::Abort:
    break;
  };


  if (exit == QMessageBox::Abort)
    return false;
  else
    return true;

}

/////////////////////////////////////////////////////////////////////
// SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////


void QtBitanaApp::slotFileNew()
{
  statusBar()->message(tr("Creating new file..."));
  doc->newDoc();
  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotFileOpen()
{
  statusBar()->message(tr("Opening file..."));

  doc->setSection("kern");

  QString fileName =  QFileDialog::getOpenFileName(doc->getStringEntry("ExemplDir"),0,this);
  if (!fileName.isEmpty())
  {
    doc->load(fileName);
    setCaption(fileName);
    QString message=tr("Loaded document: ")+fileName;
    statusBar()->message(message, 2000);
    //    view->showDoc(fileName);
  }
  else
  {
    statusBar()->message(tr("Opening aborted"), 2000);
  }
}


void QtBitanaApp::slotFileSave()
{
  statusBar()->message(tr("Saving file..."));
  if (doc->isModified())
    doc->save();
  else
    slotFileSaveAs();
  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotFileSaveAs()
{
  statusBar()->message(tr("Saving file under new filename..."));
  QString fn = QFileDialog::getSaveFileName(0, 0, this);
  if (!fn.isEmpty())
  {
    doc->saveAs(fn);
    setCaption(fn);
    statusBar()->message(tr("Saved document: ")+fn, 2000);
  }
  else
  {
    statusBar()->message(tr("Saving aborted"), 2000);
  }

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotFileClose()
{
  statusBar()->message(tr("Closing file..."));

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotFilePrint()
{
  statusBar()->message(tr("Printing..."));
  QPrinter printer;
  if (printer.setup(this))
  {
    QPainter painter;
    painter.begin(&printer);

    ///////////////////////////////////////////////////////////////////
    // TODO: Define printing by using the QPainter methods here

    painter.end();
  };

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotFileQuit()
{
  statusBar()->message(tr("Exiting application..."));
  ///////////////////////////////////////////////////////////////////
  // exits the Application
  if (doc->isModified())
  {
    if(queryExit())
    {
      doc->saveProperties();
      qApp->quit();
    }
    else
    {}
    ;
  }
  else
  {
    doc->saveProperties();
    qApp->quit();
  };

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotPropCut()
{
  statusBar()->message(tr("Cutting selection..."));

  statusBar()->message(tr("Ready."));
}


// Font setzen
void QtBitanaApp::slotPropFont()
{
  statusBar()->message(tr("Font selection..."));
  doc->setSection("fonts");
  QString hf = doc->getStringEntry("hebfont1",  "'misc-fixed,19,50,0,22'").c_str();

  QString family(hf.mid(1,hf.find(',')-1));
  hf = hf.mid(hf.find(',')+1);

  int point = hf.mid(1,hf.find(',')+1).toInt();
  hf = hf.mid(hf.find(',')+1);

  int weight = hf.left(hf.find(',')).toInt();
  hf = hf.mid(hf.find(',')+1);

  bool ital = hf.left(hf.find(',')).toInt();
  hf = hf.mid(hf.find(',')+1);

  //	int set = hf.left(hf.find('\'')).toInt();
  hf = "";

  QFont f1 = QFont(family, point, weight, ital); //  , QFont::CharSet(set));

  //
  bool ok;
  QFont f2 = QFontDialog::getFont( &ok, f1, this );
  if ( ok )
  {
    // the user selected a valid font
    QTextOStream(&hf) << '\'' << f2.family() << "," << f2.pointSize() << ","
    << f2.weight() << "," << f2.italic(); //  << "," << f2.charSet() << '\'';

    doc->setSection("fonts");
    doc->setStringEntry("hebfont1", hf.latin1());

    //    doc->saveConfig(confFile.latin1());
    doc->saveProperties();
    view->slotFontChanged();
    repaint();


  }
  else
  {
    // the user cancelled the dialog
  }

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotPropPfade()
{
  statusBar()->message(tr("Pfadeinstellungen..."));

  pdlg =  new BPathDlg(this, "Rename", true);
  connect(pdlg->book_push, SIGNAL(clicked()), this, SLOT(slotNBookDir()));
  connect(pdlg->tmp_push, SIGNAL(clicked()), this, SLOT(slotNTmpDir()));
  connect(pdlg->out_push, SIGNAL(clicked()), this, SLOT(slotNOutDir()));
  connect(pdlg->exempl_push, SIGNAL(clicked()), this, SLOT(slotNExemplDir()));

  doc->setSection("kern");
  QString bd(doc->getStringEntry("BookDir").c_str());
  QString td(doc->getStringEntry("TempDir").c_str());
  QString od(doc->getStringEntry("OutDir").c_str());
  QString ed(doc->getStringEntry("ExemplDir").c_str());

  pdlg->bookdir->setText(bd);
  pdlg->tmpdir->setText(td);
  pdlg->outdir->setText(od);
  pdlg->exempldir->setText(ed);

  if (pdlg->exec() == 1 )
  {  // ok;
    doc->setSection("kern");
    doc->setStringEntry("BookDir", pdlg->bookdir->text().latin1());
    doc->setStringEntry("TempDir", pdlg->tmpdir->text().latin1());
    doc->setStringEntry("OutDir", pdlg->outdir->text().latin1());
    doc->setStringEntry("ExemplDir", pdlg->exempldir->text().latin1());

    kern->setzBuchVerzeichnis(doc->getStringEntry("BookDir"));
    kern->setzTempVerzeichnis(doc->getStringEntry("TempDir"));
    kern->setzOutVerzeichnis(doc->getStringEntry("OutDir"));

    doc->saveProperties();
    bookToolBar->scanBookDir();
    if (viewDocLst->isOn())
      view->showDocList(true);

  }
  //  else cout << "Abbruch" << endl;



  statusBar()->message(tr("Ready."));
}


/** setzt ein neues Bcherverzeichnis */
void QtBitanaApp::slotNBookDir()
{
  //                       bc->getStringEntry("BookDir");
  QString newdir = QFileDialog::getExistingDirectory(pdlg->bookdir->text(), this, tr("Buchverzeichnis..."));
  if(!newdir.isEmpty())
  {
    pdlg->bookdir->setText(newdir);
  }
}
/** setzt ein neues Tmp-Verzeichnis */
void QtBitanaApp::slotNTmpDir()
{

  QString newdir = QFileDialog::getExistingDirectory(pdlg->tmpdir->text(), this, tr("Temp-Verzeichnis..."));
  if(!newdir.isEmpty())
  {
    pdlg->tmpdir->setText(newdir);
  }
}
/** setzt ein neues Out-Verzeichnis */
void QtBitanaApp::slotNOutDir()
{

  QString newdir = QFileDialog::getExistingDirectory(pdlg->outdir->text(), this, tr("Ausgabeverzeichnis..."));
  if(!newdir.isEmpty())
  {
    pdlg->outdir->setText(newdir);
  }
}

/** setzt ein neues Beispiel / Sucheinstellungen Verzeichnis */
void QtBitanaApp::slotNExemplDir()
{

  QString newdir = QFileDialog::getExistingDirectory(pdlg->exempldir->text(), this, tr("Beispiel-/Sucheinstellungsverzeichnis..."));
  if(!newdir.isEmpty())
  {
    pdlg->exempldir->setText(newdir);
  }
}

void QtBitanaApp::slotWrtBuch()
{
  statusBar()->message(tr("Wrterbuchwahl..."));

  wbdlg =  new QtWbdlg(this, "Rename", true);
  doc->setSection("wrt");// setzen der Vorgabe
  int wb = (doc->getIntEntry("WortBuchId", 0));
  wbdlg->wb_grp->setButton(wb);

  if (wbdlg->exec() == 1 )
  {  // ok;
    wb = wbdlg->wb_grp->selectedId();
    QString wb_name = wbdlg->wb_grp->selected()->name();

    doc->setSection("wrt");
    doc->setIntEntry("WortBuchId", wb);
    doc->setStringEntry("WrtBuchBut", wb_name.latin1());

    if (wb_name == "wb_1" ) doc->setStringEntry("WortBuch", "kuhebdeu.lex");
    if (wb_name == "wb_2" ) doc->setStringEntry("WortBuch", "mihebdeu.lex");
    if (wb_name == "wb_3" )  doc->setStringEntry("WortBuch", "lahebdeu.lex");

    doc->saveProperties();
  }
  //  else cout << "Abbruch" << endl;

  statusBar()->message(tr("Ready."));
}


void QtBitanaApp::slotViewToolBar(bool toggle)
{
  statusBar()->message(tr("Toggle toolbar..."));
  ///////////////////////////////////////////////////////////////////
  // turn Toolbar on or off

  if (toggle== false)
  {
    fileToolbar->hide();
  }
  else
  {
    fileToolbar->show();
  };

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotViewStatusBar(bool toggle)
{
  statusBar()->message(tr("Toggle statusbar..."));
  ///////////////////////////////////////////////////////////////////
  //turn Statusbar on or off

  if (toggle == false)
  {
    statusBar()->hide();
  }
  else
  {
    statusBar()->show();
  }

  statusBar()->message(tr("Ready."));
}

void QtBitanaApp::slotViewParaWindow(bool toggle)
{
  statusBar()->message(tr("Toggle Parameter Window..."));
  ///////////////////////////////////////////////////////////////////
  //turn Parameterwindow  on or off

  if (toggle == false)
  {
    view->showEditWindow(false);
    searchInText->setEnabled(false);

  }
  else
  {
    view->showEditWindow(true);
    searchInText->setEnabled(true);
  }

  statusBar()->message(tr("Ready."));
}

// Umschalten Ergebniss - Baum
void QtBitanaApp::slotViewDocList(bool toggle)
{
  statusBar()->message(tr("Toggle Doc List..."));
  ///////////////////////////////////////////////////////////////////
  //turn Parameterwindow  on or off

  if (toggle == false)
  {
    view->showDocList(false);
  }
  else
  {
    view->showDocList(true);
  }

  statusBar()->message(tr("Ready."));
}

/** Suche (Kernaufruf) laut Einstellungen */

void QtBitanaApp::slotSearch()
{

  bookToolBar->slotReturnPressed();
  doc->setSection("qtbitana");
  int sel = doc->getIntEntry("tab_sel");
  qApp->processEvents();
  /*
    doc->setSection("kern");
    kern->setzBuchVerzeichnis(doc->getStringEntry("BookDir"));
    kern->setzTempVerzeichnis(doc->getStringEntry("TempDir"));
    kern->setzOutVerzeichnis(doc->getStringEntry("OutDir"));
  */

  doc->setSection("book");
  QString buch = doc->getStringEntry("book", "genesis");
  int kvon = doc->getIntEntry("kap_von", 1);
  int vvon = doc->getIntEntry("vers_von",1);
  int kbis = doc->getIntEntry("kap_bis", 1);
  int vbis = doc->getIntEntry("vers_bis",10);
  int vpos = doc->getIntEntry("pos_von");
  int bpos = doc->getIntEntry("pos_bis");

  bool modi, int1 = false;
  int rstat;
  QString resfile;
  QString resfile2;		// Ergebnisdatei


  QString wlist;
  QString  sword;

  int wn;


  // Suche entsprechend des Tabreiters

  switch (sel)
  {

  case 0:
    // Anzeige
    doc->setSection("anz");
    if (doc->getIntEntry("anz_chk_ba") == 2)
    {
      resfile = "anz_abschnitt.bta";
      doc->setSection("book");
      rstat = kern->lesBibelAbschnitt(buch, kvon, vvon, kbis, vbis, resfile);
      suchResult(rstat, resfile);
    }

    doc->setSection("anz");
    if (doc->getIntEntry("anz_chk_gem") == 2)
    {
      resfile = "anz_gematria.bta";
      doc->setSection("book");
      rstat = kern->lesBibelAbschnittAnalyse(buch, kvon, vvon, kbis, vbis, resfile);  //"de");
      suchResult(rstat, resfile);
    }

    doc->setSection("anz");

    if (doc->getIntEntry("anz_chk_mod") == 2)
      modi = true;
    else
      modi = false;

    if (doc->getIntEntry("anz_chk_int") == 2)
    {
      resfile = "anz_intervall.bta";
      rstat = kern->lesLesIntervall(buch, doc->getIntEntry("anz_int"),
                                    doc->getIntEntry("anz_dar"), vpos, bpos, resfile, modi);
      suchResult(rstat, resfile);
    }


    break;

  case 1:
    // Intervallsuche
    doc->setSection("itv");

    if (doc->getIntEntry("itv_chk_mod") == 2)
      modi = true;
    else
      modi = false;
    if (doc->getIntEntry("itv_chk_inv") == 2)
    {

      int ri = 0;
      if ((doc->getIntEntry("itv_chk_vor") == 2) && (doc->getIntEntry("itv_chk_rue") == 0))
        ri = 1;
      if ((doc->getIntEntry("itv_chk_vor") == 0) && (doc->getIntEntry("itv_chk_rue") == 2))
        ri = 2;

      resfile = "itv_intervall.bta";
      rstat = kern->lesListeIntervall(buch, doc->getStringEntry("itv_w"), doc->getIntEntry("itv_ivv"),
                                      doc->getIntEntry("itv_ivb"), vpos, bpos, ri, doc->getIntEntry("itv_grp_sort"),
                                      modi, true, resfile);


      suchResult(rstat, resfile);
    }


    if (doc->getIntEntry("itv_chk_blk") == 2)
    {
      doc->setSection("itv");

      resfile = "itv_block.bta";
      rstat = kern->lesListeIntervallBlock(buch, doc->getStringEntry("itv_w"), vpos, bpos,
                                           doc->getIntEntry("itv_bsel"), doc->getIntEntry("itv_bbis"), modi, resfile);
      suchResult(rstat, resfile);
    }
    break;

  case 2:
    // Nachbarschaftsprfung
    doc->setSection("nbr");
    resfile = "nbr_nachbar.bta";
    resfile2 =  "nbr_abbildung.bta";

    if (doc->getIntEntry("nbr_chk_mod") == 2)
      modi = true;
    else
      modi = false;

    if (doc->getIntEntry("nbr_chk_int1") == 2)
      int1 = true;
    else
      int1 = false;


    rstat = 0;
    rstat = kern->lesPruefNachbar(buch,  doc->getStringEntry("nbr_w1"), doc->getStringEntry("nbr_w2"),
                                  doc->getStringEntry("nbr_w3"), int1, modi, doc->getIntEntry("nbr_nr"), resfile, resfile2);


    suchResult(rstat, resfile);
    break;

  case 3:
    // Nachbarschaftssuche
    doc->setSection("wrt");
    if (doc->getIntEntry("wrt_find") == 2)
    {
      resfile = "wrt_finddat.bta";
      resfile2 = "wrt_findabb.bta";
      rstat = 0;
      rstat = kern->lesFindNachbar(buch, doc->getStringEntry("wrt_w1"), doc->getIntEntry("wrt_inv"),
                                   doc->getLongEntry("wrt_spos"), resfile, resfile2, doc->getStringEntry("WortBuch","kuhebdeu.lex"));

      suchResult(rstat, resfile);

    }

    doc->setSection("wrt");
    if (doc->getIntEntry("wrt_such") == 2)
    {
      // Bearbeitungsart 33 - Parameter ??
      resfile = "wrt_vollsuche.bta";
      rstat = 0;
      rstat = kern->lesSuchNachbar(buch, doc->getStringEntry("wrt_w2"), resfile, doc->getStringEntry("WortBuch","kuhebdeu.lex"));
      suchResult(rstat, resfile);
    }
    break;

  case 4:
    // Matrixsuche
    doc->setSection("mas");
    wlist = "";
    if (doc->getIntEntry("mas_chk_mod") == 2)
      modi = true;
    else
      modi = false;

    if (doc->getIntEntry("mas_chk_int1") == 2)
      int1 = true;
    else
      int1 = false;

    for (wn=1; wn<=10; wn++)
    {
      sword = "mas_w" + QString::number(wn);
      if ( !(doc->getStringEntry(sword)).empty() )
      {
        wlist.append(doc->getStringEntry(sword)) ;
        wlist.append("\t");
      }
    }
    resfile = "mas_matrix.bta";

    if (doc->getIntEntry("mas_chk_mod") == 2)
      modi = true;
    else
      modi = false;

    rstat = 0;
    rstat = kern->lesSuchMatrix(buch, wlist, int1, modi, resfile);
    suchResult(rstat, resfile);
    break;

  default:
    break;

  }

}

// Start Suche - Progressbar in der Statusleiste

void QtBitanaApp::startProgressBar(string text)
{
  QString te = text;
  progress->show();
  progress->setProgress(0);
  statusBar()->message(te);
  qApp->processEvents();
}

bool QtBitanaApp::slotProgressStep(int i)
{
  progress->setProgress(i);
  //    qApp->processEvents();
  return true;
}
void QtBitanaApp::stopProgressBar()
{
  progress->hide();
  statusBar()->message("Ready...");

}
// Suche mit Fehlerauswertung
void QtBitanaApp::suchResult(int stat, QString resfile)
{
  searchInText->setEnabled(false);

  if (stat)
  {
    QString ftext = tr("Sucheergebnis - Status: ");
    ftext += QString::number(stat);
    ftext += " !\nText: ";
    ftext += kern->lesFehlertext(stat).c_str();
    ftext += " !\nErgebnisdatei: ";
    ftext += resfile;
    QMessageBox::information(this, tr("Fehler"),
                             ftext,
                             QMessageBox::Ok ); //, QMessageBox::Cancel);
  }
  statusBar()->message(tr("Aufbau Anzeige..."));
  qApp->processEvents();
  view->markFileItem(resfile);

  searchInText->setEnabled(true);
  statusBar()->message(tr("Ready - " ));
  qApp->processEvents();

}

void QtBitanaApp::slotHelpAbout()
{
  QMessageBox::about(this,tr("About..."),
                     tr("QtBitana\nVersion " VERSION " - \n$Rev: 220 $\n1999-2009 by Heinz Schumann \n& Hans-Juergen Schumann\nhttp://www.bitana.de/\n") );

}

