/***************************************************************************
                          qtbitana.h  -  description
                             -------------------
    begin                : Don Aug  8 22:46:53 CEST 2002
    copyright            : (C) 2002 by Heinz & Hans-Jrgen Schumann
    email                : heinz@bitana.de; hans@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QTBITANA_H
#define QTBITANA_H

// include files for QT
#include <qapp.h>
#include <qmainwindow.h>
#include <qaction.h>
#include <qmenubar.h>
#include <qpopupmenu.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qstatusbar.h>
#include <qwhatsthis.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qmsgbox.h>
#include <qfiledialog.h>
#include <qprinter.h>
#include <qpainter.h>
#include <qprogressbar.h>
#include <qbuttongroup.h>
#include <qtimer.h>


#include <string>

// application specific includes
#include "qtbitanaview.h"
#include "qtbitanadoc.h"
#include "cbitanaconfig.h"
#include "bibtext.h"
#include "ckerninterface.h"
#include "bpathdlg.h"
#include "qtwrtbdlg.h"

/**
  * This Class is the base class for your application. It sets up the main
  * window and providing a menubar, toolbar
  * and statusbar. For the main view, an instance of class QtBitanaView is
  * created which creates your view.
  */
class QtBitanaApp : public QMainWindow
{
    Q_OBJECT

public:
    /** construtor */
    QtBitanaApp(const QString conf = "bitana.conf");
    //    QtBitanaApp();
    /** destructor */
    ~QtBitanaApp();
    /** initializes all QActions of the application */
    void initActions();
    /** initMenuBar creates the menu_bar and inserts the menuitems */
    void initMenuBar();
    /** this creates the toolbars. Change the toobar look and add new toolbars in this
     * function */
    void initToolBar();
    /** setup the statusbar */
    void initStatusBar();
    /** setup the document*/
    void initDoc();
    /** setup the mainview*/
    void initView();

    /** overloaded for Message box on last window exit */
    bool queryExit();
    bool noconfig;		// Fehler in Konfigurationsdatei
	
    void startProgressBar(string text);
    void stopProgressBar();

public slots:

    /** generate a new document in the actual view */
    void slotFileNew();
    /** open a document */
    void slotFileOpen();
    /** save a document */
    void slotFileSave();
    /** save a document under a different filename*/
    void slotFileSaveAs();
    /** close the actual file */
    void slotFileClose();
    /** print the actual file */
    void slotFilePrint();
    /** exits the application */
    void slotFileQuit();
    /** put the marked text/object into the clipboard*/
    void slotPropFont();
    /** put the marked text/object into the clipboard and remove
     * it from the document */
    void slotPropCut();
    /** paste the clipboard into the document*/
    void slotPropPfade();
    /** slot Wrterbuchauswahl */	
    void slotWrtBuch();
    /** toggle the toolbar*/
    void slotViewToolBar(bool toggle);
    /** toggle the statusbar*/
    void slotViewStatusBar(bool toggle);
    /** toggle the parameter Window*/
    void slotViewParaWindow(bool toggle);
    /** toggle Doc List Window */
    void slotViewDocList(bool toggle);

    /** Suche im Text (Kernaufruf) laut Einstellungen */
    void slotSearch();

    /** Pfadeinstellungen **/
    void slotNBookDir();
    void slotNTmpDir();
    void slotNOutDir();
    void slotNExemplDir();

    /** shows an about dlg*/
    void slotHelpAbout();

    // berlagerung aus CProgressevent
    //    virtual bool eventLoop(int);
    bool slotProgressStep(int i);
private:

    /** view is the main widget which represents your working area. The View
     * class should handle all events of the view widget.  It is kept empty so
     * you can create your view according to your application's needs by
     * changing the view class.
     */
    QtBitanaView *view;
    /** doc represents your actual document and is created only once. It keeps
     * information such as filename and does the serialization of your files.
     */
    QtBitanaDoc *doc;

    /** file_menu contains all items of the menubar entry "File" */
    QPopupMenu *fileMenu;
    /** edit_menu contains all items of the menubar entry "Edit" */
    QPopupMenu *propMenu;
    /** view_menu contains all items of the menubar entry "View" */
    QPopupMenu *viewMenu;
    /** view_menu contains all items of the menubar entry "Help" */
    QPopupMenu *helpMenu;
    /** the main toolbar */
    QToolBar *fileToolbar;
    /** Book Tool Bar */
    BibText *bookToolBar;
    /** Dialog Pfadeinstellungen */
    BPathDlg *pdlg;
    /** Dialog Wrterbuchwahl */
    QtWbdlg *wbdlg;

    /** actions for the application initialized in initActions() and used to en/disable them
      * according to your needs during the program */
    QAction *fileNew;
    QAction *fileOpen;
    QAction *fileSave;
    QAction *fileSaveAs;
    QAction *fileClose;
    QAction *filePrint;
    QAction *fileQuit;

    //    QAction *propCut;
    QAction *propFont;
    QAction *propPfade;
    QAction *propWbdlg;

    QAction *viewToolBar;
    QAction *viewStatusBar;
    QAction *viewParaWindow;
    QAction *searchInText;
    QAction *viewDocLst;

    QAction *helpAboutApp;

    CKernInterface *kern;

    // Config - Objekt
    CBitanaConfig *bc;
    QString confFile;
    QTimer timer;
    QProgressBar *progress;

    void suchResult(int i, QString s);

private slots:


    void slotWindowClosed();
};
#endif

