/***************************************************************************
                          qtbitanaview.cpp  -  description
                             -------------------
    begin                : Don Aug  8 22:46:53 CEST 2002
    copyright            : (C) 2002 by Heinz & Hans-Jrgen Schumann
    email                : heinz@bitana.de; hans@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qtbitanaview.h"


#include <qpushbutton.h>
#include <qsize.h>
#include <qfile.h>
#include <qdir.h>
#include <qtextstream.h>
#include <qstrlist.h>
#include <qnamespace.h>
#include <qcheckbox.h>
#include <qbuttongroup.h>
#include <qspinbox.h>
#include <qlabel.h>

#include <string>
#include <iostream>

#define STRSEP "\t"

QtBitanaView::QtBitanaView(QWidget *parent, QtBitanaDoc *d) : QWidget(parent)
{

    doc = d;
    codec = QTextCodec::codecForName("ISO 8859-8-I");
    //		conf = bc;
    initHebFont();

    hi = new BHebInp(this);
    hi->init(doc);

    tab = new QtBitanaModi(this);


    // Tabgr�se an inp-Gr�se anpassen

    QSize s = hi->maximumSize();
    tab->setMinimumSize(200, s.height() );
    tab->setMaximumWidth(2000);


    // Doc-(Ergebnissdateien)Widgets als Splitter zusammensetzen

    hs = new QSplitter(QSplitter::Horizontal, this);

    // DocList als Listview (links)

    dlst = new BDocLst(hs);
    hs->setResizeMode(dlst, QSplitter::FollowSizeHint);
    dlst->resize(10, 0);

    // unten rechts 2 Fenster mit Splitter teilen
    vs = new QSplitter(QSplitter::Vertical, hs);

    // Kopf eines Dokuments
    dkop = new QMultiLineEdit(vs);
    vs->setResizeMode(dkop, QSplitter::FollowSizeHint);
    dkop->resize(0, 20);

    // �erlagerung der Ausgabewidgets mit Stacktechnik

    docw = new QWidgetStack(vs);
    //   docw->showMaximized();

    dtab = new QListView(docw);
    dtab->setSorting(-1);
    dtab->setAllColumnsShowFocus(true);
    docw->addWidget(dtab, 1);
    connect(dtab, SIGNAL(rightButtonPressed(QListViewItem*,const QPoint&,int) ), this, SLOT(slotMenTab(QListViewItem*,const QPoint&,int)));


    dmat = new BTextMatrix(docw);
    dmat->setFont(hfont1);
    docw->addWidget(dmat, 2);


    dpix = new QWidget(docw);
    docw->addWidget(dpix, 3);

    // Layout aufbauen / anpassen

    vl = new QVBoxLayout(this);
    hl = new QHBoxLayout();

    vl->addLayout(hl, 0);
    vl->addSpacing(1);
    vl->addWidget(hs, 2);


    hl->addWidget(hi, 0, AlignTop);
    hl->addSpacing(1);
    hl->addWidget(tab, 0, AlignTop);

    vl->activate();
    initZMenu();

    /** connect doc with the view*/
    connect(doc, SIGNAL(documentChanged()), this, SLOT(slotDocumentChanged()));
    connect(tab->TabWidget, SIGNAL(currentChanged(QWidget *)), this, SLOT(slotTabChanged(QWidget *)));

    // Aktionen aus Tabwidget connektieren
    // Textanzeige

    connect(tab->anz_chk_ba, SIGNAL(stateChanged(int)), this, SLOT(slotAnzBa(int)));
    connect(tab->anz_chk_gem, SIGNAL(stateChanged(int)), this, SLOT(slotAnzGem(int)));
    connect(tab->anz_chk_int, SIGNAL(stateChanged(int)), this, SLOT(slotAnzInt(int)));

    connect(tab->anz_chk_mod, SIGNAL(stateChanged(int)), this, SLOT(slotAnzMod(int)));
    connect(tab->anz_int, SIGNAL(valueChanged(int)), this, SLOT(slotAnzLInt(int)));
    connect(tab->anz_dar, SIGNAL(valueChanged(int)), this, SLOT(slotAnzDar(int)));

    // Intervallsuche

    connect(tab->itv_wb, SIGNAL(clicked()), this, SLOT(slotItvWset()));
    connect(tab->itv_chk_mod, SIGNAL(stateChanged(int)), this, SLOT(slotItvMod(int)));
    connect(tab->itv_chk_inv, SIGNAL(stateChanged(int)), this, SLOT(slotItvInv(int)));

    connect(tab->itv_ivv, SIGNAL(valueChanged(int)), this, SLOT(slotItvIvv(int)));
    connect(tab->itv_ivb, SIGNAL(valueChanged(int)), this, SLOT(slotItvIvb(int)));


    connect(tab->itv_chk_vor, SIGNAL(stateChanged(int)), this, SLOT(slotItvVor(int)));
    connect(tab->itv_chk_rue, SIGNAL(stateChanged(int)), this, SLOT(slotItvRue(int)));

    connect(tab->itv_grp_sort, SIGNAL(clicked(int)), this, SLOT(slotItvSort(int)));

    connect(tab->itv_chk_blk, SIGNAL(stateChanged(int)), this, SLOT(slotItvBlk(int)));
    connect(tab->itv_bbis, SIGNAL(valueChanged(int)), this, SLOT(slotItvBbis(int)));
    connect(tab->itv_bsel, SIGNAL(valueChanged(int)), this, SLOT(slotItvBsel(int)));


    // Nacbarschaftsprfung

    connect(tab->nbr_w1b, SIGNAL(clicked()), this, SLOT(slotNbrW1set()));
    connect(tab->nbr_w2b, SIGNAL(clicked()), this, SLOT(slotNbrW2set()));
    connect(tab->nbr_w3b, SIGNAL(clicked()), this, SLOT(slotNbrW3set()));

    connect(tab->nbr_chk_int1, SIGNAL(stateChanged(int)), this, SLOT(slotNbrInt1(int)));
    connect(tab->nbr_chk_mod,  SIGNAL(stateChanged(int)), this, SLOT(slotNbrMod(int)));

    // Nachbarschafts / Wortsuche

    connect(tab->wrt_find, SIGNAL(stateChanged(int)), this, SLOT(slotWrtFind(int)));
    connect(tab->wrt_such, SIGNAL(stateChanged(int)), this, SLOT(slotWrtSuch(int)));

    connect(tab->wrt_wb1, SIGNAL(clicked()), this, SLOT(slotWrtW1set()));
    connect(tab->wrt_wb2, SIGNAL(clicked()), this, SLOT(slotWrtW2set()));

    connect(tab->wrt_spos, SIGNAL(valueChanged(int)), this, SLOT(slotWrtSpos(int)));
    connect(tab->wrt_inv, SIGNAL(valueChanged(int)), this, SLOT(slotWrtInv(int)));

    // Matrixsuche

    connect(tab->mas_w1b, SIGNAL(clicked()), this, SLOT(slotMasW1set()));
    connect(tab->mas_w2b, SIGNAL(clicked()), this, SLOT(slotMasW2set()));
    connect(tab->mas_w3b, SIGNAL(clicked()), this, SLOT(slotMasW3set()));
    connect(tab->mas_w4b, SIGNAL(clicked()), this, SLOT(slotMasW4set()));
    connect(tab->mas_w5b, SIGNAL(clicked()), this, SLOT(slotMasW5set()));
    connect(tab->mas_w6b, SIGNAL(clicked()), this, SLOT(slotMasW6set()));
    connect(tab->mas_w7b, SIGNAL(clicked()), this, SLOT(slotMasW7set()));
    connect(tab->mas_w8b, SIGNAL(clicked()), this, SLOT(slotMasW8set()));
    connect(tab->mas_w9b, SIGNAL(clicked()), this, SLOT(slotMasW9set()));
    connect(tab->mas_w10b, SIGNAL(clicked()), this, SLOT(slotMasW10set()));

    connect(tab->mas_clear, SIGNAL(clicked()), this, SLOT(slotMasClear()));
    connect(tab->mas_chk_mod, SIGNAL(stateChanged(int)), this, SLOT(slotMasMod(int)));
    connect(tab->mas_chk_int1, SIGNAL(stateChanged(int)), this, SLOT(slotMasInt1(int)));
    // Ergebnisliste

    connect(dlst, SIGNAL(selectionChanged(QListViewItem *)), this, SLOT(slotResDoc(QListViewItem *)));

    slotFontChanged();
    slotDocumentChanged();
}

QtBitanaView::~QtBitanaView()
{}

void QtBitanaView::slotDocumentChanged()
{
    //  update the doc / view

    hi->getInputStack();

    doc->setSection("qtbitana");
    tab->TabWidget->setCurrentPage(doc->getIntEntry("tab_sel"));

    // Textanzeige

    doc->setSection("anz");

    if ( doc->getIntEntry("anz_chk_ba") == 2)
        tab->anz_chk_ba->setChecked(true);
    else
        tab->anz_chk_ba->setChecked(false);

    if ( doc->getIntEntry("anz_chk_gem") == 2)
        tab->anz_chk_gem->setChecked(true);
    else
        tab->anz_chk_gem->setChecked(false);

    if ( doc->getIntEntry("anz_chk_int") == 2)
        tab->anz_chk_int->setChecked(true);
    else
        tab->anz_chk_int->setChecked(false);

    if ( doc->getIntEntry("anz_chk_mod") == 2)
        tab->anz_chk_mod->setChecked(true);
    else
        tab->anz_chk_mod->setChecked(false);

    tab->anz_int->setValue(doc->getIntEntry("anz_int"));
    tab->anz_dar->setValue(doc->getIntEntry("anz_dar"));


    // Intervallsuche

    doc->setSection("itv");

    string s = doc->getStringEntry("itv_w");

    QString word(s.c_str());
    tab->itv_w->setText(codec->toUnicode(word));

    if ( doc->getIntEntry("itv_chk_mod") == 2)
        tab->itv_chk_mod->setChecked(true);
    else
        tab->itv_chk_mod->setChecked(false);

    if ( doc->getIntEntry("itv_chk_inv") == 2)
        tab->itv_chk_inv->setChecked(true);
    else
        tab->itv_chk_inv->setChecked(false);
    slotItvInv(doc->getIntEntry("itv_chk_inv"));

    tab->itv_ivv->setValue(doc->getIntEntry("itv_ivv"));
    tab->itv_ivb->setValue(doc->getIntEntry("itv_ivb"));


    if ( doc->getIntEntry("itv_chk_vor") == 2)
        tab->itv_chk_vor->setChecked(true);
    else
        tab->itv_chk_vor->setChecked(false);

    if ( doc->getIntEntry("itv_chk_rue") == 2)
        tab->itv_chk_rue->setChecked(true);
    else
        tab->itv_chk_rue->setChecked(false);

    switch (doc->getIntEntry("itv_grp_sort"))
    {
    case 0:
        tab->itv_grp_sort->setButton(2);
        break;
    case 1:
        tab->itv_grp_sort->setButton(0);
        break;
    case 2:
        tab->itv_grp_sort->setButton(1);
        break;
    default:
        tab->itv_grp_sort->setButton(doc->getIntEntry("itv_grp_sort"));
    }

    //   tab->itv_grp_sort->setButton(doc->getIntEntry("itv_grp_sort"));

    if ( doc->getIntEntry("itv_chk_blk") == 2)
        tab->itv_chk_blk->setChecked(true);
    else
        tab->itv_chk_blk->setChecked(false);
    slotItvBlk(doc->getIntEntry("itv_chk_blk"));

    tab->itv_bbis->setValue(doc->getIntEntry("itv_bbis"));
    tab->itv_bsel->setValue(doc->getIntEntry("itv_bsel"));


    // Nacbarschaftsprfung

    doc->setSection("nbr");

    s = doc->getStringEntry("nbr_w1");
    word = s.c_str();
    tab->nbr_w1->setText(codec->toUnicode(word));

    s = doc->getStringEntry("nbr_w2");
    word = s.c_str();
    tab->nbr_w2->setText(codec->toUnicode(word));

    s = doc->getStringEntry("nbr_w3");
    word = s.c_str();
    tab->nbr_w3->setText(codec->toUnicode(word));

    if ( doc->getIntEntry("nbr_chk_int1") == 2)
        tab->nbr_chk_int1->setChecked(true);
    else
        tab->nbr_chk_int1->setChecked(false);

    if ( doc->getIntEntry("nbr_chk_mod") == 2)
        tab->nbr_chk_mod->setChecked(true);
    else
        tab->nbr_chk_mod->setChecked(false);


    // Nachbarschafts / Wortsuche

    doc->setSection("wrt");

    s = doc->getStringEntry("wrt_w1");
    word = s.c_str();
    tab->wrt_w1->setText(codec->toUnicode(word));

    s = doc->getStringEntry("wrt_w2");
    word = s.c_str();
    tab->wrt_w2->setText(codec->toUnicode(word));

    tab->wrt_spos->setValue(doc->getLongEntry("wrt_spos"));
    tab->wrt_inv->setValue(doc->getIntEntry("wrt_inv"));

    if (doc->getIntEntry("wrt_find") == 2)
    {
        tab->wrt_find->setChecked(true);
        slotWrtFind(2);
    }
    else
    {
        tab->wrt_find->setChecked(false);
        slotWrtFind(0);
    }

    if (doc->getIntEntry("wrt_such") == 2)
    {
        tab->wrt_such->setChecked(true);
        slotWrtSuch(2);
    }
    else
    {
        tab->wrt_such->setChecked(false);
        slotWrtSuch(0);
    }

    // Matrixsuche

    doc->setSection("mas");

    s = doc->getStringEntry("mas_w1");
    word = s.c_str();
    tab->mas_w1->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w2");
    word = s.c_str();
    tab->mas_w2->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w3");
    word = s.c_str();
    tab->mas_w3->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w4");
    word = s.c_str();
    tab->mas_w4->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w5");
    word = s.c_str();
    tab->mas_w5->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w6");
    word = s.c_str();
    tab->mas_w6->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w7");
    word = s.c_str();
    tab->mas_w7->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w8");
    word = s.c_str();
    tab->mas_w8->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w9");
    word = s.c_str();
    tab->mas_w9->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_w10");
    word = s.c_str();
    tab->mas_w10->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t1");
    word = s.c_str();
    tab->mas_t1->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t2");
    word = s.c_str();
    tab->mas_t2->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t3");
    word = s.c_str();
    tab->mas_t3->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t4");
    word = s.c_str();
    tab->mas_t4->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t5");
    word = s.c_str();
    tab->mas_t5->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t6");
    word = s.c_str();
    tab->mas_t6->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t7");
    word = s.c_str();
    tab->mas_t7->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t8");
    word = s.c_str();
    tab->mas_t8->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t9");
    word = s.c_str();
    tab->mas_t9->setText(codec->toUnicode(word));

    s = doc->getStringEntry("mas_t10");
    word = s.c_str();
    tab->mas_t10->setText(codec->toUnicode(word));

    if ( doc->getIntEntry("mas_chk_int1") == 2)
        tab->mas_chk_int1->setChecked(true);
    else
        tab->mas_chk_int1->setChecked(false);

    
    if ( doc->getIntEntry("mas_chk_mod") == 2)
        tab->mas_chk_mod->setChecked(true);
    else
        tab->mas_chk_mod->setChecked(false);


	
}


/** initialisiert die heb-Fonts aus dem doc-Objekt */
bool QtBitanaView::initHebFont()
{

    doc->setSection("fonts");

    // zeitweiliges Umladen
    if (!doc->isEntry("hebfont1"))
    {
        doc->setSection("qtbitana");
        string ft = doc->getStringEntry("hebfont1");
        doc->setSection("fonts");
        doc->setStringEntry("hebfont1", ft);
    }
    QString hf = (doc->getStringEntry("hebfont1",  "'misc-fixed,19,50,0,8'")).c_str();

    QString family(hf.mid(1,hf.find(',')-1));
    hf = hf.mid(hf.find(',')+1);

    int point = hf.left(hf.find(',')).toInt();
    hf = hf.mid(hf.find(',')+1);

    int weight = hf.left(hf.find(',')).toInt();
    hf = hf.mid(hf.find(',')+1);

    bool ital = hf.left(hf.find(',')).toInt();
    hf = hf.mid(hf.find(',')+1);

    //	int set = hf.left(hf.find('\'')).toInt();

    hfont1 = QFont(family, point, weight, ital); // , QFont::CharSet(set));
    //  setFont(hfont1);
    return true;
}

/** Eingabefenster zeigen **/
void QtBitanaView::showEditWindow(bool show)
{

    if (show)
    {
        hi->show();
        tab->show();
    }
    else
    {
        hi->hide();
        tab->hide();
    }
    //  vl->activate();
}

void QtBitanaView::showDocList(bool show)
{

    if (show)
    {

        dlst->show();
        doc->setSection("kern");
        resultdir = doc->getStringEntry("OutDir", "out").c_str();
        dlst->scanResultList(resultdir);


    }
    else
        dlst->hide();
    //  vl->activate();
}

/** Marked the fileItem in DocList and show the Document */
void QtBitanaView::markFileItem(QString file)
{

    QListViewItem *ifile, *igroup, *item;
    int i;
    if (dlst->scanResultList(resultdir) == 0)
        return;

    if ((ifile = dlst->itemFile(file)) == NULL)
        return;
    if (ifile->isSelected())
        (ifile->listView())->setSelected(ifile, false);
    igroup =  ifile->parent();

    item = dlst->firstChild();
    for (i=0; i < dlst->childCount(); i++)
    {
        if (item == igroup)
            item->setOpen(true);
        else
            item->setOpen(false);
        item = item->nextSibling();
    }
    (ifile->listView())->setSelected(ifile, true);
}

/** Ausgabe eines Ergebnisdokuments
in die entsprechenden Fenster */


bool QtBitanaView::showDoc(QString file)
{

    QFile f1;

    f1.setName(file);
    if (!f1.open(IO_ReadOnly))
        QMessageBox::warning(0,tr("Cannot find the file"),
                             f1.name());
    QTextStream dat(&f1);

    QString s;
    QChar c;
    dkop->clear();
    int spalten = 0;
    dat.setEncoding(QTextStream::Latin1);
    while (!dat.atEnd())
    {
        s = dat.readLine();
        QString tmp = s;
        c = s.at(0);
        //    cout << "c= " << c << endl;
        if (c == '\a' )
        {         // Parameterzeile
            li_art = s.mid(1, s.find('\t')).toInt();
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_nr = s.left(s.find('\t')).toInt();
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_book = s.left(s.find('\t'));
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_wo1 =  s.left(s.find('\t'));
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_wo2 = s.left(s.find('\t'));
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_wo3 = s.left(s.find('\t'));
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_vonkv = s.left(s.find('\t'));
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_biskv = s.left(s.find('\t'));
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_vonint = s.left(s.find('\t')).toInt();
            s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
            li_bisint = s.left(s.find('\t')).toInt();
            s = s.mid(s.find('\t')+1);
            li_file = s;
            s = tmp;
            continue;               // ohne continue wird die Parameterzeile mit ausgegeben
        }

        if (c ==  '\b')
        {          // Tabellenbegin

            // s enth�t Spaltenausrichtung
            QString sricht = s.mid(1);

            // Testausgaben
            //      dkop->append("Tabellenbeginn");
            //      dkop->append(sricht);

            spalten = s.length() -1 ;
            dtab->clear();
            int i;
            for (i = dtab->columns()-1; i>= 0; i--)
                dtab->removeColumn(i);

            s = dat.readLine();       // Kopfzeile

            for (i = 0; i<spalten; i++)
            {
                dtab->addColumn(s.left(s.find('\t')));
                s = s.mid(s.find('\t')+1, s.length() - s.find('\t'));
                // Spaltenausrichtung
                if (sricht.at(i) == 'l')
                    dtab->setColumnAlignment(i,Qt::AlignLeft);
                if (sricht.at(i) == 'c')
                    dtab->setColumnAlignment(i,Qt::AlignHCenter);
                if (sricht.at(i) == 'r')
                    dtab->setColumnAlignment(i,Qt::AlignRight);
            }

            // Zeilen Ausgeben

            // Zeilen in Puffer lesen wegen inverser Ausgabe
            QStrList zeilen;
            while(!dat.atEnd())
            {                      // oder Tabellenende
                zeilen.prepend(dat.readLine());
            }

            char *ze;
            QListViewItem *zeile;
            for (ze = zeilen.first(); ze != 0; ze = zeilen.next())
            {
                s = ze;
                zeile = new QListViewItem(dtab);
                for (int i = 0; i<spalten; i++)
                {
                    zeile->setText(i, codec->toUnicode(s.left(s.find('\t'))));
                    s = s.mid(s.find('\t')+1, s.length() - s.find('\t') );
                }
            }
            s = "";
            docw->raiseWidget(dtab);
            dtab->show();
        } // Tabellenende

        if ( c == '\v' )
        {  // Beginn Matrix
            int spalten = s.toInt();
            dmat->clear();
            dmat->setSpalten(spalten);

            while (!dat.atEnd() )
            {
                s = dat.readLine();
                if (s.at(0) == '\e')
                    break;
                dmat->addMatrixLine(codec->toUnicode(s));
            }
            s = "";
            dmat->setZeilen(0);
            dmat->show();
            dmat->repaint();
            docw->raiseWidget(dmat);
            vs->refresh();

        } // Ende Matrix

        /*
           if (c ==  'G') {          // Beginn Grafikausgabe
         
                cout << " im Fenster";
                QPainter p;                       // our painter
                p.begin( dpix );                  // start painting the widget
                p.setPen( red );                  // red outline
                p.setBrush( yellow );             // yellow fill
                p.drawEllipse( 10, 20, 100,100 ); // 100x100 ellipse at position (10, 20)
                p.end();
                                          // painting done
            dpix->show();
            dpix->repaint();
            docw->raiseWidget(dpix);
            vs->refresh();
           }
        */
        //     dkop->setFont(hfont1);
        dkop->append(codec->toUnicode(s));  //s.latin1()));


        //    doc->setSection("hebinput");
        //    string s = doc->getStringEntry("word", "");
        //    QString word(s.c_str());
        //    dkop->append(codec->toUnicode(word));


    }
    vl->activate();
    return TRUE;
}

//-- PopUp Menus fuer Ergebnistabellen -----------------------------------------------------------

/** Initialisiert das popup-Men fr die Bearbeitung der Ergebniszeilen */
void QtBitanaView::initZMenu()
{

    zmenu = new QPopupMenu(this);
    zmenu->setFont(hfont1);
}

/** Men bei rechter Maustaste in Ergebnistabelle **/

void QtBitanaView::slotMenTab(QListViewItem* zeile,const QPoint& point,int i)
{
    // wenn i <0  dann wurde keine Zeile angeklickt
    if (i < 0)
        return;
    selzeile = zeile;    // selektierte Zeile
    zmenu->clear();
    QString s;
    // Zusammenbauen des Menus
    switch (li_art)
    {
    case 11:
        s = codec->fromUnicode(selzeile->text(1));
        if (!s.isEmpty())
            zmenu->insertItem(s +" -> Gematria", this, SLOT(slotZMen11_1()), 0, 1);
        break;

    case 12:
        s = codec->fromUnicode(selzeile->text(0));
        zmenu->insertItem(s +" -> Anzeige", this, SLOT(slotZMen12_1()), 0, 1);
        break;

    case 21:
        zmenu->insertItem("Textstelle", this, SLOT(slotZMen21_1()), 0, 1);
        zmenu->insertItem("Wortfinden", this, SLOT(slotZMen21_2()), 0, 2);
        break;

    case 22:
        zmenu->insertItem("Textstelle", this, SLOT(slotZMen22_1()), 0, 1);
        //      zmenu->insertItem("Wortanzeige", this, SLOT(slotZMen21_2()), 0, 2);
        break;

    case 31:
        zmenu->insertItem("Nachbarschaftsabbildung", this, SLOT(slotZMen31_1()), 0, 1);
        zmenu->insertItem("Wortfinden - " + codec->toUnicode(li_wo1), this, SLOT(slotZMen31_2()), 0, 2);
        zmenu->insertItem("Wortfinden - " + codec->toUnicode(li_wo2), this, SLOT(slotZMen31_3()), 0, 3);
        zmenu->insertItem("Wortfinden - " + codec->toUnicode(li_wo3), this, SLOT(slotZMen31_4()), 0, 4);
        zmenu->insertItem("Matrixsuche -> ", this, SLOT(slotZMen31_5()), 0, 5);
        break;

    case 32:
        zmenu->insertItem( "w2 <- " + selzeile->text(5) , this, SLOT(slotZMen32_1()), 0, 1);
        zmenu->insertItem( "w3 <- " + selzeile->text(5) , this, SLOT(slotZMen32_2()), 0, 2);
        zmenu->insertItem( "Matrix <- " + selzeile->text(5) , this, SLOT(slotZMen42()), 0, 3);

        break;

    case 33:
        zmenu->insertItem("w2 <- " + selzeile->text(9) , this, SLOT(slotZMen33_1()), 0, 1);
        zmenu->insertItem("w3 <- " + selzeile->text(9) , this, SLOT(slotZMen33_2()), 0, 2);
        zmenu->insertItem("Matrix <- " + selzeile->text(9) , this, SLOT(slotZMen43()), 0, 3);
        break;

    default:
        break;
    }
    zmenu->popup(point);

}

// Menpunkte aus den Ergebnistabellen

void QtBitanaView::slotZMen11_1()
{
    //  Aus bearbeitungsart 11 -> 12
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 0);

    doc->setSection("anz");
    doc->setIntEntry("anz_chk_ba", 0);
    doc->setIntEntry("anz_chk_gem", 2);

    QString s = codec->fromUnicode(selzeile->text(1));
    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->setStringEntry("Kap_vers_bis", s.latin1());
    doc->setStringEntry("Kap_vers_von", s.latin1());

    doc->newDoc();
    emit signalSearch();
}


void QtBitanaView::slotZMen12_1()
{
    //  Aus bearbeitungsart 12 -> 11
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 0);

    doc->setSection("anz");
    doc->setIntEntry("anz_chk_ba", 2);
    doc->setIntEntry("anz_chk_gem", 0);

    QString s = codec->fromUnicode(selzeile->text(0));
    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->setStringEntry("Kap_vers_von", s.latin1());
    doc->setStringEntry("Kap_vers_bis", s.latin1());

    doc->newDoc();
    emit signalSearch();
}

void QtBitanaView::slotZMen21_1()
{
    //  Aus bearbeitungsart 21 -> 11
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 0);

    doc->setSection("anz");
    doc->setIntEntry("anz_chk_ba", 2);
    doc->setIntEntry("anz_chk_gem", 0);
    doc->setIntEntry("anz_chk_int", 0);

    QString s = codec->fromUnicode(selzeile->text(3));
    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->setStringEntry("Kap_vers_von", s.latin1());
    s = codec->fromUnicode(selzeile->text(5));
    doc->setStringEntry("Kap_vers_bis", s.latin1());

    doc->newDoc();
    emit signalSearch();
}

void QtBitanaView::slotZMen21_2()
{
    //  Aus bearbeitungsart 21 -> 31
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 3);

    doc->setSection("wrt");
    doc->setIntEntry("wrt_find", 2);
    doc->setIntEntry("wrt_such", 0);
    doc->setLongEntry("wrt_spos", selzeile->text(2).toLong());
    doc->setIntEntry("wrt_inv", selzeile->text(1).toInt());
    doc->setStringEntry("wrt_w1", li_wo1.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());

    //  QString s = codec->fromUnicode(selzeile->text(3));
    //  doc->setStringEntry("Kap_vers_von", s.latin1());
    //  s = codec->fromUnicode(selzeile->text(5));
    //  doc->setStringEntry("Kap_vers_bis", s.latin1());

    emit signalInitBook();
    doc->newDoc();
 //  emit signalSearch();
}


void QtBitanaView::slotZMen22_1()
{
    //  Aus bearbeitungsart 22 -> 11
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 0);

    doc->setSection("anz");
    doc->setIntEntry("anz_chk_gem", 0);
    doc->setIntEntry("anz_chk_ba", 2);

    //  QString s = codec->fromUnicode(selzeile->text(3));
    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->setIntEntry("pos_von", selzeile->text(2).toInt());
    doc->setIntEntry("pos_bis", selzeile->text(4).toInt());

    doc->newDoc();
    doc->newTextPos();
    emit signalSearch();
}

void QtBitanaView::slotZMen31_1()
{
    //  Aus bearbeitungsart 31 -> 31  Abbildung
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 2);

    doc->setSection("nbr");
 //   doc->setIntEntry("nbr_chk_abb", 2);
//    doc->setIntEntry("nbr_grp_bre", 0);
    doc->setStringEntry("nbr_w1", li_wo1.latin1());
    doc->setStringEntry("nbr_w2", li_wo2.latin1());
    doc->setStringEntry("nbr_w3", li_wo3.latin1());

    doc->setIntEntry("nbr_nr", selzeile->text(0).toInt());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    /*
      QString s = codec->fromUnicode(selzeile->text(3));
      doc->setStringEntry("Kap_vers_von", s.latin1());
      s = codec->fromUnicode(selzeile->text(5));
      doc->setStringEntry("Kap_vers_bis", s.latin1());
    */
    doc->newDoc();
    emit signalSearch();
    markFileItem("nbr_abbildung.bta");
    doc->setSection("nbr");
    doc->setIntEntry("nbr_nr", 1);    // default-Wert wieder Einstellen

}

void QtBitanaView::slotZMen31_2()
{
    //  Aus bearbeitungsart 21 -> 31 1. Wort
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 3);

    doc->setSection("wrt");
    doc->setIntEntry("wrt_find", 2);
    doc->setIntEntry("wrt_such", 0);
    doc->setLongEntry("wrt_spos", selzeile->text(7).toLong());
    doc->setIntEntry("wrt_inv", selzeile->text(6).toInt());
    doc->setStringEntry("wrt_w1", li_wo1.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    //  doc->setIntEntry("pos_von", selzeile->text(3).toInt());
    //  doc->setIntEntry("pos_bis", selzeile->text(4).toInt());
    emit signalInitBook();
    doc->newDoc();
    emit signalSearch();
}

void QtBitanaView::slotZMen31_3()
{
    //  Aus bearbeitungsart 21 -> 31  / 2. Wort
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 3);

    doc->setSection("wrt");
    doc->setIntEntry("wrt_find", 2);
    doc->setIntEntry("wrt_such", 0);
    doc->setLongEntry("wrt_spos", selzeile->text(9).toLong());
    doc->setIntEntry("wrt_inv", selzeile->text(8).toInt());
    doc->setStringEntry("wrt_w1", li_wo2.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->setIntEntry("pos_von", selzeile->text(3).toInt());
    doc->setIntEntry("pos_bis", selzeile->text(4).toInt());

    emit signalInitBook();
    doc->newDoc();
    emit signalSearch();
}

void QtBitanaView::slotZMen31_4()
{
    //  Aus bearbeitungsart 21 -> 31  / 3. Wort
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 3);

    doc->setSection("wrt");
    doc->setIntEntry("wrt_find", 2);
    doc->setIntEntry("wrt_such", 0);
    doc->setLongEntry("wrt_spos", selzeile->text(11).toLong());
    doc->setIntEntry("wrt_inv", selzeile->text(10).toInt());
    doc->setStringEntry("wrt_w1", li_wo3.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->setIntEntry("pos_von", selzeile->text(3).toInt());
    doc->setIntEntry("pos_bis", selzeile->text(4).toInt());

    emit signalInitBook();
    doc->newDoc();
    emit signalSearch();
}

void QtBitanaView::slotZMen31_5()
{
    int wn;
    QString sword;
    QString tword;
    QString s;
    //  Aus bearbeitungsart 21 -> 31  / 3 Worte nach Matrixsuche
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 4);

    doc->setSection("mas");

    // Wort1
    s = li_wo1;
    for (wn=1; wn<=10; wn++)
    {
        sword = "mas_w" + QString::number(wn);
        tword = "mas_t" + QString::number(wn);
        if ( (doc->getStringEntry(sword)).empty() )
        {

            if (checkMasWord(s.latin1()))
            {
                doc->setStringEntry(sword, s.latin1());
                // bersetzung
                s = ""; 				// codec->fromUnicode(selzeile->text(6));
                doc->setStringEntry(tword, s.latin1());
            }
            break;
        }
    }

    // Wort 2

    s = li_wo2;
    for (wn=1; wn<=10; wn++)
    {
        sword = "mas_w" + QString::number(wn);
        tword = "mas_t" + QString::number(wn);
        if ( (doc->getStringEntry(sword)).empty() )
        {

            if (checkMasWord(s.latin1()))
            {
                doc->setStringEntry(sword, s.latin1());
                // bersetzung
                s = ""; 				// codec->fromUnicode(selzeile->text(6));
                doc->setStringEntry(tword, s.latin1());
            }
            break;
        }
    }


    // Wort 3

    s = li_wo3;
    for (wn=1; wn<=10; wn++)
    {
        sword = "mas_w" + QString::number(wn);
        tword = "mas_t" + QString::number(wn);
        if ( (doc->getStringEntry(sword)).empty() )
        {

            if (checkMasWord(s.latin1()))
            {
                doc->setStringEntry(sword, s.latin1());
                // bersetzung
                s = ""; 				// codec->fromUnicode(selzeile->text(6));
                doc->setStringEntry(tword, s.latin1());
            }
            break;
        }
    }
    doc->newDoc();


}
void QtBitanaView::slotZMen32_1()
{
    //  Aus bearbeitungsart 32 ->   /  Wort -2
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 2);

    doc->setSection("nbr");
//    doc->setIntEntry("nbr_chk_abb", 2);
//    doc->setIntEntry("nbr_grp_bre", 0);
    doc->setStringEntry("nbr_w1", li_wo1.latin1());
    QString s = codec->fromUnicode(selzeile->text(5));
    doc->setStringEntry("nbr_w2", s.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->newDoc();
}

void QtBitanaView::slotZMen32_2()
{
    //  Aus bearbeitungsart 32 ->   /  Wort -2
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 2);

    doc->setSection("nbr");
//    doc->setIntEntry("nbr_chk_abb", 2);
//    doc->setIntEntry("nbr_grp_bre", 0);
    doc->setStringEntry("nbr_w1", li_wo1.latin1());
    QString s = codec->fromUnicode(selzeile->text(5));
    doc->setStringEntry("nbr_w3", s.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->newDoc();
}

void QtBitanaView::slotZMen33_1()
{
    //  Aus bearbeitungsart 32 ->   /  Wort -2
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 2);

    doc->setSection("nbr");
//    doc->setIntEntry("nbr_chk_abb", 2);
//    doc->setIntEntry("nbr_grp_bre", 0);
    doc->setStringEntry("nbr_w1", li_wo1.latin1());
    QString s = codec->fromUnicode(selzeile->text(9));
    doc->setStringEntry("nbr_w2", s.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->newDoc();
}

void QtBitanaView::slotZMen33_2()
{
    //  Aus bearbeitungsart 32 ->   /  Wort -2
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 2);

    doc->setSection("nbr");
//    doc->setIntEntry("nbr_chk_abb", 2);
//    doc->setIntEntry("nbr_grp_bre", 0);
    doc->setStringEntry("nbr_w1", li_wo1.latin1());
    QString s = codec->fromUnicode(selzeile->text(9));
    doc->setStringEntry("nbr_w3", s.latin1());

    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->newDoc();
}
// Worte fr Matrix

void QtBitanaView::slotZMen42()
{
    int wn;
    QString sword;
    QString tword;
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 4);
    doc->setSection("mas");

    for (wn=1; wn<=10; wn++)
    {
        sword = "mas_w" + QString::number(wn);
        tword = "mas_t" + QString::number(wn);
        if ( (doc->getStringEntry(sword)).empty() )
        {
            QString s = codec->fromUnicode(selzeile->text(5));
            if (checkMasWord(s.latin1()))
            {
                doc->setStringEntry(sword, s.latin1());
                s = codec->fromUnicode(selzeile->text(6));
                doc->setStringEntry(tword, s.latin1());
            }
            break;
        }
    }
    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->newDoc();
}

void QtBitanaView::slotZMen43()
{
    int wn;
    QString sword;
    QString tword;
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 4);
    doc->setSection("mas");

    for (wn=1; wn<=10; wn++)
    {
        sword = "mas_w" + QString::number(wn);
        tword = "mas_t" + QString::number(wn);
        if ( (doc->getStringEntry(sword)).empty() )
        {
            QString s = codec->fromUnicode(selzeile->text(9));
            if (checkMasWord(s.latin1()))
            {
                doc->setStringEntry(sword, s.latin1());
                s = codec->fromUnicode(selzeile->text(10));
                doc->setStringEntry(tword, s.latin1());
            }
            break;
        }
    }
    doc->setSection("book");
    doc->setStringEntry("book", li_book.latin1());
    doc->newDoc();
}


//-------------------------------------------------------------------------------------------------

/** �ernahme der hebeingabe in ein Feld */
void QtBitanaView::setHebWord(string section, string wname, QLineEdit *wo)
{

    doc->setSection("hebinput");
    string s = doc->getStringEntry("word", "");
    QString word(s.c_str());
    wo->setText(codec->toUnicode(word));

    doc->setSection(section);
    doc->setStringEntry(wname, s);

}


//-------------------------------------------------------------------------------
/** Ausgewaehltes Ergebnisdokument anzeigen */
void QtBitanaView::slotResDoc(QListViewItem *item)
{

    QString fname = item->text(2);
    if (fname.find(".bta") < 1)
        return;
    showDoc( resultdir + fname);

}
// Slots fr Anzeige - signals

void  QtBitanaView::slotAnzBa(int i)
{
    doc->setSection("anz");
    doc->setIntEntry("anz_chk_ba", i);
}

void  QtBitanaView::slotAnzGem(int i)
{
    doc->setSection("anz");
    doc->setIntEntry("anz_chk_gem", i);
}

void  QtBitanaView::slotAnzInt(int i)
{
    doc->setSection("anz");
    doc->setIntEntry("anz_chk_int", i);
}

void  QtBitanaView::slotAnzMod(int i)
{
    doc->setSection("anz");
    doc->setIntEntry("anz_chk_mod", i);
}


// Slots fr Intervallsuche - signals

void QtBitanaView::slotItvWset()
{
    setHebWord("itv", "itv_w", tab->itv_w);
}

void  QtBitanaView::slotItvMod(int i)
{
    doc->setSection("itv");
    doc->setIntEntry("itv_chk_mod", i);
}

void  QtBitanaView::slotItvInv(int i)
{
    doc->setSection("itv");
    if ((i == 0) && (doc->getIntEntry("itv_chk_blk") == 0))
    {
        tab->itv_chk_inv->setChecked(true);
        i =2;
    }
    doc->setIntEntry("itv_chk_inv", i);
    if (i==0)
    {
        //    tab->itv_ivv->setDisabled(true);
        //    tab->itv_ivb->setDisabled(true);
        tab->itv_grp_ric->setDisabled(true);
        tab->itv_grp_sort->setDisabled(true);

    }
    else
    {
        //    tab->itv_ivv->setEnabled(true);
        //    tab->itv_ivb->setEnabled(true);
        tab->itv_chk_vor->setEnabled(true);
        tab->itv_grp_ric->setEnabled(true);
        tab->itv_grp_sort->setEnabled(true);

    }
}

void QtBitanaView::slotAnzLInt(int i)
{
    doc->setSection("anz");
    doc->setIntEntry("anz_int", i);
}

void QtBitanaView::slotAnzDar(int i)
{
    doc->setSection("anz");
    doc->setIntEntry("anz_dar", i);
}


void QtBitanaView::slotItvIvv(int i)
{
    doc->setSection("itv");
    doc->setIntEntry("itv_ivv", i);
}

void QtBitanaView::slotItvIvb(int i)
{
    doc->setSection("itv");
    doc->setIntEntry("itv_ivb", i);
}

void QtBitanaView::slotItvBbis(int i)
{
    doc->setSection("itv");
    doc->setIntEntry("itv_bbis", i);
}

void QtBitanaView::slotItvBsel(int i)
{
    doc->setSection("itv");
    doc->setIntEntry("itv_bsel", i);
}

void  QtBitanaView::slotItvVor(int i)
{

    doc->setSection("itv");
    if ((i == 0) && (doc->getIntEntry("itv_chk_rue") == 0))
    {
        tab->itv_chk_vor->setChecked(true);
        i =2;
    }
    doc->setIntEntry("itv_chk_vor", i);
}

void  QtBitanaView::slotItvRue(int i)
{
    doc->setSection("itv");
    if ((i == 0) && (doc->getIntEntry("itv_chk_vor") == 0))
    {
        tab->itv_chk_rue->setChecked(true);
        i =2;
    }
    doc->setIntEntry("itv_chk_rue", i);
}

void  QtBitanaView::slotItvSort(int i)
{
    doc->setSection("itv");
    switch (i)
    {
    case 0: // Position
        doc->setIntEntry("itv_grp_sort", 1);
        break;
    case 1: // Max Bereich
        doc->setIntEntry("itv_grp_sort", 2);
        break;
    case 2: // Intervall
        doc->setIntEntry("itv_grp_sort", 0);
        break;
    default:
        doc->setIntEntry("itv_grp_sort", i);
    }

}

void  QtBitanaView::slotItvBlk(int i)
{
    doc->setSection("itv");
    if ((i == 0) && (doc->getIntEntry("itv_chk_inv") == 0))
    {
        tab->itv_chk_blk->setChecked(true);
        i =2;
    }
    doc->setIntEntry("itv_chk_blk", i);
    if (i==0)
    {
        tab->itv_bbis->setDisabled(true);
        tab->itv_bsel->setDisabled(true);

    }
    else
    {
        tab->itv_bbis->setEnabled(true);
        tab->itv_bsel->setEnabled(true);

    }
}

// Nachbarschaftsprfung

void  QtBitanaView::slotNbrInt1(int i)
{
    doc->setSection("nbr");
    doc->setIntEntry("nbr_chk_int1", i);

}

void  QtBitanaView::slotNbrMod(int i)
{
    doc->setSection("nbr");
    doc->setIntEntry("nbr_chk_mod", i);
}

void QtBitanaView::slotNbrW1set()
{
    setHebWord("nbr", "nbr_w1", tab->nbr_w1);
}
void QtBitanaView::slotNbrW2set()
{
    setHebWord("nbr", "nbr_w2", tab->nbr_w2);
}
void QtBitanaView::slotNbrW3set()
{
    setHebWord("nbr", "nbr_w3", tab->nbr_w3);
}

void QtBitanaView::slotTabChanged(QWidget *tw)
{

    tw->isEnabled();
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", tab->TabWidget->currentPageIndex());

}

void QtBitanaView::slotWrtW1set()
{
    setHebWord("wrt", "wrt_w1", tab->wrt_w1);
}
void QtBitanaView::slotWrtW2set()
{
    setHebWord("wrt", "wrt_w2", tab->wrt_w2);
}

void QtBitanaView::slotWrtSpos(int i)
{
    QString wert =  tab->wrt_spos->text();
    doc->setSection("wrt");
    doc->setLongEntry("wrt_spos", wert.toLong());
}

void QtBitanaView::slotWrtInv(int i)
{
    doc->setSection("wrt");
    doc->setIntEntry("wrt_inv", i);
}

void QtBitanaView::slotWrtMnb(int i)
{
    doc->setSection("wrt");
}

void QtBitanaView::slotWrtFind(int i)
{
    doc->setSection("wrt");
    if (i == 2)
    {
        tab->wrt_such->setChecked(false);
    }
    doc->setIntEntry("wrt_find", i);

    if (i==0)
    {
        tab->wrt_w1->setDisabled(true);
        tab->wrt_spos->setDisabled(true);
        tab->wrt_inv->setDisabled(true);

    }
    else
    {
        tab->wrt_w1->setEnabled(true);
        tab->wrt_spos->setEnabled(true);
        tab->wrt_inv->setEnabled(true);

    }
}

void QtBitanaView::slotWrtSuch(int i)
{
    doc->setSection("wrt");
    if (i == 2)
    {
        tab->wrt_find->setChecked(false);
    }
    doc->setIntEntry("wrt_such", i);

    if (i==0)
    {
        tab->wrt_w2->setDisabled(true);
    }
    else
    {
        tab->wrt_w2->setEnabled(true);
    }
}

// Matrixsuche

void QtBitanaView::slotMasW1set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {

        setHebWord("mas", "mas_w1", tab->mas_w1);
        tab->mas_t1->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t1", "");
    }
}

void QtBitanaView::slotMasW2set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w2", tab->mas_w2);
        tab->mas_t2->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t2", "");
    }
}

void QtBitanaView::slotMasW3set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w3", tab->mas_w3);
        tab->mas_t3->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t3", "");
    }
}

void QtBitanaView::slotMasW4set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w4", tab->mas_w4);
        tab->mas_t4->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t4", "");
    }
}

void QtBitanaView::slotMasW5set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w5", tab->mas_w5);
        tab->mas_t5->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t5", "");
    }
}

void QtBitanaView::slotMasW6set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w6", tab->mas_w6);
        tab->mas_t6->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t6", "");
    }
}

void QtBitanaView::slotMasW7set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w7", tab->mas_w7);
        tab->mas_t7->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t7", "");
    }
}

void QtBitanaView::slotMasW8set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w8", tab->mas_w8);
        tab->mas_t8->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t8", "");
    }
}

void QtBitanaView::slotMasW9set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w9", tab->mas_w9);
        tab->mas_t9->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t9", "");
    }
}

void QtBitanaView::slotMasW10set()
{
    doc->setSection("hebinput");
    if (checkMasWord(doc->getStringEntry("word", "")))
    {
        setHebWord("mas", "mas_w10", tab->mas_w10);
        tab->mas_t10->setText("");
        doc->setSection("mas");
        doc->setStringEntry("mas_t10", "");

    }
}

void QtBitanaView::slotMasClear()
{
    QString sw, tw;
    int i;
    doc->setSection("mas");
    for (i=1; i<=10; i++)
    {
        sw = "mas_w" + QString::number(i);
        tw = "mas_t" + QString::number(i);

        doc->setStringEntry(sw, "");
        doc->setStringEntry(tw, "");


    }
    doc->newDoc();
}

void  QtBitanaView::slotMasMod(int i)
{
    doc->setSection("mas");
    doc->setIntEntry("mas_chk_mod", i);
}

void  QtBitanaView::slotMasInt1(int i)
{
    doc->setSection("mas");
    doc->setIntEntry("mas_chk_int1", i);
}

/** Font wurde ge�dert */
void QtBitanaView::slotFontChanged()
{
    initHebFont();
    hi->setFont(hfont1);
    hi->repaint();

    dkop->setFont( font() );
    dkop->repaint();

    dtab->setFont( font());
    dtab->repaint();

    //   dmat->setFont(hfont1);
    dmat->setFont( font());
    dmat->repaint();

    tab->setFont( font());

    //  tab->setFont(hfont1);
    tab->nbr_w1->setFont(hfont1);
    tab->nbr_w2->setFont(hfont1);
    tab->nbr_w3->setFont(hfont1);
    tab->wrt_w1->setFont(hfont1);
    tab->wrt_w2->setFont(hfont1);
    tab->itv_w->setFont(hfont1);

    tab->mas_w1->setFont(hfont1);
    tab->mas_w2->setFont(hfont1);
    tab->mas_w3->setFont(hfont1);
    tab->mas_w4->setFont(hfont1);
    tab->mas_w5->setFont(hfont1);
    tab->mas_w6->setFont(hfont1);
    tab->mas_w7->setFont(hfont1);
    tab->mas_w8->setFont(hfont1);
    tab->mas_w9->setFont(hfont1);
    tab->mas_w10->setFont(hfont1);

    tab->repaint();
    repaint();
}


/*!
    \fn QtBitanaView::checkMasWord(string)
    Wenn Word noch nicht in der Liste -> true
 */
bool QtBitanaView::checkMasWord(string w1)
{
    int wn;
    QString sword;
    QString tword;
    doc->setSection("qtbitana");
    doc->setIntEntry("tab_sel", 4);
    doc->setSection("mas");

    for (wn=1; wn<=10; wn++)
    {
        sword = "mas_w" + QString::number(wn);
        tword = "mas_t" + QString::number(wn);
        if ( (doc->getStringEntry(sword)).empty() )
            continue;
        if ( (doc->getStringEntry(sword)) == w1)
            return false;
    }
    return true;
}
