/***************************************************************************
                          qtbitanaview.h  -  description
                             -------------------
    begin                : Don Aug  8 22:46:53 CEST 2002
    copyright            : (C) 2002 by Heinz & Hans-Jrgen Schumann
    email                : heinz@bitana.de; hans@bitana.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QTBITANAVIEW_H
#define QTBITANAVIEW_H

// include files for QT
#include <qwidget.h>
#include <qtabwidget.h>
#include <qfont.h>
#include <qtextcodec.h>
#include <qlayout.h>
#include <qlineedit.h>
#include <qsplitter.h>
#include <qwidgetstack.h>
#include <qmultilineedit.h>
#include <qtable.h>
#include <qstring.h>
#include <qlistview.h>
#include <qpopupmenu.h>

// #include <string>

// application specific includes
#include "qtbitanadoc.h"
#include "cbitanaconfig.h"
#include "qtbitanamod.h"
#include "bhebinp.h"
#include "btextmatrix.h"
#include "bdoclst.h"
/**
 * This class provides an incomplete base for your application view. 
 */

class QtBitanaView : public QWidget
{
    Q_OBJECT
public:
    QtBitanaView(QWidget *parent=0, QtBitanaDoc* doc=0);
    ~QtBitanaView();

    /** Eingabefenster zeigen **/
    void showEditWindow(bool show = true);
    void showDocList(bool show=true);
    bool showDoc(QString file);
    void markFileItem(QString file);

signals:
    void signalSearch();
    void signalInitBook();
private:
    QString resultdir;
    CBitanaConfig *conf;
    BHebInp *hi;
    QtBitanaModi *tab;
    QVBoxLayout *vl;
    QHBoxLayout *hl;
    QSplitter *hs, *vs;

    /** Heb-Font1 for Buttons and widgetstitels / menus */
    QFont hfont1;
    /** Heb-Font2 for Text / Matrix and Multilinewindow */
    QFont hfont2;

    QtBitanaDoc *doc;
    // Private methods
    /** initialisiert die heb-Fonts aus dem Config-Objekt */
    bool initHebFont();
    QTextCodec* codec;
    BDocLst *dlst;

    QWidgetStack *docw;
    // Doc - Ausgabe
    QMultiLineEdit *dkop;
    //  QMultiLineEdit *dtxt;
    /** Widget Ergebnistabellen */
    QListView *dtab;
    /**Widget Textmatrix */
    BTextMatrix *dmat;
    /** Widget Pictures */
    QWidget *dpix;

    // Listen Kopf fr Tabellenmenu
    int li_art;         // Bearbeitungsart
    int li_nr;          // nr
    QString li_book;    // Buch
    QString li_wo1;     // Wort 1
    QString li_wo2;     // Wort 2
    QString li_wo3;     // Wort 3
    QString li_vonkv;   // Von Kap:Vers
    QString li_biskv;   // Bis Kap:Vers
    int li_vonint;      // Von Intervall
    int li_bisint;      // Bis Intervall
    QString li_file;    // Listen filename

    QListViewItem *selzeile;
    QPopupMenu *zmenu;
    void initZMenu();
protected slots:
    void slotResDoc(QListViewItem *item);
    void slotDocumentChanged();
    //private slots: // Private slots
    /** No descriptions */
    void setHebWord(string s, string wn, QLineEdit *w);

    void slotAnzBa(int);
    void slotAnzGem(int);
    void slotAnzInt(int);
    void slotAnzMod(int);
    void slotAnzLInt(int);
    void slotAnzDar(int);

    void slotItvWset();
    void slotItvMod(int);
    void slotItvInv(int);
    void slotItvIvv(int);
    void slotItvIvb(int);
    void slotItvVor(int);
    void slotItvRue(int);
    void slotItvSort(int);
    void slotItvBlk(int);
    void slotItvBbis(int);
    void slotItvBsel(int);

    void slotNbrW1set();
    void slotNbrW2set();
    void slotNbrW3set();
    void slotNbrInt1(int);
    void slotNbrMod(int);
 
    void slotWrtW1set();
    void slotWrtW2set();

    void slotWrtFind(int);
    void slotWrtSuch(int);

    void slotWrtSpos(int);
    void slotWrtInv(int);
    void slotWrtMnb(int);

    void slotMasW1set();
    void slotMasW2set();
    void slotMasW3set();
    void slotMasW4set();
    void slotMasW5set();
    void slotMasW6set();
    void slotMasW7set();
    void slotMasW8set();
    void slotMasW9set();
    void slotMasW10set();
    void slotMasClear();
    void slotMasMod(int);
    void slotMasInt1(int);

    void slotTabChanged(QWidget *);
    void slotMenTab(QListViewItem*,const QPoint&,int);

    void slotZMen11_1();    // menupunkt 1 aus Art 11
    void slotZMen12_1();    // menupunkt 1 aus Art 12
    void slotZMen21_1();    // menuepunkt 1 aus Art 21
    void slotZMen21_2();    // menuepunkt 1 aus Art 21
    void slotZMen22_1();
    void slotZMen31_1();
    void slotZMen31_2();
    void slotZMen31_3();
    void slotZMen31_4();
    void slotZMen31_5();
    void slotZMen32_1();
    void slotZMen32_2();
    void slotZMen33_1();
    void slotZMen33_2();

    void slotZMen42();
    void slotZMen43();


public slots: // Public slots
    /** Font wurde ge?dert */
    void slotFontChanged();
private:
    bool checkMasWord(string);
};

#endif
